SystemOrganization addCategory: #Log4s!
SystemOrganization addCategory: #'Log4s-Appenders'!
SystemOrganization addCategory: #'Log4s-Converters'!
SystemOrganization addCategory: #'Log4s-FileSupport'!
SystemOrganization addCategory: #'Log4s-Filters'!
SystemOrganization addCategory: #'Log4s-Layouts'!
SystemOrganization addCategory: #'Log4s-SocketSupport'!
SystemOrganization addCategory: #'Log4s-Tests'!

!Socket methodsFor: '*log4s' stamp: 'DonaldMacQueen 6/7/2013 10:33'!
connectToNoSignal: hostAddress port: port waitForConnectionFor: timeout 
	"Initiate a connection to the given port at the given host 
	address. Waits until the connection is established or time outs."
	self connectNonBlockingTo: hostAddress port: port.
	self
		waitForConnectionFor: timeout
		ifTimedOut: [^nil] desiredStatus: Connected  ! !

!Socket methodsFor: '*log4s' stamp: 'DonaldMacQueen 6/7/2013 09:40'!
waitForConnectionFor: timeout ifTimedOut: timeoutBlock desiredStatus: desiredStatus
	"Wait up until the given deadline for a connection to be established. Return true if it is established by the deadline, false if not.
	
	This method is the same as waitForConnectionFor: timeout ifTimedOut: timeoutBlock except that we wait for the desired status before timing out"

	| startTime msecsDelta msecsEllapsed status |
	startTime := Time millisecondClockValue.
	msecsDelta := (timeout * 1000) truncated.
	status := self primSocketConnectionStatus: socketHandle.
	[(status ~= desiredStatus) and: [(msecsEllapsed := Time millisecondsSince: startTime) < msecsDelta]]  
		whileTrue: [
			semaphore waitTimeoutMSecs: msecsDelta - msecsEllapsed.
			status := self primSocketConnectionStatus: socketHandle].

	status = Connected ifFalse: [^timeoutBlock value].
	^ true! !

!DateAndTime methodsFor: '*Log4s' stamp: 'DonaldMacQueen 6/7/2013 16:57'!
transformTo: aTimeZone
	"4pm EST is 1pm PST. Both times are the same"
	offset:= aTimeZone offset! !

TestCase subclass: #LoggingDailyRollingFileAppenderTestCase
	instanceVariableNames: 'logger event'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Tests'!

!LoggingDailyRollingFileAppenderTestCase methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/27/2012 17:12'!
dailyRollingFileAppenderParams: aPatternConverterString

	"1 - name
	2 - loggerName
	3 - fileName
	4 - fileAppend
	5 - level
	6 - layout
	7 - patternConverter
	8 - immediateFlush
	9 - datePattern"

	| oc |

	oc := (OrderedCollection
		with: 'TestDailyRollingFileAppender'
		with: 'root'
		with: 'dailyRollingFileAppender.log'
		with: false).
	oc
		add: 'Info';
		add: 'EsPatternLayout';
		add: aPatternConverterString;
		add: true.
	^oc! !

!LoggingDailyRollingFileAppenderTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
dateToTest12

	"8-28-1989 8:15:07 AM"

	^DateAndTime year: 1989 day: 240 hour: 8 minute: 15 second: 7! !

!LoggingDailyRollingFileAppenderTestCase methodsFor: 'accessing' stamp: 'DonaldMacQueen 6/5/2013 21:19'!
dateToTest24

	"7-15-1991 20:05:07 PM"

	^DateAndTime year: 1991 month:7 day: 15 hour: 20 minute: 5 second: 7! !

!LoggingDailyRollingFileAppenderTestCase methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/1/2012 13:39'!
setUp

	EsLogManager reset.
	logger := EsLogManager rootLogger.
	event :=
		EsLoggingEvent
			logger: logger
			locationInfo: thisContext
			level: EsLevel Info
			message: 'Hello, World'
			object: self

! !

!LoggingDailyRollingFileAppenderTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
tearDown

	EsLogManager shutDown! !

!LoggingDailyRollingFileAppenderTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/13/2012 11:20'!
testHalfDay

	"there should be fewer than 12 hours until the next scheduled rollover"

	| in params dailyRollingFileAppender now |

	in := 'level - %m'.

	now := DateAndTime now.
	params := self dailyRollingFileAppenderParams: in.
	params addLast: 'halfday'.

	self assert: (params last notNil).

	dailyRollingFileAppender := EsLogManager dailyRollingFileAppender: params isAsync: false.
	self assert: (dailyRollingFileAppender notNil).

	self assert: ((dailyRollingFileAppender scheduledRollover - now) hours < 12)! !

!LoggingDailyRollingFileAppenderTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/13/2012 11:20'!
testTopOfDay

	"there should be fewer than 24 hours until the next scheduled rollover"

	| in params dailyRollingFileAppender now |

	in := 'level - %m'.
	now := DateAndTime now.
	params := self dailyRollingFileAppenderParams: in.
	params addLast: 'topofday'.

	self assert: (params last notNil).

	dailyRollingFileAppender := EsLogManager dailyRollingFileAppender: params isAsync: false.
	self assert: (dailyRollingFileAppender notNil).

	self assert: ((dailyRollingFileAppender scheduledRollover - now) hours < 24)! !

!LoggingDailyRollingFileAppenderTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/13/2012 11:20'!
testTopOfHour

	"there should be fewer than 60 minutes until the next scheduled rollover"

	| in params dailyRollingFileAppender now |

	in := 'level - %m'.

	now := DateAndTime now.
	params := self dailyRollingFileAppenderParams: in.
	params addLast: 'topofhour'.

	self assert: (params last notNil).

	dailyRollingFileAppender := EsLogManager dailyRollingFileAppender: params isAsync: false.
	self assert: (dailyRollingFileAppender notNil).

	self assert: ((dailyRollingFileAppender scheduledRollover - now) minutes < 60)! !

!LoggingDailyRollingFileAppenderTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/5/2012 13:17'!
testTopOfMinute

	"there should be fewer than 60 seconds until the next scheduled rollover"

	| in params dailyRollingFileAppender now |

	in := 'level - %m'.

	now := DateAndTime now.
	params := self dailyRollingFileAppenderParams: in.
	params addLast: 'topofminute'.

	self assert: (params last notNil).

	dailyRollingFileAppender := EsLogManager dailyRollingFileAppender: params isAsync: false.
	self assert: (dailyRollingFileAppender notNil).

	self assert: ((dailyRollingFileAppender scheduledRollover - now) seconds < 60)! !

!LoggingDailyRollingFileAppenderTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/13/2012 11:20'!
testTopOfMonth

	"the rollover month shoud be greater than the current month"

	| in params dailyRollingFileAppender now nowMonth rollover nextMonth |

	in := 'level - %m'.

	now := DateAndTime now.
	params := self dailyRollingFileAppenderParams: in.
	params addLast: 'topofmonth'.

	dailyRollingFileAppender := EsLogManager dailyRollingFileAppender: params isAsync: false.
	self assert: (dailyRollingFileAppender notNil).

	self assert: (params last notNil).

	rollover := dailyRollingFileAppender scheduledRollover.

	self assert: (rollover month > 1 ifTrue: [rollover month > now month])! !

!LoggingDailyRollingFileAppenderTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/13/2012 11:20'!
testTopOfWeek

	| in params dailyRollingFileAppender now |

	in := 'level - %m'.

	now := DateAndTime now.
	params := self dailyRollingFileAppenderParams: in.
	params addLast: 'topofweek'.

	dailyRollingFileAppender := EsLogManager dailyRollingFileAppender: params isAsync: false.
	self assert: (dailyRollingFileAppender notNil).

	self assert: (params last notNil).

	self assert: (dailyRollingFileAppender scheduledRollover dayOfWeek = 1).
	self assert: (dailyRollingFileAppender scheduledRollover > now).
	self assert: ((dailyRollingFileAppender scheduledRollover - now) days < 7)! !

TestCase subclass: #LoggingFileAppenderTestCase
	instanceVariableNames: 'logger event'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Tests'!

!LoggingFileAppenderTestCase methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/27/2012 17:12'!
fileAppenderParams: aPatternConverterString

	"1 - name
	2 - loggerName
	3 - fileName
	4 - fileAppend
	5 - level
	6 - layout
	7 - patternConverter
	8 - immediateFlush"

	| oc |

	oc := (OrderedCollection with: 'TestFileAppender' with: 'root' with: 'fileAppender.log' with: false).
	oc
		add: 'Info';
		add: 'EsPatternLayout';
		add: aPatternConverterString;
		add: true.
	^oc! !

!LoggingFileAppenderTestCase methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/1/2012 13:39'!
setUp

	EsLogManager reset.
	logger := EsLogManager rootLogger.
	event :=
		EsLoggingEvent
			logger: logger
			locationInfo: thisContext
			level: EsLevel Info
			message: 'Hello, World'
			object: self

! !

!LoggingFileAppenderTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
tearDown

	EsLogManager shutDown! !

!LoggingFileAppenderTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/12/2012 12:30'!
testFileAppend

	| result in out appender oc params firstSize secondSize file fileName |

	in := '%message'.

	appender := EsLogManager fileAppender: (self fileAppenderParams: in) isAsync: false.
	self assert: (appender notNil).

	5 timesRepeat: [logger log: event].

	fileName := appender fileName.
	EsLogManager shutDown: nil. "close all the files"

	file := FileStream oldFileNamed:  fileName.
	firstSize := file size.
	file close.

	self setUp.

	params := self fileAppenderParams: in.
	params at: 4 put: true. "set fileAppend to true"

	appender := EsLogManager fileAppender: (params) isAsync: false.
	self assert: (appender notNil).

	5 timesRepeat: [logger log: event].

	EsLogManager shutDown: nil. "close all the files"

	file := FileStream oldFileNamed:  fileName.
	secondSize := file size.
	file close.

	self assert: (secondSize > firstSize)! !

!LoggingFileAppenderTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/13/2012 21:55'!
testFileAppendNoFile

	|   in appender params |

	in := '%message'.
	
	params := self fileAppenderParams: in.
	params := params at: 3 put: 'a:\xyzzy.txt';yourself.
	params at: 4 put: true. "set fileAppend to true"

	appender := EsLogManager fileAppender: (params) isAsync: false.
	self assert: (appender isNil).

	! !

!LoggingFileAppenderTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/12/2012 12:30'!
testFileNoAppend

	| result in out appender oc params firstSize secondSize file fileName |

	in := '%message'.

	appender := EsLogManager fileAppender: (self fileAppenderParams: in) isAsync: false.
	self assert: (appender notNil).

	5 timesRepeat: [logger log: event].

	fileName := appender fileName.
	EsLogManager shutDown: nil. "close all the files"

	file := FileStream oldFileNamed:  fileName.
	firstSize := file size.
	file close.

	self setUp.

	params := self fileAppenderParams: in.

	appender := EsLogManager fileAppender: (params) isAsync: false.
	self assert: (appender notNil).

	5 timesRepeat: [logger log: event].

	EsLogManager shutDown: nil. "close all the files"

	file := FileStream oldFileNamed:  fileName.
	secondSize := file size.
	file close.

	self assert: (secondSize = firstSize)! !

!LoggingFileAppenderTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/14/2012 07:52'!
testFileNoAppendCantCreate

	| result in out appender oc params firstSize secondSize file  fileName   |

	in := '%message'.

	fileName := WriteStream on: String new.
	fileName nextPutAll: 'bad'; nextPut: (Character value: 0); nextPutAll: 'FileName'. "create an illegal fileName"
	
	fileName := 'zz:\xyzzy.'.
	params := self fileAppenderParams: in.
	params := params at: 3 put: fileName  ;yourself.

	appender := EsLogManager fileAppender: params isAsync: false.
	self assert: (appender isNil).

	! !

TestCase subclass: #LoggingFiltersTestCase
	instanceVariableNames: 'logger event'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Tests'!

!LoggingFiltersTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
addCr: in

	| string |

	string := WriteStream on: ''.
	string
		nextPutAll: in;
		cr.
	^string contents! !

!LoggingFiltersTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
dateToTest12

	"8-28-1989 8:15:07 AM"

	^DateAndTime year: 1989 day: 240 hour: 8 minute: 15 second: 7! !

!LoggingFiltersTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/14/2011 9:6'!
dateToTest24

	"7-15-1991 20:05:07 PM"

	^DateAndTime year: 1991 day: 196 hour: 20 minute: 5 second: 7! !

!LoggingFiltersTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
inMemoryParams: aString

	| oc |

	oc :=
		OrderedCollection
			with: 'LoggingFiltersInMemoryAppender'
			with: 'root'
			with: 'Info'
			with: 'EsPatternLayout'.
	oc add: aString.
	^oc! !

!LoggingFiltersTestCase methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/1/2012 13:39'!
setUp

	EsLogManager reset.
	logger := EsLogManager rootLogger.
	event :=
		EsLoggingEvent
			logger: logger
			locationInfo: thisContext
			level: EsLevel Info
			message: 'Hello, World'
			object: self

! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testChainedFilters1

	| filter filterName stringToMatch result appender in |

	filterName := 'StringMatchFilter'.
	stringToMatch := 'Hi Mom'. "test succeeds because we do not find this string in the event message ''Hello, World''"

	in := '%C'.

	appender := EsLogManager inMemoryAppender: (self inMemoryParams: in).
	self assert: (appender notNil).

	logger log: event. "no filters"

	self assert: (appender filters isEmpty).

	self assert: (appender contents = (self addCr: 'LoggingFiltersTestCase'))







! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testChainedFilters2

	| filter filterName stringToMatch result appender in |

	in := '%C'. "both event level and filter level are Info"

	appender := EsLogManager inMemoryAppender: (self inMemoryParams: in).
	self assert: (appender notNil).

	filterName := 'LevelMatchFilter'.

	filter := appender addLevelMatchFilter: (OrderedCollection with: filterName with: 'Info').

	logger log: event.

	self assert: (appender filters size = 1).

	self assert: (appender contents = (self addCr: 'LoggingFiltersTestCase'))







! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testChainedFilters4

	| filter filterName stringToMatch result appender in |

	in := '%C'. " event level is info and filter level is debug"

	appender := EsLogManager inMemoryAppender: (self inMemoryParams: in).
	self assert: (appender notNil).

	filterName := 'LevelMatchFilter'.

	filter := appender addLevelMatchFilter: (OrderedCollection with: filterName with: 'Debug').

	logger log: event.

	self assert: (appender filters size = 1).

	self assert: (appender contents isEmpty)







! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testChainedFilters5

	| filter filterName stringToMatch result appender in |

	in := '%C'. " event level is Fatal which is outside the range"

	appender := EsLogManager inMemoryAppender: (self inMemoryParams: in).
	self assert: (appender notNil).

	filterName := 'LevelRangeFilter'.

	filter :=
		appender
			addLevelRangeFilter: (OrderedCollection with: filterName with: 'Debug' with: 'Error').

	event level: EsLevel Fatal.
	logger log: event.

	self assert: (appender filters size = 1).

	self assert: (appender contents isEmpty)







! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testChainedFilters6

	| filter filterName stringToMatch result appender in |

	in := '%C'. " event level is Info which is inside the range"

	appender := EsLogManager inMemoryAppender: (self inMemoryParams: in).
	self assert: (appender notNil).

	filterName := 'LevelRangeFilter'.
	filter :=
		appender
			addLevelRangeFilter: (OrderedCollection with: filterName with: 'Debug' with: 'Error').

	logger log: event.

	self assert: (appender filters size = 1).

	self assert: (appender contents = (self addCr: 'LoggingFiltersTestCase'))







! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testChainedFilters7

	| filter filterName stringToMatch result appender in |

	in := '%C'. " event level is Info which is inside the range but classNameToFilter is not Time"

	appender := EsLogManager inMemoryAppender: (self inMemoryParams: in).
	self assert: (appender notNil).

	filterName := 'LevelRangeFilter'.
	filter :=
		appender
			addLevelRangeFilter: (OrderedCollection with: filterName with: 'Debug' with: 'Error').

	filterName := 'ClassNameFilter'.
	filter := appender addClassNameFilter: (OrderedCollection with: filterName with: 'Time').


	logger log: event.

	self assert: (appender filters size = 2).

	self assert: (appender contents isEmpty)







! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testChainedFilters8

	| filter filterName stringToMatch result appender in |

	in := '%C'. " event level is Info which is inside the range and classNameToFilter is LoggingFiltersTestCase"

	appender := EsLogManager inMemoryAppender: (self inMemoryParams: in).
	self assert: (appender notNil).

	filterName := 'LevelRangeFilter'.
	filter :=
		appender
			addLevelRangeFilter: (OrderedCollection with: filterName with: 'Debug' with: 'Error').

	filterName := 'ClassNameFilter'.
	filter :=
		appender
			addClassNameFilter: (OrderedCollection with: filterName with: 'LoggingFiltersTestCase').

	logger log: event.

	self assert: (appender filters size = 2).

	self assert: (appender contents = (self addCr: 'LoggingFiltersTestCase'))







! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testChainedFilters9

	| filter filterName stringToMatch result appender in |

	in := '%C'. " event level is Info which is inside the range and classNameToFilter is LoggingFiltersTestCase, but string match fails"

	appender := EsLogManager inMemoryAppender: (self inMemoryParams: in).
	self assert: (appender notNil).

	filterName := 'LevelRangeFilter'.
	filter :=
		appender
			addLevelRangeFilter: (OrderedCollection with: filterName with: 'Debug' with: 'Error').

	filterName := 'StringMatchFilter'.
	stringToMatch := 'Hi Mom'. "test fails because we do not find this string in the event message ''Hello, World''"
	filter :=
		appender addStringMatchFilter:
			(OrderedCollection with: filterName with: stringToMatch with: true with: true).

	filterName := 'ClassNameFilter'.
	filter :=
		appender
			addClassNameFilter: (OrderedCollection with: filterName with: 'LoggingFiltersTestCase').

	logger log: event.

	self assert: (appender filters size = 3).

	self assert: (appender contents isEmpty)







! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testClassNameFilter1

	| filter filterName className result transcriptAppender |

	filterName := 'ClassNameFilter'.

	className := 'Time'.

	transcriptAppender := EsTranscriptAppender level: EsLevel All layout: (EsPatternLayout new: '%m').
	logger addAppender: transcriptAppender.

	filter :=
		transcriptAppender addClassNameFilter: (OrderedCollection with: filterName with: className).

	result := filter decide: event.
	self assert: (result = EsAbstractFilter Deny) "the class name is not Time"








! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testClassNameFilter2

	| filter filterName transcriptAppender className result |

	filterName := 'ClassNameFilter'.

	className := 'LoggingFiltersTestCase'.

	transcriptAppender := EsTranscriptAppender level: EsLevel All layout: (EsPatternLayout new: '%m').
	logger addAppender: transcriptAppender.

	filter :=
		transcriptAppender addClassNameFilter: (OrderedCollection with: filterName with: className).


	result := filter decide: event.
	self assert: (result = EsAbstractFilter Accept)








! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testClassNameFilter3

	| filter filterName className result transcriptAppender |

	filterName := 'ClassNameFilter'.

	className := 'Time'.

	transcriptAppender := EsTranscriptAppender level: EsLevel All layout: (EsPatternLayout new: '%m').
	logger addAppender: transcriptAppender.

	filter :=
		transcriptAppender
			addClassNameFilter: (OrderedCollection with: filterName with: className with: false).

	result := filter decide: event.
	self assert: (result = EsAbstractFilter Accept) "the class name is not Time but acceptOnMatch is false"








! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testCreateClassNameFilter

	| filter filterName transcriptAppender className |

	filterName := 'ClassNameFilter'.

	className := 'Time'.

	transcriptAppender := EsTranscriptAppender level: EsLevel All layout: (EsPatternLayout new: '%m').
	logger addAppender: transcriptAppender.

	filter :=
		transcriptAppender addClassNameFilter: (OrderedCollection with: filterName with: className).

	self assert: (filter name = filterName).
	self assert: (filter classNameToFilter = className).
	self assert: (filter class name = #EsClassNameFilter)






! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testCreateLevelMatchFilter

	| filter transcriptAppender filterName className |

	filterName := 'LevelMatchFilter'.

	transcriptAppender := EsTranscriptAppender level: EsLevel All layout: (EsPatternLayout new: '%m').
	logger addAppender: transcriptAppender.

	filter :=
		transcriptAppender addLevelMatchFilter: (OrderedCollection with: filterName with: 'Info').

	self assert: (filter name = filterName).
	self assert: (filter levelToMatch = EsLevel Info).
	self assert: (filter class name = #EsLevelMatchFilter)






! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testCreateLevelRangeFilter

	| filter filterName transcriptAppender className |

	filterName := 'LevelRangeFilter'.

	transcriptAppender := EsTranscriptAppender level: EsLevel All layout: (EsPatternLayout new: '%m').
	logger addAppender: transcriptAppender.

	filter :=
		transcriptAppender
			addLevelRangeFilter: (OrderedCollection with: filterName with: 'Debug' with: 'Error').

	self assert: (filter name = filterName).
	self assert: (filter lowLevel = EsLevel Debug).
	self assert: (filter highLevel = EsLevel Error).
	self assert: (filter class name = #EsLevelRangeFilter)






! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testCreateStringMatchFilter

	| filter filterName transcriptAppender stringToMatch |

	filterName := 'StringMatchFilter'.
	stringToMatch := 'ello'.

	transcriptAppender := EsTranscriptAppender level: EsLevel All layout: (EsPatternLayout new: '%m').
	logger addAppender: transcriptAppender.

	filter :=
		transcriptAppender addStringMatchFilter:
			(OrderedCollection with: filterName with: stringToMatch with: true with: true).

	self assert: (filter name = filterName).
	self assert: (filter stringToMatch = stringToMatch).
	self assert: (filter acceptOnMatch).
	self assert: (filter ignoreCase).
	self assert: (filter class name = #EsStringMatchFilter)






! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testLevelMatchFilter1

	| filter filterName result transcriptAppender |

	filterName := 'LevelMatchFilter'. "the event level is Info so this should work"

	transcriptAppender := EsTranscriptAppender level: EsLevel All layout: (EsPatternLayout new: '%m').
	logger addAppender: transcriptAppender.

	filter :=
		transcriptAppender addLevelMatchFilter: (OrderedCollection with: filterName with: 'Info').

	result := filter decide: event.
	self assert: (result = EsAbstractFilter Accept)








! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testLevelMatchFilter2

	| filter filterName result transcriptAppender |

	filterName := 'LevelMatchFilter'.

	event level: EsLevel Debug.

	transcriptAppender := EsTranscriptAppender level: EsLevel All layout: (EsPatternLayout new: '%m').
	logger addAppender: transcriptAppender.

	filter :=
		transcriptAppender addLevelMatchFilter: (OrderedCollection with: filterName with: 'Info').

	result := filter decide: event.
	self assert: (result = EsAbstractFilter Deny) " Level Debug ~= Level Info"








! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testLevelMatchFilter3

	| filter filterName result transcriptAppender |

	filterName := 'LevelMatchFilter'.

	event level: EsLevel Debug.

	transcriptAppender := EsTranscriptAppender level: EsLevel All layout: (EsPatternLayout new: '%m').
	logger addAppender: transcriptAppender.

	filter :=
		transcriptAppender
			addLevelMatchFilter: (OrderedCollection with: filterName with: 'Info' with: false).

	result := filter decide: event.
	self assert: (result = EsAbstractFilter Accept) " Level Debug ~= Level Info and acceptOnMatch = false"








! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testLevelRangeFilter1

	| filter filterName result transcriptAppender |

	filterName := 'LevelRangeFilter'.

	transcriptAppender := EsTranscriptAppender level: EsLevel All layout: (EsPatternLayout new: '%m').
	logger addAppender: transcriptAppender.

	filter :=
		transcriptAppender
			addLevelRangeFilter: (OrderedCollection with: filterName with: 'Debug' with: 'Error').

	result := filter decide: event.
	self assert: (result = EsAbstractFilter Accept) "Debug < Info < Error"





! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testLevelRangeFilter2

	| filter filterName transcriptAppender result |

	filterName := 'LevelRangeFilter'.

	event level: EsLevel Fatal.
	transcriptAppender := EsTranscriptAppender level: EsLevel All layout: (EsPatternLayout new: '%m').
	logger addAppender: transcriptAppender.

	filter :=
		transcriptAppender
			addLevelRangeFilter: (OrderedCollection with: filterName with: 'Debug' with: 'Error').

	result := filter decide: event.
	self assert: (result = EsAbstractFilter Deny)





! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testLevelRangeFilter3

	| filter filterName result transcriptAppender |

	filterName := 'LevelRangeFilter'.

	transcriptAppender := EsTranscriptAppender level: EsLevel All layout: (EsPatternLayout new: '%m').
	logger addAppender: transcriptAppender.

	filter :=
		transcriptAppender addLevelRangeFilter:
			(OrderedCollection with: filterName with: 'Debug' with: 'Error' with: false).

	result := filter decide: event.
	self assert: (result = EsAbstractFilter Deny) "Debug < Info < Error and acceptOnMatch = false"





! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testStringMatchFilter1

	| filter filterName stringToMatch result transcriptAppender |

	filterName := 'StringMatchFilter'.
	stringToMatch := 'ello'. "test succeeds if we find this string in the event message ''Hello, World''"

	transcriptAppender := EsTranscriptAppender level: EsLevel All layout: (EsPatternLayout new: '%m').
	logger addAppender: transcriptAppender.

	filter :=
		transcriptAppender addStringMatchFilter:
			(OrderedCollection with: filterName with: stringToMatch with: true with: true).

	result := filter decide: event.
	self assert: (result = EsAbstractFilter Accept)





! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testStringMatchFilter2

	| filter filterName transcriptAppender stringToMatch result |

	filterName := 'StringMatchFilter'.
	stringToMatch := 'ELLO'. "test succeds if we find this string in the event message ''Hello, World'' because we ignore case"

	transcriptAppender := EsTranscriptAppender level: EsLevel All layout: (EsPatternLayout new: '%m').
	logger addAppender: transcriptAppender.

	filter :=
		transcriptAppender addStringMatchFilter:
			(OrderedCollection with: filterName with: stringToMatch with: true with: true).

	result := filter decide: event.
	self assert: (result = EsAbstractFilter Accept)





! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testStringMatchFilter3

	| filter filterName transcriptAppender stringToMatch result |

	filterName := 'StringMatchFilter'.
	stringToMatch := 'Hi Mom'. "test succeds because we do not want to find this string in the event message ''Hello, World''"

	transcriptAppender := EsTranscriptAppender level: EsLevel All layout: (EsPatternLayout new: '%m').
	logger addAppender: transcriptAppender.

	filter :=
		transcriptAppender addStringMatchFilter:
			(OrderedCollection with: filterName with: stringToMatch with: false with: true).

	result := filter decide: event.
	self assert: (result = EsAbstractFilter Accept)





! !

!LoggingFiltersTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testStringMatchFilter4

	| filter filterName transcriptAppender stringToMatch result |

	filterName := 'StringMatchFilter'.
	stringToMatch := 'Hi Mom'. "test succeeds because we do not find this string in the event message ''Hello, World''"

	transcriptAppender := EsTranscriptAppender level: EsLevel All layout: (EsPatternLayout new: '%m').
	logger addAppender: transcriptAppender.

	filter :=
		transcriptAppender addStringMatchFilter:
			(OrderedCollection with: filterName with: stringToMatch with: true with: true).

	result := filter decide: event.
	self assert: (result = EsAbstractFilter Deny)





! !

TestCase subclass: #LoggingFormattingInfoTestCase
	instanceVariableNames: 'logger event'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Tests'!

!LoggingFormattingInfoTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testConstructor

	| formattingInfo |

	formattingInfo := EsFormattingInfo leftAlign: true min: 4 max: 9.

	self assert: (formattingInfo notNil).
	self assert: (formattingInfo min = 4).
	self assert: (formattingInfo max = 9).
	self assert: (formattingInfo leftAlign = true)




! !

!LoggingFormattingInfoTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/1/2012 18:12'!
testGetDefault

	| formattingInfo |

	formattingInfo := EsFormattingInfo Default.

	self assert: (formattingInfo notNil).
	self assert: (formattingInfo min = 0).
	self assert: (formattingInfo max = SmallInteger maxVal	).
	self assert: (formattingInfo leftAlign = false)



! !

!LoggingFormattingInfoTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testPad1

	| string formattingInfo result |

	string := 'foobar'.

	formattingInfo := EsFormattingInfo leftAlign: false min: 9 max: 10.

	result := formattingInfo format: 4 buffer: string.

	self assert: ('foo      bar' = result)

! !

!LoggingFormattingInfoTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testPad2

	| string formattingInfo result |

	string := 'foo'.

	formattingInfo := EsFormattingInfo leftAlign: false min: 5 max: 10.

	result := formattingInfo format: 1 buffer: string.

	self assert: ('  foo' = result)

! !

!LoggingFormattingInfoTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testPad3

	| string formattingInfo result |

	string := 'foobar'.

	formattingInfo := EsFormattingInfo leftAlign: false min: 7 max: 10.

	result := formattingInfo format: 1 buffer: string.

	self assert: (' foobar' = result)

! !

!LoggingFormattingInfoTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testPadLeft

	| string formattingInfo result |

	string := 'abcdef'. "take the field starting at position 3 and pad it to 5 characters"

	formattingInfo := EsFormattingInfo leftAlign: false min: 5 max: 10.

	result := formattingInfo format: 3 buffer: string.

	self assert: ('ab cdef' = result)

! !

!LoggingFormattingInfoTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testPadRight

	| string formattingInfo result |

	string := 'foobar'.

	formattingInfo := EsFormattingInfo leftAlign: true min: 5 max: 10.

	result := formattingInfo format: 4 buffer: string.

	self assert: ('foobar  ' = result)

! !

!LoggingFormattingInfoTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testTruncate

	| string formattingInfo result |

	string := 'abXXefgh'.

	formattingInfo := EsFormattingInfo leftAlign: true min: 1 max: 4.

	result := formattingInfo format: 3 buffer: string. "the string starting at position 3 can be at most 4 characters long"

	self assert: ('abefgh' = result)

! !

!LoggingFormattingInfoTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testTruncate2

	| string formattingInfo result |

	string := 'abcdefg'.

	formattingInfo := EsFormattingInfo leftAlign: true min: 1 max: 3.

	result := formattingInfo format: 1 buffer: string.

	self assert: ('efg' = result)! !

TestCase subclass: #LoggingInMemoryAppenderTestCase
	instanceVariableNames: 'logger event'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Tests'!

!LoggingInMemoryAppenderTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
InMemoryAppenderParams: aPatternConverterString

	"
		1 - name
		2 - logger
		3 - threshold
		4-  layout
		5 - patternConverter"

	| oc |

	oc := (OrderedCollection
		with: 'TestInMemoryAppender'
		with: 'root'
		with: 'Info'
		with: 'EsPatternLayout').
	oc add: aPatternConverterString.
	^oc! !

!LoggingInMemoryAppenderTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
addCr: in

	| string |

	string := WriteStream on: ''.
	string
		nextPutAll: in;
		cr.
	^string contents! !

!LoggingInMemoryAppenderTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
dateToTest12

	"8-28-1989 8:15:07 AM"

	^DateAndTime year: 1989 day: 240 hour: 8 minute: 15 second: 7! !

!LoggingInMemoryAppenderTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/14/2011 9:6'!
dateToTest24

	"7-15-1991 20:05:07 PM"

	^DateAndTime year: 1991 day: 196 hour: 20 minute: 5 second: 7! !

!LoggingInMemoryAppenderTestCase methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/10/2012 10:22'!
printLog4s

	^'printLog4s'! !

!LoggingInMemoryAppenderTestCase methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/1/2012 13:39'!
setUp

	EsLogManager reset.
	EsLogManager level: EsLevel All.
	logger := EsLogManager rootLogger.
	event :=
		EsLoggingEvent
			logger: logger
			locationInfo: thisContext
			level: EsLevel Info
			message: 'Hello, World'
			object: self

! !

!LoggingInMemoryAppenderTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
tearDown

	EsLogManager shutDown! !

!LoggingInMemoryAppenderTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testClassNamePatternConverter

	| result in out level appender |

	level := EsLevel Info.
	in := '%C'.

	appender := EsLogManager inMemoryAppender: (self InMemoryAppenderParams: in).
	self assert: (appender notNil).

	logger log: event.

	self assert: (appender contents = (self addCr: 'LoggingInMemoryAppenderTestCase'))



! !

!LoggingInMemoryAppenderTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/10/2012 10:22'!
testObjectPatternConverter

	| result in out level appender |

	level := EsLevel Info.
	in := '%o'.

	appender := EsLogManager inMemoryAppender: (self InMemoryAppenderParams: in).
	self assert: (appender notNil).

	logger log: event.

	self assert: (appender contents = (self addCr: 'printLog4s'))



! !

!LoggingInMemoryAppenderTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/10/2012 10:13'!
testRelativeTime

	| result in out appender |

	in := '%r'.

	appender := EsLogManager inMemoryAppender: (self InMemoryAppenderParams: in).
	self assert: (appender notNil).

	logger log: event.

	self assert: ((appender contents occurrencesOf: $:) > 2)



! !

!LoggingInMemoryAppenderTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testRelativeTime2

	| result in out appender |

	in := '%r'.

	appender := EsLogManager inMemoryAppender: (self InMemoryAppenderParams: in).
	self assert: (appender notNil).

	logger log: event.

	self assert: ((appender contents occurrencesOf: $:) > 2)



! !

TestCase subclass: #LoggingLayoutTestCase
	instanceVariableNames: 'contentType header footer logger event'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Tests'!

!LoggingLayoutTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
contentType

	^'text/plain'! !

!LoggingLayoutTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
footer

	^nil! !

!LoggingLayoutTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
header

	^nil! !

!LoggingLayoutTestCase methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/1/2012 13:39'!
setUp

	EsLogManager reset.
	EsLogManager level: EsLevel All.
	logger := EsLogManager rootLogger.
	event :=
		EsLoggingEvent
			logger: logger
			locationInfo: thisContext
			level: EsLevel Info
			message: 'Hello, World'
			object: self

! !

!LoggingLayoutTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
tearDown

	EsLogManager shutDown! !

!LoggingLayoutTestCase methodsFor: 'Testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testLineSep

	"dq self assert: (CldtConstants::LineDelimiter = EsAbstractLayout lineSeparator)"

! !

!LoggingLayoutTestCase methodsFor: 'Testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testLineSepLen

"dq	self assert: ((CldtConstants::LineDelimiter) size = EsAbstractLayout lineSeparatorLength)"! !

TestCase subclass: #LoggingLevelTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Tests'!

!LoggingLevelTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/1/2012 18:15'!
testAllInt

	self assert: (SmallInteger minVal = EsLevel All level)! !

!LoggingLevelTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDebugInt

	self assert: (10000 = EsLevel Debug level)



! !

!LoggingLevelTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testErrorInt

	self assert: (40000 = EsLevel Error level)



! !

!LoggingLevelTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testFatalInt

	self assert: (50000 = EsLevel Fatal level)



! !

!LoggingLevelTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testInfoInt

	self assert: (20000 = EsLevel Info level)

! !

!LoggingLevelTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testLevelAll

	self assert: (EsLevel All < EsLevel Debug).
	self assert: (EsLevel All < EsLevel Info).
	self assert: (EsLevel All < EsLevel Warn).
	self assert: (EsLevel All < EsLevel Error).
	self assert: (EsLevel All < EsLevel Fatal).
	self assert: (EsLevel All < EsLevel Off)




! !

!LoggingLevelTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testLevelByName

	self assert: ((EsLevel levelByName: 'Debug') = EsLevel Debug)



! !

!LoggingLevelTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testLevelByValue

	self assert: ((EsLevel levelByValue: 20000) = EsLevel Info)



! !

!LoggingLevelTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testLevelDebug

	self assert: (EsLevel Debug < EsLevel Info).
	self assert: (EsLevel Debug < EsLevel Warn).
	self assert: (EsLevel Debug < EsLevel Error).
	self assert: (EsLevel Debug < EsLevel Fatal).
	self assert: (EsLevel Debug < EsLevel Off)




! !

!LoggingLevelTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testLevelError

	self assert: (EsLevel Error < EsLevel Fatal).
	self assert: (EsLevel Error < EsLevel Off)




! !

!LoggingLevelTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testLevelFatal

	self assert: (EsLevel Fatal < EsLevel Off)




! !

!LoggingLevelTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testLevelInfo

	self assert: (EsLevel Info < EsLevel Warn).
	self assert: (EsLevel Info < EsLevel Error).
	self assert: (EsLevel Info < EsLevel Fatal).
	self assert: (EsLevel Info < EsLevel Off)




! !

!LoggingLevelTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testLevelWarn

	self assert: (EsLevel Warn < EsLevel Error).
	self assert: (EsLevel Warn < EsLevel Fatal).
	self assert: (EsLevel Warn < EsLevel Off)




! !

!LoggingLevelTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/1/2012 18:15'!
testOffInt

	self assert: (SmallInteger maxVal = EsLevel Off level)! !

!LoggingLevelTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testTrace

	self assert: ('TRACE' = EsLevel Trace levelStr).
	self assert: (5000 = EsLevel Trace level).
	self assert: (7 = EsLevel Trace syslogEquivalent)! !

!LoggingLevelTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testTraceInt

	self assert: (5000 = EsLevel traceInt)! !

!LoggingLevelTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testWarnInt

	self assert: (30000 = EsLevel Warn level)


! !

TestCase subclass: #LoggingLogCannedEventsTestCase
	instanceVariableNames: 'logger event'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Tests'!

!LoggingLogCannedEventsTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
InMemoryAppenderParams

	| oc |

	oc := (OrderedCollection
		with: 'TestInMemoryAppender'
		with: 'root'
		with: 'All'
		with: 'EsPatternLayout').
	oc add: '%c %p %m %l %object'. "logger level message location object"
	^oc! !

!LoggingLogCannedEventsTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
addCr: in

	| string |

	string := WriteStream on: ''.
	string
		nextPutAll: in;
		cr.
	^string contents! !

!LoggingLogCannedEventsTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
printLog4s

	^'printLog4s'! !

!LoggingLogCannedEventsTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/21/2011 10:11'!
printStrings: anArray

	| stream |

	stream := WriteStream on: ''.
	anArray do: [:each |
		stream
			nextPutAll: each;
			cr].
	^stream contents! !

!LoggingLogCannedEventsTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
setUp

	EsLogManager reset.
	logger := EsLogManager rootLogger


! !

!LoggingLogCannedEventsTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
tearDown

	EsLogManager shutDown! !

!LoggingLogCannedEventsTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 6/3/2013 18:23'!
testBasic1

	"talk to the roorLogger"

	| result in out msg appender |

	msg := 'Hello, World'.

	EsLogManager singleton level: EsLevel All.

	appender := EsLogManager inMemoryAppender: (self InMemoryAppenderParams).
	self assert: (appender notNil).

	EsLogManager logWarn: msg.
	self assert: (appender contents = (self printStrings: #('root WARN Hello, World  '))).

	appender flush.

	EsLogManager logError: msg.
	self assert: (appender contents = (self printStrings: #('root ERROR Hello, World  '))).

	appender flush.


	EsLogManager logInfo: msg.
	self assert: (appender contents = (self printStrings: #('root INFO Hello, World  '))).

	appender flush.

	EsLogManager logDebug: msg.
	self assert: (appender contents = (self printStrings: #('root DEBUG Hello, World  ')))



! !

!LoggingLogCannedEventsTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testBasic1a

	"talk to a logger named Vast through the LogManager"

	| result in out msg appender aLogger loggerName params |

	msg := 'Hello, World'.
	loggerName := 'Vast'.

	EsLogManager singleton level: EsLevel All.

	aLogger := EsLogManager createLogger: loggerName.
	self assert: (aLogger notNil).

	params := self InMemoryAppenderParams.
	params at: 2 put: loggerName. "add this appender to the logger named Vast"

	appender := EsLogManager inMemoryAppender: params.
	self assert: (appender notNil).

	EsLogManager loggerNamed: loggerName warn: msg.
	self assert: (appender contents = (self printStrings: #('Vast WARN Hello, World  '))).

	appender flush.

	EsLogManager loggerNamed: loggerName error: msg.
	self assert: (appender contents = (self printStrings: #('Vast ERROR Hello, World  '))).

	appender flush.


	EsLogManager loggerNamed: loggerName info: msg.
	self assert: (appender contents = (self printStrings: #('Vast INFO Hello, World  '))).

	appender flush.

	EsLogManager loggerNamed: loggerName debug: msg.
	self assert: (appender contents = (self printStrings: #('Vast DEBUG Hello, World  ')))


! !

!LoggingLogCannedEventsTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 6/3/2013 18:36'!
testBasic1b

	"talk to a logger named Vast directly"

	| result in out msg appender aLogger loggerName params |

	msg := 'Hello, World'.
	loggerName := 'Vast'.

	EsLogManager singleton level: EsLevel All.

	aLogger := EsLogManager createLogger: loggerName.
	self assert: (aLogger notNil).

	params := self InMemoryAppenderParams.
	params at: 2 put: loggerName. "add this appender to the logger named Vast"

	appender := EsLogManager inMemoryAppender: params.
	self assert: (appender notNil).

	aLogger warn: msg.
	self assert: (appender contents = (self printStrings: #('Vast WARN Hello, World  '))).

	appender flush.

	aLogger error: msg.
	self assert: (appender contents = (self printStrings: #('Vast ERROR Hello, World  '))).

	appender flush.

	aLogger info: msg.
	self assert: (appender contents = (self printStrings: #('Vast INFO Hello, World  '))).
	appender flush.

	aLogger debug: msg.
	self assert: (appender contents = (self printStrings: #('Vast DEBUG Hello, World  ')))


! !

!LoggingLogCannedEventsTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 6/3/2013 18:18'!
testBasic2

	"talk to the roorLogger"

	| result in out msg appender |

	msg := 'Hello, World'.

	EsLogManager singleton level: EsLevel All.

	appender := EsLogManager inMemoryAppender: (self InMemoryAppenderParams).
	self assert: (appender notNil).
	appender flush.

	EsLogManager logWarn: msg locationInfo: thisContext.
	self assert: (
		appender contents = (
			self printStrings: #(
				'root WARN Hello, World LoggingLogCannedEventsTestCase>>testBasic2 '))).

	appender flush.

	EsLogManager logError: msg locationInfo: thisContext.
	self assert: (
		appender contents = (
			self printStrings: #(
				'root ERROR Hello, World LoggingLogCannedEventsTestCase>>testBasic2 '))).

	appender flush.

	EsLogManager logInfo: msg locationInfo: thisContext.
	self assert: (
		appender contents = (
			self printStrings: #(
				'root INFO Hello, World LoggingLogCannedEventsTestCase>>testBasic2 '))).

	appender flush.

	EsLogManager logDebug: msg locationInfo: thisContext.
	self assert: (
		appender contents = (
			self printStrings: #(
				'root DEBUG Hello, World LoggingLogCannedEventsTestCase>>testBasic2 ')))


! !

!LoggingLogCannedEventsTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/1/2012 18:19'!
testBasic2a

	"talk to a logger named Vast through the LogManager"

	| result in out msg appender aLogger loggerName params |

	msg := 'Hello, World'.
	loggerName := 'Vast'.

	EsLogManager singleton level: EsLevel All.

	aLogger := EsLogManager createLogger: loggerName.
	self assert: (aLogger notNil).

	params := self InMemoryAppenderParams.
	params at: 2 put: loggerName. "add this appender to the logger named Vast"

	appender := EsLogManager inMemoryAppender: params.
	self assert: (appender notNil).

	EsLogManager loggerNamed: loggerName warn: msg locationInfo: thisContext.
	self assert: (
		appender contents = (
			self printStrings: #(
				'Vast WARN Hello, World LoggingLogCannedEventsTestCase>>testBasic2a '))).

	appender flush.

	EsLogManager loggerNamed: loggerName error: msg locationInfo: thisContext.
	self assert: (
		appender contents = (
			self printStrings: #(
				'Vast ERROR Hello, World LoggingLogCannedEventsTestCase>>testBasic2a '))).

	appender flush.

	EsLogManager loggerNamed: loggerName info: msg locationInfo: thisContext.
	self assert: (
		appender contents = (
			self printStrings: #(
				'Vast INFO Hello, World LoggingLogCannedEventsTestCase>>testBasic2a '))).

	appender flush.

	EsLogManager loggerNamed: loggerName debug: msg locationInfo: thisContext.
	self assert: (
		appender contents = (
			self printStrings: #(
				'Vast DEBUG Hello, World LoggingLogCannedEventsTestCase>>testBasic2a ')))


! !

!LoggingLogCannedEventsTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/1/2012 18:19'!
testBasic2b

	"talk to a logger named Vast directly"

	| result in out msg appender aLogger loggerName params |

	msg := 'Hello, World'.
	loggerName := 'Vast'.

	EsLogManager singleton level: EsLevel All.

	aLogger := EsLogManager createLogger: loggerName.
	self assert: (aLogger notNil).

	params := self InMemoryAppenderParams.
	params at: 2 put: loggerName. "add this appender to the logger named Vast"

	appender := EsLogManager inMemoryAppender: params.
	self assert: (appender notNil).

	aLogger warn: msg locationInfo: thisContext.
	self assert: (
		appender contents = (
			self printStrings: #(
				'Vast WARN Hello, World LoggingLogCannedEventsTestCase>>testBasic2b '))).

	appender flush.

	aLogger error: msg locationInfo: thisContext.
	self assert: (
		appender contents = (
			self printStrings: #(
				'Vast ERROR Hello, World LoggingLogCannedEventsTestCase>>testBasic2b '))).

	appender flush.


	aLogger info: msg locationInfo: thisContext.
	self assert: (
		appender contents = (
			self printStrings: #(
				'Vast INFO Hello, World LoggingLogCannedEventsTestCase>>testBasic2b '))).

	appender flush.

	aLogger debug: msg locationInfo: thisContext.
	self assert: (
		appender contents = (
			self printStrings: #(
				'Vast DEBUG Hello, World LoggingLogCannedEventsTestCase>>testBasic2b ')))

! !

!LoggingLogCannedEventsTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 6/3/2013 18:20'!
testBasic3

	"talk to the roorLogger"

	| result in out msg appender |

	msg := 'Hello, World'.

	EsLogManager singleton level: EsLevel All.

	appender := EsLogManager inMemoryAppender: (self InMemoryAppenderParams).
	self assert: (appender notNil).

	EsLogManager logWarn: msg locationInfo: thisContext object: self.
	self assert: (
		appender contents = (
			self printStrings: #(
				'root WARN Hello, World LoggingLogCannedEventsTestCase>>testBasic3 printLog4s'))).

	appender flush.

	EsLogManager logError: msg locationInfo: thisContext object: self.
	self assert: (
		appender contents = (
			self printStrings: #(
				'root ERROR Hello, World LoggingLogCannedEventsTestCase>>testBasic3 printLog4s'))).

	appender flush.

	EsLogManager logInfo: msg locationInfo: thisContext object: self.
	self assert: (
		appender contents = (
			self printStrings: #(
				'root INFO Hello, World LoggingLogCannedEventsTestCase>>testBasic3 printLog4s'))).

	appender flush.

	EsLogManager logDebug: msg locationInfo: thisContext object: self.
	self assert: (
		appender contents = (
			self printStrings: #(
				'root DEBUG Hello, World LoggingLogCannedEventsTestCase>>testBasic3 printLog4s')))

! !

!LoggingLogCannedEventsTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/1/2012 18:22'!
testBasic3a

	"talk to a logger named Vast through the LogManager"

	| result in out msg appender aLogger loggerName params |

	msg := 'Hello, World'.
	loggerName := 'Vast'.

	EsLogManager singleton level: EsLevel All.

	aLogger := EsLogManager createLogger: loggerName.
	self assert: (aLogger notNil).

	params := self InMemoryAppenderParams.
	params at: 2 put: loggerName. "add this appender to the logger named Vast"

	appender := EsLogManager inMemoryAppender: params.
	self assert: (appender notNil).

	EsLogManager
		loggerNamed: loggerName
		warn: msg
		locationInfo: thisContext
		object: self.
	self assert: (
		appender contents = (
			self printStrings: #(
				'Vast WARN Hello, World LoggingLogCannedEventsTestCase>>testBasic3a printLog4s'))).
	appender flush.

	EsLogManager
		loggerNamed: loggerName
		error: msg
		locationInfo:thisContext
		object: self.
	self assert: (
		appender contents = (
			self printStrings: #(
				'Vast ERROR Hello, World LoggingLogCannedEventsTestCase>>testBasic3a printLog4s'))).
	appender flush.

	EsLogManager
		loggerNamed: loggerName
		info: msg
		locationInfo: thisContext
		object: self.
	self assert: (
		appender contents = (
			self printStrings: #(
				'Vast INFO Hello, World LoggingLogCannedEventsTestCase>>testBasic3a printLog4s'))).
	appender flush.

	EsLogManager
		loggerNamed: loggerName
		debug: msg
		locationInfo:thisContext
		object: self.
	self assert: (
		appender contents = (
			self printStrings: #(
				'Vast DEBUG Hello, World LoggingLogCannedEventsTestCase>>testBasic3a printLog4s')))

! !

!LoggingLogCannedEventsTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/1/2012 18:21'!
testBasic3b

	"talk to a logger named Vast directly"

	| result in out msg appender aLogger loggerName params |

	msg := 'Hello, World'.
	loggerName := 'Vast'.

	EsLogManager singleton level: EsLevel All.

	aLogger := EsLogManager createLogger: loggerName.
	self assert: (aLogger notNil).

	params := self InMemoryAppenderParams.
	params at: 2 put: loggerName. "add this appender to the logger named Vast"

	appender := EsLogManager inMemoryAppender: params.
	self assert: (appender notNil).

	aLogger warn: msg locationInfo: thisContext object: self.
	self assert: (
		appender contents = (
			self printStrings: #(
				'Vast WARN Hello, World LoggingLogCannedEventsTestCase>>testBasic3b printLog4s'))).
	appender flush.

	aLogger error: msg locationInfo: thisContext object: self.
	self assert: (
		appender contents = (
			self printStrings: #(
				'Vast ERROR Hello, World LoggingLogCannedEventsTestCase>>testBasic3b printLog4s'))).
	appender flush.

	aLogger info: msg locationInfo: thisContext object: self.
	self assert: (
		appender contents = (
			self printStrings: #(
				'Vast INFO Hello, World LoggingLogCannedEventsTestCase>>testBasic3b printLog4s'))).
	appender flush.

	aLogger debug: msg locationInfo: thisContext object: self.
	self assert: (
		appender contents = (
			self printStrings: #(
				'Vast DEBUG Hello, World LoggingLogCannedEventsTestCase>>testBasic3b printLog4s')))


! !

!LoggingLogCannedEventsTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 6/3/2013 18:21'!
testBasic4

	"talk to the roorLogger"

	| result in out msg appender |

	msg := 'Hello, World'.

	EsLogManager singleton level: EsLevel All.

	appender := EsLogManager inMemoryAppender: (self InMemoryAppenderParams).
	self assert: (appender notNil).

	EsLogManager logWarn: msg object: self.
	self assert: (appender contents = (self printStrings: #('root WARN Hello, World  printLog4s'))).

	appender flush.

	EsLogManager logError: msg object: self.
	self assert: (appender contents = (self printStrings: #('root ERROR Hello, World  printLog4s'))).

	appender flush.

	EsLogManager logInfo: msg object: self.
	self assert: (appender contents = (self printStrings: #('root INFO Hello, World  printLog4s'))).

	appender flush.

	EsLogManager logDebug: msg object: self.
	self assert: (appender contents = (self printStrings: #('root DEBUG Hello, World  printLog4s')))

! !

!LoggingLogCannedEventsTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testBasic4a

	"talk to a logger named Vast through the LogManager"

	| result in out msg appender aLogger loggerName params |

	msg := 'Hello, World'.
	loggerName := 'Vast'.

	EsLogManager singleton level: EsLevel All.

	aLogger := EsLogManager createLogger: loggerName.
	self assert: (aLogger notNil).

	params := self InMemoryAppenderParams.
	params at: 2 put: loggerName. "add this appender to the logger named Vast"

	appender := EsLogManager inMemoryAppender: params.
	self assert: (appender notNil).

	EsLogManager loggerNamed: loggerName warn: msg object: self.
	self assert: (appender contents = (self printStrings: #('Vast WARN Hello, World  printLog4s'))).
	appender flush.

	EsLogManager loggerNamed: loggerName error: msg object: self.
	self assert: (appender contents = (self printStrings: #('Vast ERROR Hello, World  printLog4s'))).
	appender flush.

	EsLogManager loggerNamed: loggerName info: msg object: self.
	self assert: (appender contents = (self printStrings: #('Vast INFO Hello, World  printLog4s'))).
	appender flush.

	EsLogManager loggerNamed: loggerName debug: msg object: self.
	self assert: (appender contents = (self printStrings: #('Vast DEBUG Hello, World  printLog4s')))

! !

!LoggingLogCannedEventsTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testBasic4b

	"talk to a logger named Vast directly"

	| result in out msg appender aLogger loggerName params |

	msg := 'Hello, World'.
	loggerName := 'Vast'.

	EsLogManager singleton level: EsLevel All.

	aLogger := EsLogManager createLogger: loggerName.
	self assert: (aLogger notNil).

	params := self InMemoryAppenderParams.
	params at: 2 put: loggerName. "add this appender to the logger named Vast"

	appender := EsLogManager inMemoryAppender: params.
	self assert: (appender notNil).

	aLogger warn: msg object: self.
	self assert: (appender contents = (self printStrings: #('Vast WARN Hello, World  printLog4s'))).
	appender flush.

	aLogger error: msg object: self.
	self assert: (appender contents = (self printStrings: #('Vast ERROR Hello, World  printLog4s'))).
	appender flush.

	aLogger info: msg object: self.
	self assert: (appender contents = (self printStrings: #('Vast INFO Hello, World  printLog4s'))).
	appender flush.

	aLogger debug: msg object: self.
	self assert: (appender contents = (self printStrings: #('Vast DEBUG Hello, World  printLog4s')))

! !

TestCase subclass: #LoggingLogManagerTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Tests'!

!LoggingLogManagerTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testCreatedLogger

	| logger |

	logger := EsLogManager createLogger: 'vast'.

	self assert: (logger notNil).
	self assert: (logger name = 'vast').
	self assert: (logger class name = #EsLogger)


! !

!LoggingLogManagerTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDefaultRootLogger

	| logger |

	logger := EsLogManager rootLogger.

	self assert: (logger notNil).
	self assert: (logger name = 'root').
	self assert: (logger class name = #EsLogger)


! !

!LoggingLogManagerTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/11/2012 14:4'!
testShutdown

	"(self new setTestSelector: #testShutdown) debug"

	| manager |

	manager := EsLogManager singleton.
	manager createLogger: 'aLoggerNameString'.
	manager shutDown.

	self assert: manager loggers isEmpty! !

!LoggingLogManagerTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/2/2012 18:48'!
testSingleton

	| singleton |

	singleton := EsLogManager singleton.

	self assert: (singleton notNil).
	self assert: (singleton class name = #EsLogManager).
	self assert: (singleton loggers notNil).
	self assert: (singleton loggers class name = #Dictionary).
	self assert: (singleton level = EsLevel All).

	singleton level: EsLevel Debug.

	self assert: (singleton level = EsLevel Debug).

	EsLogManager reset

! !

!LoggingLogManagerTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/1/2012 18:28'!
testStartTime

	| startTime |

	startTime := EsLogManager startTime.

	self assert: (startTime notNil).
	self assert: (startTime seconds > 0).
	self assert: (startTime class name = #DateAndTime)

! !

TestCase subclass: #LoggingLoggerTestCase
	instanceVariableNames: 'logger event'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Tests'!

!LoggingLoggerTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
InMemoryAppenderParams: aPatternConverterString

	"
		1 - name
		2 - logger
		3 - threshold
		4-  layout
		5 - patternConverter"

	| oc |

	oc := (OrderedCollection
		with: 'TestInMemoryAppender'
		with: 'root'
		with: 'Info'
		with: 'EsPatternLayout').
	oc add: aPatternConverterString.
	^oc! !

!LoggingLoggerTestCase methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/1/2012 13:39'!
setUp

	EsLogManager reset.
	logger := EsLogManager rootLogger.
	event :=
		EsLoggingEvent
			logger: logger
			locationInfo: thisContext
			level: EsLevel Info
			message: 'Hello, World'
			object: self

! !

!LoggingLoggerTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
tearDown

	EsLogManager shutDown! !

!LoggingLoggerTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testAddAppender

	| a1 params |

	params := self InMemoryAppenderParams: '%m%n'.
	params at: 1 put: 'Appender1'.

	a1 := EsLogManager inMemoryAppender: params.
	self assert: (a1 notNil).

	self assert: (logger allAppenders size = 1).
	self assert: (logger allAppenders first == a1).
	self assert: (logger allAppenders first name = 'Appender1')! !

!LoggingLoggerTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testAddAppenderThatAlreadyExists

	| a1 params result |

	params := self InMemoryAppenderParams: '%m%n'.
	params at: 1 put: 'Appender1'.

	a1 := EsLogManager inMemoryAppender: params.
	self assert: (a1 notNil).

	self assert: (logger allAppenders size = 1).
	self assert: (logger allAppenders first == a1).
	self assert: (logger allAppenders first name = 'Appender1').

	result := logger addAppender: a1.

	self assert: (result isNil).
	self assert: (logger allAppenders size = 1).
	self assert: (logger allAppenders first == a1).
	self assert: (logger allAppenders first name = 'Appender1')! !

!LoggingLoggerTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testCloseAppender

	| a1 a2 app params |

	params := self InMemoryAppenderParams: '%m%n'.
	params at: 1 put: 'Appender1'.

	a1 := EsLogManager inMemoryAppender: params.

	params := self InMemoryAppenderParams: '%m%n'.
	params at: 1 put: 'Appender2'.

	a2 := EsLogManager inMemoryAppender: params.


	self assert: (logger allAppenders size = 2).

	app := logger getAppender: 'Appender2'.
	self assert: (app notNil).
	self assert: (app name = 'Appender2').

	app close.
	self assert: (app closed)

! !

!LoggingLoggerTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testGetAppenderByName

	| a1 a2 params app |

	params := self InMemoryAppenderParams: '%m%n'.
	params at: 1 put: 'Appender1'.

	a1 := EsLogManager inMemoryAppender: params.

	params := self InMemoryAppenderParams: '%m%n'.
	params at: 1 put: 'Appender2'.

	a2 := EsLogManager inMemoryAppender: params.

	self assert: (logger allAppenders size = 2).

	app := logger getAppender: 'Appender2'.
	self assert: (app notNil).
	self assert: (app name = 'Appender2')

! !

!LoggingLoggerTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testRemoveAllAppenders

	| a1 params a2 |

	params := self InMemoryAppenderParams: '%m%n'.
	params at: 1 put: 'Appender1'.

	a1 := EsLogManager inMemoryAppender: params.

	params := self InMemoryAppenderParams: '%m%n'.
	params at: 1 put: 'Appender2'.

	a2 := EsLogManager inMemoryAppender: params.

	self assert: (logger allAppenders size = 2).

	logger removeAllAppenders.

	self assert: (logger allAppenders isEmpty)! !

!LoggingLoggerTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testRemoveAppenders

	| a1 params a2 |

	params := self InMemoryAppenderParams: '%m%n'.
	params at: 1 put: 'Appender1'.

	a1 := EsLogManager inMemoryAppender: params.

	params := self InMemoryAppenderParams: '%m%n'.
	params at: 1 put: 'Appender2'.

	a2 := EsLogManager inMemoryAppender: params.

	self assert: (logger allAppenders size = 2).

	logger removeAppender: a1.

	self assert: (logger allAppenders size = 1).
	self assert: (logger allAppenders first == a2).
	self assert: (logger allAppenders first name = 'Appender2').

	logger removeAppender: a2.
	self assert: (logger allAppenders isEmpty)! !

!LoggingLoggerTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testShutdown

	| a1 params a2 |

	params := self InMemoryAppenderParams: '%m%n'.
	params at: 1 put: 'Appender1'.

	a1 := EsLogManager inMemoryAppender: params.

	params := self InMemoryAppenderParams: '%m%n'.
	params at: 1 put: 'Appender2'.

	a2 := EsLogManager inMemoryAppender: params.
	self assert: (logger allAppenders size = 2).

	logger shutDown.

	logger allAppenders do: [:each | self assert: (each closed)]

! !

TestCase subclass: #LoggingPatternLayoutTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Tests'!

!LoggingPatternLayoutTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
createLayout

	^EsPatternLayout new: '[%t] %p %c - %m%n'! !

!LoggingPatternLayoutTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDefaultConversionPattern

	self assert: ('%m%n' = EsPatternLayout defaultConversionPattern)! !

!LoggingPatternLayoutTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testGetPatternFormat

	| layout |

	layout := self createLayout.

	self assert: ('[%t] %p %c - %m%n' = layout pattern)! !

!LoggingPatternLayoutTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/12/2012 15:50'!
testGetPatternLayout

	| logManager |

	logManager := EsLogManager new.

	self assert: (logManager getPatternLayout: nil) isNil.

	self assert: (logManager getPatternLayout: '') = EsPatternLayout.

	self assert: (logManager getPatternLayout: 'BadLayout') isNil

! !

TestCase subclass: #LoggingPatternParserTestCase
	instanceVariableNames: 'logger event'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Tests'!

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
convert: patternString registry: registry loggingEvent: aLoggingEvent

	^EsPatternParser parse: patternString loggingEvent: aLoggingEvent ruleRegistry: registry! !

!LoggingPatternParserTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
dateToTest12

	"8-28-1989 8:15:07 AM"

	^DateAndTime year: 1989 day: 240 hour: 8 minute: 15 second: 7! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/14/2011 11:17'!
dateToTest12Sun

	"8--07-2011 8:15:07 AM"

	^DateAndTime year: 2011 day: 219 hour: 8 minute: 15 second: 7! !

!LoggingPatternParserTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/13/2011 13:21'!
dateToTest12a

	"8--07-1989 8:15:07 AM"

	^DateAndTime year: 1989 day: 219 hour: 8 minute: 15 second: 7! !

!LoggingPatternParserTestCase methodsFor: 'accessing' stamp: 'DonaldMacQueen 6/5/2013 21:21'!
dateToTest24

	"7-15-1991 20:05:07 PM"

	^DateAndTime year: 1991 month: 7 day: 15 hour: 20 minute: 5 second: 7! !

!LoggingPatternParserTestCase methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/1/2012 16:56'!
setUp
	logger := EsLogManager createLogger: 'PatternParserLogger'.
	event := EsLoggingEvent
		logger: logger
		locationInfo: thisContext
		level: EsLevel Info
		message: 'Hello, World'
		object: self! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testAssertFactoriesPatternLayoutRules

	| result in out rules |

	rules := EsPatternParser PatternLayoutRules.

	self assert: (rules size > 0).

	rules values do: [:each | | class |
		class := (Smalltalk at: each ifAbsent: []).
		self assert: (class notNil).
		class notNil ifTrue: [self assert: (class singleton isNil = false)]]







! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testBogus

	| result in out |

	in := '%bogus'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = in)


! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testBogusWord1

	| result string |

	string := '%, foobar'.

	result := self convert: string registry: nil loggingEvent: event.
	self assert: (string = result)


! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testBogusWord2

	| result string |

	string := 'xyz %, foobar'.

	result := self convert: string registry: nil loggingEvent: event.
	self assert: (string = result)


! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testClassNamePatternConverter

	| result in out |

	in := '%C'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = 'LoggingPatternParserTestCase')



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testClassNamePatternConverter2

	| result in out |

	in := '%class'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = 'LoggingPatternParserTestCase')



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateAbsoluteFormat

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{ABSOLUTE}'.
	out := '08:15:07,000'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateDateAndTimeFormat

	"
	dd MMM yyyy HH:mm:ss,SSS' for example, '06 Nov 1994 15:49:37,459'
	"

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{DATE}'.
	out := '28 Aug 1989 08:15:07,000'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)

! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateDateOnly

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{yyyy-MM-dd}'.
	out := '1989-08-28'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 13:21'!
testDateDateOnlyNoLeadingZeroOnDay

	| result in out |

	event timeStamp: self dateToTest12a.

	in := '%d{M-f-yyyy}'.
	out := '8-7-1989'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateDateOnlyNoLeadingZeroOnMonth

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{M-dd-yyyy}'.
	out := '8-28-1989'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 13:45'!
testDateDateOnlySpaceInFrontOfDay

	| result in out |

	event timeStamp: self dateToTest12a.

	in := '%d{M-d-yyyy}'.
	out := '8- 7-1989'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateDateThenTime12AmPm

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{dd MMM yyyy HH:mm:ss a}'.
	out := '28 Aug 1989 08:15:07 am'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)

! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateDateThenTime12NoLeadingZeroOnHour

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{yyyy-MMMM-dd H:mm:ss,SSS}'.
	out := '1989-August-28 8:15:07,000'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateDateThenTime12NoLeadingZeroOnHour2

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{yyyy-MMMM-dd h:mm:ss,SSS}'.
	out := '1989-August-28 8:15:07,000'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/14/2011 9:8'!
testDateDateThenTime24AmPm

	| result in out |

	event timeStamp: self dateToTest24.

	in := '%d{dd MMM yyyy hh:mm:ss a}'.
	out := '15 Jul 1991 08:05:07 pm'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)

! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/14/2011 9:9'!
testDateDateThenTime24AmPm2

	| result in out |

	event timeStamp: self dateToTest24.

	in := '%d{dd MMM yyyy HH:mm:ss a}'. "you would not normally use 24 hour time with am and pm"
	out := '15 Jul 1991 20:05:07 pm'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)

! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/14/2011 9:9'!
testDateDateThenTime24NoLeadingZeroOnHour

	| result in out |

	event timeStamp: self dateToTest24.

	in := '%d{yyyy-MMMM-dd H:mm:ss,SSS}'.
	out := '1991-July-15 20:05:07,000'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/14/2011 9:10'!
testDateDateThenTime24NoLeadingZeroOnHour2

	| result in out |

	event timeStamp: self dateToTest24.

	in := '%d{yyyy-MMMM-dd h:mm:ss,SSS}'.
	out := '1991-July-15 8:05:07,000'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateDateThenTimeHour

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{dd MMM yyyy HH:mm:ss a}'.
	out := '28 Aug 1989 08:15:07 am'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)

! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateDateThenTimeHourAndMinute

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{yyyy-MM-dd-HH-mm}'.
	out := '1989-08-28-08-15'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)

! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateDateThenTimeInParens

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{(dd MMM yyyy HH:mm:ss,SSS)}'.
	out := '(28 Aug 1989 08:15:07,000)'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)

! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateDateThenTimeLongWeekdayNames

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{yyyy_MMM_dd EEEE HH:mm:ss}'.
	out := '1989_Aug_28 Monday 08:15:07'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)

! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateDateThenTimeNoLeadingZeroOnMonth

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{M-dd-yyyy HH:mm:ss}'.
	out := '8-28-1989 08:15:07'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)







! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateDateThenTimeShortWeekdayNames

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{yyyy_MMM_dd EE HH:mm:ss}'.
	out := '1989_Aug_28 Mon 08:15:07'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)

! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateDateThenTimeWithDashes

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{===>yyyy_MMM_dd HH:mm:ss<===}'.
	out := '===>1989_Aug_28 08:15:07<==='.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)

! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateDateThenTimeWithUnderscores

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{yyyy_MMM_dd HH:mm:ss}'.
	out := '1989_Aug_28 08:15:07'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)

! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateDateThenTineTwoDigitYear

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{yy-MMM-dd HH:mm:ss,SSS}'.
	out := '89-Aug-28 08:15:07,000'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 14:30'!
testDateDayOfYear

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{D}'.
	out := '240'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateISO8601Format

	"
	yyyy-MM-dd HH:mm:ss,SSS' for example '1999-11-27 15:49:37,459
	"

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{ISO8601}'.
	out := '1989-08-28 08:15:07,000'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateNoFormat

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d'.
	out := '1989-08-28 08:15:07,000'. "ISO8601 is the default"

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)

! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateNoFormat2

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%date'.
	out := '1989-08-28 08:15:07,000'. "ISO8601 is the default"

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)

! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 20:40'!
testDateSpecifierD

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{D}'.
	out := '240'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 20:51'!
testDateSpecifierE

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{E}'.
	out := 'Mon'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 20:42'!
testDateSpecifierEE

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{EE}'.
	out := 'Mon'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 20:43'!
testDateSpecifierEEE

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{EEE}'.
	out := 'Mon'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 20:52'!
testDateSpecifierEEEE

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{EEEE}'.
	out := 'Monday'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 20:53'!
testDateSpecifierEEEEE

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{EEEEE}'.
	out := 'Monday'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 20:45'!
testDateSpecifierM

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{M}'.
	out := '8'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 20:45'!
testDateSpecifierMM

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{MM}'.
	out := '08'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 20:46'!
testDateSpecifierMMM

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{MMM}'.
	out := 'Aug'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 20:46'!
testDateSpecifierMMMM

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{MMMM}'.
	out := 'August'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 20:46'!
testDateSpecifierMMMMM

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{MMMMM}'.
	out := 'August'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 20:38'!
testDateSpecifierd

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{d}'.
	out := '28'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 20:41'!
testDateSpecifierdd

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{dd}'.
	out := '28'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 20:50'!
testDateSpecifierf

	| result in out |

	event timeStamp: self dateToTest12a.

	in := '%d{f}'.
	out := '7'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/14/2011 11:16'!
testDateSpecifieru

	| result in out |

	event timeStamp: self dateToTest12Sun.

	in := '%d{u}'.
	out := '7'. "Sunday = 7"

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/14/2011 11:16'!
testDateSpecifierw

	| result in out |

	event timeStamp: self dateToTest12Sun.

	in := '%d{w}'.
	out := '0'. "Sunday = 0"

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 20:47'!
testDateSpecifiery

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{y}'.
	out := '89'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 20:47'!
testDateSpecifieryy

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{yy}'.
	out := '89'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 20:47'!
testDateSpecifieryyyy

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{yyyy}'.
	out := '1989'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateSyslogFormat

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{yyyy MMM dd HH:mm:ss}'.
	out := '1989 Aug 28 08:15:07'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)

! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/14/2011 11:36'!
testDateTimeBadFormat

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{QQ}'. "there is no QQ format"

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result isEmpty)

! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateTimeMixedFormats

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{EE HH:mm:ss yyyy_MMM_dd}'. "date specifer EE should not be in front of the time format"

	result := self convert: in registry: nil loggingEvent: event.
	self assert: ((result indexOfSubCollection: 'Error' startingAt: 1 ifAbsent: [0]) > 0)

! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/14/2011 11:29'!
testDateTimeMixedFormats2

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{HH:QQ:ss }'. "there is no QQ format"

	result := self convert: in registry: nil loggingEvent: event.
	self assert: ((result indexOfSubCollection: 'Error' startingAt: 1 ifAbsent: [0]) > 0)

! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateTimeOnly12

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{HH:mm:ss,SSS}'.
	out := '08:15:07,000'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateTimeOnly12NoLeadingZeroOnHour

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{H:mm:ss,SSS}'.
	out := '8:15:07,000'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/14/2011 9:10'!
testDateTimeOnly24

	| result in out |

	event timeStamp: self dateToTest24.

	in := '%d{HH:mm:ss,SSS}'.
	out := '20:05:07,000'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/14/2011 9:10'!
testDateTimeOnly24NoLeadingZeroOnHour

	| result in out |

	event timeStamp: self dateToTest24.

	in := '%d{H:mm:ss,SSS}'.
	out := '20:05:07,000'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateTimeThenDate

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{HH:mm:ss,SSS yyyy-MM-dd}'.
	out := '08:15:07,000 1989-08-28'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateTimeThenDate12

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{HH:mm:ss,SSS yyyy-MM-dd}'.
	out := '08:15:07,000 1989-08-28'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateTimeThenDate12NoLeadingZeroOnHour

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{h:mm:ss,SSS yyyy-MMMM-dd}'.
	out := '8:15:07,000 1989-August-28'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateTimeThenDate24

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{HH:mm:ss,SSS yyyy-MM-dd}'.
	out := '08:15:07,000 1989-08-28'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/14/2011 9:11'!
testDateTimeThenDate24NoLeadingZeroOnHour

	| result in out |

	event timeStamp: self dateToTest24.

	in := '%d{h:mm:ss,SSS yyyy-MMMM-dd}'.
	out := '8:05:07,000 1991-July-15'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateTimeThenDateLongMonthNames

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{HH:mm:ss,SSS yyyy-MMMM-dd}'.
	out := '08:15:07,000 1989-August-28'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateTimeThenDateLongWeekdayNames

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{HH:mm:ss EEEE yyyy_MMM_dd}'.
	out := '08:15:07 Monday 1989_Aug_28'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)

! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateTimeThenDateNoLeadingZeroOnMonth

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{H:mm:ss M-dd-yyyy}'.
	out := '8:15:07 8-28-1989'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)







! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateTimeThenDateShortMonthNames

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{HH:mm:ss,SSS yyyy-MMM-dd}'.
	out := '08:15:07,000 1989-Aug-28'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateTimeThenDateShortWeekdayNames

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{HH:mm:ss EE yyyy_MMM_dd}'.
	out := '08:15:07 Mon 1989_Aug_28'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)

! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateTimeThenDateTime12AmPm

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{h:mm:ss,SSS a yyyy-MMMM-dd}'.
	out := '8:15:07,000 am 1989-August-28'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)

! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/14/2011 9:12'!
testDateTimeThenDateTime24AmPm

	| result in out |

	event timeStamp: self dateToTest24.

	in := '%d{hh:mm:ss a dd MMM yyyy}'.
	out := '08:05:07 pm 15 Jul 1991'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)

! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/14/2011 9:12'!
testDateTimeThenDateTime24AmPm2

	| result in out |

	event timeStamp: self dateToTest24.

	in := '%d{HH:mm:ss a dd MMM yyyy}'. "you would not normally use 24 hour time with am and pm"
	out := '20:05:07 pm 15 Jul 1991'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)

! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDateTimeThenDateTwoDigitYear

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{HH:mm:ss,SSS yy-MMM-dd}'.
	out := '08:15:07,000 89-Aug-28'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testFullLocationPatternConverter

	"Class And MethodName"

	| result in |

	in := '%l'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = 'LoggingPatternParserTestCase>>setUp')



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testHelloWorld

	| result string |

	string := 'mom'.

	result := self convert: string registry: nil loggingEvent: event.
	self assert: (string = result)


! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testLevelPatternConverter


	| result in out |

	in := '%p'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = 'INFO')


! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testLevelPatternConverter2

	| result in out |

	in := '%level'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = 'INFO')


! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testLoggerPatternConverter

	| result in out |

	in := '%c'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = 'PatternParserLogger')



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testLoggerPatternConverter2

	| result in out |

	in := '%logger'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = 'PatternParserLogger')



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testMalformedOption

	| result in out |

	in := 'foo%m{yyyy.MM.dd'.
	out := 'fooHello, World{yyyy.MM.dd'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)


! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testMessagePatternConverter

	| result in out |

	in := '%message'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = 'Hello, World')



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testMessagePatternConverter2

	| result in out |

	in := '%m'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = 'Hello, World')



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testMethodLocationPatternConverter

	| result in out |

	in := '%M'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = 'setUp')



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testMethodLocationPatternConverter2

	| result in out |

	in := '%method'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = 'setUp')



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testModifier

	| result in out |

	in := '%25m'.
	event message: 'LeftPadto25Characters'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = '    LeftPadto25Characters')


! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testModifier2

	| result in out |

	in := '%-25m'.
	event message: 'RightPadto25Characters'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = 'RightPadto25Characters   ')


! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testModifier3

	| result in out |

	event message: 'thisWillBeTruncatedToTheLast9Characters123456789'.

	in := '%.9m'.
	out := '123456789'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)


! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testModifier4

	| result in out |

	event message: 'thisWillBeTruncatedToTheLast9Characters123456789'.

	in := '%7.9m'.
	out := '123456789'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)


! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testModifier5

	| result in out |

	event message: 'this'.

	in := '%7.9m'.
	out := '   this'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)


! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testModifier6

	| result in out |

	event message: 'thisandthat'.

	in := '%-7.9m'.
	out := 'isandthat'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)


! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testMore

	| result in out |

	in := '%more'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = 'Hello, Worldore')


! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/4/2012 07:29'!
testObjectPatternConverter

	| result in out |

	in := '%o'.

	event object: (Interval from: 1 to: 9).

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = '(1 to: 9)')! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/4/2012 07:29'!
testObjectPatternConverter2

	| result in |

	in := '%object'.

	event object: (Interval from: 1 to: 9).

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = '(1 to: 9)')



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testRelativeTime

	| result in expectedRelativeTime |

	in := '%relative'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: ((result occurrencesOf: $:) > 2)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/7/2012 20:54'!
testRelativeTime2

	| result in expectedRelativeTime |

	in := '%r'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: ((result occurrencesOf: $:) > 2)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/2/2012 15:41'!
testThreadPatternConverter

	| result in |

	in := '%thread'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result notNil)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/2/2012 15:42'!
testThreadPatternConverter2

	| result in |

	in := '%t'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result notNil)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 20:59'!
testTimeSpecifierH

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{H}'.
	out := '8'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 20:59'!
testTimeSpecifierHH

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{HH}'.
	out := '08'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 21:4'!
testTimeSpecifierSSS

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{SSS}'.
	out := '000'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 21:6'!
testTimeSpecifiera

	| result in out |

	event timeStamp: self dateToTest12a.

	in := '%d{a}'.
	out := 'am'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 21:6'!
testTimeSpecifierh

	| result in out |

	event timeStamp: self dateToTest12a.

	in := '%d{h}'.
	out := '8'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 21:6'!
testTimeSpecifierhh

	| result in out |

	event timeStamp: self dateToTest12a.

	in := '%d{hh}'.
	out := '08'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 21:3'!
testTimeSpecifiermm

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{mm}'.
	out := '15'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

!LoggingPatternParserTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 8/13/2011 21:3'!
testTimeSpecifierss

	| result in out |

	event timeStamp: self dateToTest12.

	in := '%d{ss}'.
	out := '07'.

	result := self convert: in registry: nil loggingEvent: event.
	self assert: (result = out)



! !

TestCase subclass: #LoggingPriorityTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Tests'!

!LoggingPriorityTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/1/2012 13:37'!
testAllInt

	self assert: (SmallInteger minVal = EsLevel All level)! !

!LoggingPriorityTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testDebugInt

	self assert: (10000 = EsLevel Debug level)



! !

!LoggingPriorityTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testErrorInt

	self assert: (40000 = EsLevel Error level)



! !

!LoggingPriorityTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testFatalInt

	self assert: (50000 = EsLevel Fatal level)



! !

!LoggingPriorityTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testInfoInt

	self assert: (20000 = EsLevel Info level)

! !

!LoggingPriorityTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 8/1/2012 13:37'!
testOffInt

	self assert: (SmallInteger maxVal = EsLevel Off level)! !

!LoggingPriorityTestCase methodsFor: 'testing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
testWarnInt

	self assert: (30000 = EsLevel Warn level)


! !

TestCase subclass: #LoggingRollingFileAppenderTestCase
	instanceVariableNames: 'logger event'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Tests'!

!LoggingRollingFileAppenderTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
dateToTest12

	"8-28-1989 8:15:07 AM"

	^DateAndTime year: 1989 day: 240 hour: 8 minute: 15 second: 7! !

!LoggingRollingFileAppenderTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/14/2011 9:6'!
dateToTest24

	"7-15-1991 20:05:07 PM"

	^DateAndTime year: 1991 day: 196 hour: 20 minute: 5 second: 7! !

!LoggingRollingFileAppenderTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/13/2012 11:31'!
rollingFileAppenderParams: aPatternConverterString

	"1 - name
	2 - loggerName
	3 - fileName
	4 - fileAppend
	5 - level
	6 - layout
	7 - patternConverter
	8 - immediateFlush
	9 - maxFileSize
	10 -  maxBackupIndex  "

	| oc |

	oc := (OrderedCollection
		with: 'TestRollingFileAppender'
		with: 'root'
		with: 'rollLog4s.log'
		with: false).
	oc
		add: 'Info';
		add: 'EsPatternLayout';
		add: aPatternConverterString;
		add: true;
		add: 9000;
		add: 4.
	^oc! !

!LoggingRollingFileAppenderTestCase methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/1/2012 13:39'!
setUp

	EsLogManager reset.
	logger := EsLogManager rootLogger.
	event :=
		EsLoggingEvent
			logger: logger
			locationInfo: thisContext
			level: EsLevel Info
			message: 'This message will be 50 characters long----------'
			object: self

! !

!LoggingRollingFileAppenderTestCase methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/22/2011 11:36'!
tearDown

	EsLogManager shutDown! !

!LoggingRollingFileAppenderTestCase methodsFor: 'testing' stamp: 'DonaldMacQueen 6/5/2013 22:13'!
testWriteMessage1000Times

	"This test will write an ~50 character message 1000 times.
	The maxFileSize of 9000 bytes will limit each file to appoximately 162 messages in each file. 
	The maxBackupIndex of 4 will cause rollLog4s.log and rollLog4s.log1 to be overwritten.
	All of the files should have a size > 9k except for rollLog4s.log2 which should be about 2k"

	| in level appender message fileNames |

	level := EsLevel Info.
	in := '%m'.
	fileNames := #('rollLog4s.log' 'rollLog4s.log1' 'rollLog4s.log2' 'rollLog4s.log3'
	'rollLog4s.log4').

	fileNames do: [:each | each asFileReference ensureDeleted].

	appender := EsLogManager rollingFileAppender: (self rollingFileAppenderParams: in) isAsync: false.
	self assert: (appender notNil).

	message := event message.

	1 to: 1000 do: [:index | | string |
		string := index asString.
		[string size < 4] whileTrue: [string := ' ' , string].
		event message: string , ' ' , message.
		logger log: event].

	fileNames do: [:each |
		self assert: (each asFileReference exists) ].

	self assert: ( 'rollLog4s.log5' asFileReference exists) not. 	"we should not have this file"
	 





! !

Object subclass: #EsAbstractFilter
	instanceVariableNames: 'name acceptOnMatch'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Filters'!

!EsAbstractFilter class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:31'!
Accept

	^1! !

!EsAbstractFilter class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:31'!
Deny

	^-1! !

!EsAbstractFilter class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:31'!
Neutral

	^0! !

!EsAbstractFilter class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 6/23/2011 13:31'!
new

	^self shouldNotImplement! !

!EsAbstractFilter methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:31'!
accept

	^self class Accept! !

!EsAbstractFilter methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:31'!
decide: aLoggingEvent

	^nil! !

!EsAbstractFilter methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:31'!
deny

	^self class Deny! !

!EsAbstractFilter methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:31'!
name

	^name! !

!EsAbstractFilter methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:31'!
neutral

	^self class Neutral! !

!EsAbstractFilter methodsFor: 'printing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
printOn: aStream

	aStream nextPutAll: self class name , ' '! !

EsAbstractFilter subclass: #EsClassNameFilter
	instanceVariableNames: 'classNameToFilter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Filters'!

!EsClassNameFilter class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 7/19/2011 9:4'!
name: aNameString classNameToFilter: aString

	^(self basicNew)
		name: aNameString classNameToFilter: aString;
		yourself! !

!EsClassNameFilter class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 7/19/2011 9:4'!
name: aNameString classNameToFilter: aString acceptOnMatch: aBoolean

	^(self basicNew)
		name: aNameString classNameToFilter: aString acceptOnMatch: aBoolean;
		yourself! !

!EsClassNameFilter methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:32'!
classNameToFilter

	^classNameToFilter! !

!EsClassNameFilter methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 20:28'!
decide: aLoggingEvent

	"comparison is not case sensitive"

	aLoggingEvent className isNil ifTrue: [^self neutral].

	^aLoggingEvent className asLowercase = classNameToFilter asLowercase
		ifTrue: [acceptOnMatch ifTrue: [self accept] ifFalse: [self deny]]
		ifFalse: [acceptOnMatch ifTrue: [self deny] ifFalse: [self accept]]

! !

!EsClassNameFilter methodsFor: 'initialization' stamp: 'LibrarySupervisor 6/23/2011 13:32'!
name: aNameString classNameToFilter: aString

	name := aNameString.
	classNameToFilter := aString.
	acceptOnMatch := true


! !

!EsClassNameFilter methodsFor: 'initialization' stamp: 'LibrarySupervisor 6/23/2011 13:32'!
name: aNameString classNameToFilter: aString acceptOnMatch: aBoolean

	name := aNameString.
	classNameToFilter := aString.
	acceptOnMatch := aBoolean


! !

!EsClassNameFilter methodsFor: 'printing' stamp: 'LibrarySupervisor 6/23/2011 13:32'!
printOn: aStream

	super printOn: aStream.

	aStream
		nextPutAll: classNameToFilter printString;
		cr! !

EsAbstractFilter subclass: #EsLevelMatchFilter
	instanceVariableNames: 'levelToMatch'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Filters'!

!EsLevelMatchFilter class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 7/19/2011 9:4'!
name: aNameString levelToMatch: aLevel

	^(self basicNew)
		name: aNameString levelToMatch: aLevel;
		yourself! !

!EsLevelMatchFilter class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 7/19/2011 9:4'!
name: aNameString levelToMatch: aLevel acceptOnMatch: aBoolean

	^(self basicNew)
		name: aNameString levelToMatch: aLevel acceptOnMatch: aBoolean;
		yourself! !

!EsLevelMatchFilter methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:33'!
decide: aLoggingEvent

	^aLoggingEvent level = levelToMatch
		ifTrue: [acceptOnMatch ifTrue: [self accept] ifFalse: [self deny]]
		ifFalse: [acceptOnMatch ifTrue: [self deny] ifFalse: [self accept]]! !

!EsLevelMatchFilter methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:33'!
levelToMatch

	^levelToMatch! !

!EsLevelMatchFilter methodsFor: 'initialization' stamp: 'LibrarySupervisor 6/23/2011 13:33'!
name: aNameString levelToMatch: aLevel

	name := aNameString.
	levelToMatch := aLevel.
	acceptOnMatch := true! !

!EsLevelMatchFilter methodsFor: 'initialization' stamp: 'LibrarySupervisor 6/23/2011 13:33'!
name: aNameString levelToMatch: aLevel acceptOnMatch: aBoolean

	name := aNameString.
	levelToMatch := aLevel.
	acceptOnMatch := aBoolean! !

!EsLevelMatchFilter methodsFor: 'printing' stamp: 'LibrarySupervisor 6/23/2011 13:33'!
printOn: aStream

	super printOn: aStream.

	aStream
		nextPutAll: levelToMatch printString;
		cr! !

EsAbstractFilter subclass: #EsLevelRangeFilter
	instanceVariableNames: 'lowLevel highLevel'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Filters'!

!EsLevelRangeFilter class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 7/19/2011 9:4'!
name: aNameString lowLevel: level1 highLevel: level2

	^(self basicNew)
		name: aNameString lowLevel: level1 highLevel: level2;
		yourself

! !

!EsLevelRangeFilter class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 7/19/2011 9:5'!
name: aNameString lowLevel: level1 highLevel: level2 acceptOnMatch: aBoolean

	^(self basicNew)
		name: aNameString lowLevel: level1 highLevel: level2 acceptOnMatch: aBoolean;
		yourself

! !

!EsLevelRangeFilter methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:33'!
decide: aLoggingEvent

	^(aLoggingEvent level >= lowLevel and: [aLoggingEvent level <= highLevel])
		ifTrue: [acceptOnMatch ifTrue: [self accept] ifFalse: [self deny]]
		ifFalse: [acceptOnMatch ifTrue: [self deny] ifFalse: [self accept]]! !

!EsLevelRangeFilter methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:33'!
highLevel

	^highLevel! !

!EsLevelRangeFilter methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
lowLevel

	^lowLevel! !

!EsLevelRangeFilter methodsFor: 'initialize' stamp: 'LibrarySupervisor 6/23/2011 13:33'!
name: aNameString lowLevel: level1 highLevel: level2

	name := aNameString.
	acceptOnMatch := true.

	level1 < level2
		ifTrue: [
			lowLevel := level1.
			highLevel := level2]
		ifFalse: [
			lowLevel := level2.
			highLevel := level1]! !

!EsLevelRangeFilter methodsFor: 'initialize' stamp: 'LibrarySupervisor 6/23/2011 13:33'!
name: aNameString lowLevel: level1 highLevel: level2 acceptOnMatch: aBoolean

	name := aNameString.
	acceptOnMatch := aBoolean.

	level1 < level2
		ifTrue: [
			lowLevel := level1.
			highLevel := level2]
		ifFalse: [
			lowLevel := level2.
			highLevel := level1]! !

!EsLevelRangeFilter methodsFor: 'printing' stamp: 'LibrarySupervisor 6/23/2011 13:33'!
printOn: aStream

	super printOn: aStream.

	aStream
		nextPutAll: lowLevel printString , ' -> ' , highLevel printString;
		cr! !

EsAbstractFilter subclass: #EsStringMatchFilter
	instanceVariableNames: 'stringToMatch ignoreCase'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Filters'!

!EsStringMatchFilter class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 7/19/2011 9:5'!
name: aNameString stringToMatch: aString acceptOnMatch: aBoolean ignoreCase: anotherBoolean

	^(self basicNew)
		name: aNameString stringToMatch: aString acceptOnMatch: aBoolean ignoreCase: anotherBoolean;
		yourself! !

!EsStringMatchFilter methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:33'!
acceptOnMatch

	^acceptOnMatch! !

!EsStringMatchFilter methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:33'!
decide: aLoggingEvent

	| message index |

	message := aLoggingEvent message.

	message isNil ifTrue: [^self neutral].

	index :=
		ignoreCase
			ifTrue: [
				message asUppercase
					indexOfSubCollection: stringToMatch asUppercase
					startingAt: 1
					ifAbsent: [0]]
			ifFalse: [message indexOfSubCollection: stringToMatch startingAt: 1 ifAbsent: [0]].

	^index > 0
		ifTrue: [acceptOnMatch ifTrue: [self accept] ifFalse: [self deny]]
		ifFalse: [acceptOnMatch ifTrue: [self deny] ifFalse: [self accept]]






! !

!EsStringMatchFilter methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:33'!
ignoreCase

	^ignoreCase! !

!EsStringMatchFilter methodsFor: 'initialization' stamp: 'LibrarySupervisor 6/23/2011 13:33'!
name: aNameString stringToMatch: aString acceptOnMatch: aBoolean ignoreCase: anotherBoolean

	name := aNameString.
	stringToMatch := aString.
	acceptOnMatch := aBoolean.
	ignoreCase := anotherBoolean! !

!EsStringMatchFilter methodsFor: 'printing' stamp: 'LibrarySupervisor 6/23/2011 13:33'!
printOn: aStream

	super printOn: aStream.

	aStream
		nextPut: $';
		nextPutAll: stringToMatch;
		nextPut: $';
		nextPutAll:
			' ignoreCase=' , ignoreCase printString , ' acceptOnMatch=' , acceptOnMatch printString;
		cr! !

!EsStringMatchFilter methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:33'!
stringToMatch

	^stringToMatch! !

Object subclass: #EsAbstractLayout
	instanceVariableNames: ''
	classVariableNames: 'LineSeparator LineSeparatorLength'
	poolDictionaries: ''
	category: 'Log4s-Layouts'!

!EsAbstractLayout class methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/2/2012 16:26'!
lineSeparator
	LineSeparator isNil
		ifTrue: [ 
			| ls |
			ls := MultiByteFileStream lineEndDefault.
			ls = #cr
				ifTrue: [ LineSeparator := Character cr asString ]
				ifFalse: [ 
					ls = #ls
						ifTrue: [ LineSeparator := Character lf asString ]
						ifFalse: [ LineSeparator := Character cr asString , Character lf asString ] ] ].
	^ LineSeparator! !

!EsAbstractLayout class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:29'!
lineSeparatorLength

	LineSeparatorLength isNil ifTrue: [LineSeparatorLength := self lineSeparator size].
	^LineSeparatorLength! !

!EsAbstractLayout methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:29'!
format: aLoggingEvent

	self subclassResponsibility! !

!EsAbstractLayout methodsFor: 'actions' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
getFooter

	"subClasses should override as necessary"

	^nil! !

!EsAbstractLayout methodsFor: 'actions' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
getHeader

	"subClasses should override as necessary"

	^nil! !

!EsAbstractLayout methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
getStartTime

	^EsLogManager startTime! !

!EsAbstractLayout methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:29'!
lineSeparator

	^self class lineSeparator! !

EsAbstractLayout subclass: #EsPatternLayout
	instanceVariableNames: 'pattern'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Layouts'!

!EsPatternLayout class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:30'!
defaultConversionPattern

	^'%m%n'! !

!EsPatternLayout class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 7/19/2011 9:5'!
new: aPatternString

	^self new
		pattern: aPatternString;
		yourself! !

!EsPatternLayout methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
defaultConversionPattern

	^self class defaultConversionPattern! !

!EsPatternLayout methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:45'!
format: aLoggingEvent

	^EsPatternParser parse: pattern loggingEvent: aLoggingEvent ruleRegistry: nil! !

!EsPatternLayout methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/1/2012 09:48'!
pattern

	pattern isNil
		ifTrue: [
			EsLogLog debug: 'Pattern is nil; using default pattern'.
			pattern := self defaultConversionPattern].
	^pattern! !

!EsPatternLayout methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
pattern: anObject

	pattern := anObject! !

!EsPatternLayout methodsFor: 'printing' stamp: 'LibrarySupervisor 6/23/2011 13:30'!
printOn: aStream

	aStream
		nextPutAll: self class name asString , ' - ' , self pattern;
		cr! !

EsAbstractLayout subclass: #EsSimpleLayout
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Layouts'!

!EsSimpleLayout methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:30'!
format: aLoggingEvent

	| sbuf |

	sbuf := WriteStream on: ''.

	sbuf nextPutAll: aLoggingEvent level printString.
	sbuf nextPutAll: ' - '.
	sbuf nextPutAll: aLoggingEvent message.
	sbuf nextPut: self lineSeparator.
	^sbuf contents

! !

Object subclass: #EsAppender
	instanceVariableNames: 'layout name closed wroteFirstError filters stream level timeZone'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Appenders'!

!EsAppender class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 7/19/2011 9:4'!
name: aString level: aLevel layout: aPatternLayout

	^(self basicNew)
		name: aString level: aLevel layout: aPatternLayout;
		yourself! !

!EsAppender class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 6/23/2011 13:38'!
new

	^self shouldNotImplement! !

!EsAppender methodsFor: 'testing' stamp: 'LibrarySupervisor 6/23/2011 13:38'!
addClassNameFilter: anArray

	"for sunit testing only. use 'LogManager classNameFilter: anArray' instead"

	| filterName className classNameFilter |

	filterName := (anArray at: 1).
	className := (anArray at: 2).

	classNameFilter := (anArray size = 3
		ifTrue: [
			EsClassNameFilter
				name: filterName
				classNameToFilter: className
				acceptOnMatch: (anArray at: 3)]
		ifFalse: [EsClassNameFilter name: filterName classNameToFilter: className]).

	self addFilter: classNameFilter.

	^classNameFilter! !

!EsAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:38'!
addFilter: newFilter

	filters addLast: newFilter

! !

!EsAppender methodsFor: 'testing' stamp: 'LibrarySupervisor 7/19/2011 15:41'!
addLevelMatchFilter: anArray

	"for sunit testing only. use 'LogManager levelMatchFilter: anArray' instead"

	| filterName error levelMatchFilter |

	error := false.

	(filterName := self getName: (anArray at: 1)) isNil ifTrue: [error := true].
	(level := self getLevel: (anArray at: 2)) isNil ifTrue: [error := true].

	error ifTrue: [^nil].

	levelMatchFilter := (anArray size = 3
		ifTrue: [
			EsLevelMatchFilter name: filterName levelToMatch: level acceptOnMatch: (anArray at: 3)]
		ifFalse: [EsLevelMatchFilter name: filterName levelToMatch: level]).

	self addFilter: levelMatchFilter.

	^levelMatchFilter! !

!EsAppender methodsFor: 'testing' stamp: 'LibrarySupervisor 7/19/2011 15:40'!
addLevelRangeFilter: anArray

	"for sunit testing only. use 'LogManager levelRangeFilter: anArray' instead"

	| filterName lowLevel highLevel levelRangeFilter error |

	error := false.

	(filterName := self getName: (anArray at: 1)) isNil ifTrue: [error := true].
	(lowLevel := self getLevel: (anArray at: 2)) isNil ifTrue: [error := true].
	(highLevel := self getLevel: (anArray at: 3)) isNil ifTrue: [error := true].

	error ifTrue: [^nil].

	levelRangeFilter := (anArray size = 4
		ifTrue: [
			EsLevelRangeFilter
				name: filterName
				lowLevel: lowLevel
				highLevel: highLevel
				acceptOnMatch: (anArray at: 4)]
		ifFalse: [EsLevelRangeFilter name: filterName lowLevel: lowLevel highLevel: highLevel]).

	self addFilter: levelRangeFilter.

	^levelRangeFilter! !

!EsAppender methodsFor: 'testing' stamp: 'LibrarySupervisor 6/23/2011 13:38'!
addStringMatchFilter: anArray

	"for sunit testing only. use 'LogManager stringMatchFilter: anArray' instead"

	| filterName stringToMatch acceptOnMatch ignoreCase stringMatchFilter |

	filterName := (anArray at: 1).
	stringToMatch := (anArray at: 2).
	acceptOnMatch := (anArray at: 3).
	ignoreCase := (anArray at: 4).

	stringMatchFilter :=
		EsStringMatchFilter
			name: filterName
			stringToMatch: stringToMatch
			acceptOnMatch: acceptOnMatch
			ignoreCase: ignoreCase.

	self addFilter: stringMatchFilter.

	^stringMatchFilter! !

!EsAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:38'!
append: aLoggingEvent

	self subclassResponsibility

! !

!EsAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
clearFilters

	filters := OrderedCollection new! !

!EsAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 22:27'!
clearLevels

	level := EsLevel All! !

!EsAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:38'!
close

	closed := true

! !

!EsAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:38'!
closed

	closed isNil ifTrue: [closed := false].
	^closed! !

!EsAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
closed: anObject

	closed := anObject! !

!EsAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
contents

	^stream contents! !

!EsAppender methodsFor: 'actions' stamp: 'DonaldMacQueen 6/29/2013 17:36'!
doAppend: aLoggingEvent

	closed ifTrue: [^self logError: ( 'Attempted to append to a closed appender named {1}' format:  name)]. 
	(aLoggingEvent level >= level) ifFalse: [^self].

	(self requiresLayout and: [layout isNil]) ifTrue: [^self logError: ( 'Appender named { 1} requires a PatternLayout. None found' format: name)].  

	(self filtersAllow: aLoggingEvent)
		ifTrue: [
			aLoggingEvent fixMessage.
			timeZone notNil ifTrue: [aLoggingEvent fixTimeStamp: timeZone].
			self append: aLoggingEvent]

! !

!EsAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:38'!
filters

	^filters! !

!EsAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
filters: anObject

	filters := anObject! !

!EsAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:38'!
filtersAllow: aLoggingEvent

	filters do: [:each | | decision |
		decision := each decide: aLoggingEvent.
		decision = EsAbstractFilter Deny ifTrue: [^false]].

	^true

! !

!EsAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
getLevel: aString

	^EsLogManager getLevel: aString! !

!EsAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
getName: aString

	^(aString isString and: [aString notEmpty]) ifTrue: [aString] ifFalse: [nil]

! !

!EsAppender methodsFor: 'initialize' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
initialize

	closed := false.
	wroteFirstError := false.
	filters := OrderedCollection new! !

!EsAppender methodsFor: 'testing' stamp: 'LibrarySupervisor 7/18/2012 12:21'!
isAsyncAppender

	^false! !

!EsAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
layout

	^layout! !

!EsAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
layout: aLayout

	layout := aLayout! !

!EsAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
level

	^level! !

!EsAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
level: aPriority

	level := aPriority! !

!EsAppender methodsFor: 'errors' stamp: 'DonaldMacQueen 6/6/2013 16:10'!
logError: aString

	"write just the first error this appender has"

	wroteFirstError
		ifFalse: [
			Transcript
				nextPutAll: 'log4s:ERROR ' , aString;
				cr.
			wroteFirstError := true]! !

!EsAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
name

	^name! !

!EsAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
name: anObject

	name := anObject! !

!EsAppender methodsFor: 'initialize' stamp: 'LibrarySupervisor 6/23/2011 13:38'!
name: aString level: aLevel layout: aPatternLayout

	name := aString.
	level := aLevel.
	layout := aPatternLayout.

	self initialize! !

!EsAppender methodsFor: 'printing' stamp: 'DonaldMacQueen 8/1/2012 10:03'!
printFiltersOn: aStream

	filters isEmpty
		ifTrue: [aStream nextPutAll: 'no loggers']  
		ifFalse: [
			filters do: [:each |
				aStream
					nextPutAll: ' ' , each printString;
					cr]]! !

!EsAppender methodsFor: 'printing' stamp: 'LibrarySupervisor 7/22/2011 8:11'!
printOn: aStream

	aStream
		nextPutAll: name , ' ' , level printString;
		cr.
	self printFiltersOn: aStream! !

!EsAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
removeFilter: aNameString

	filters := filters reject: [:each | each name = aNameString]! !

!EsAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:38'!
requiresLayout

	^true! !

!EsAppender methodsFor: 'initialize' stamp: 'DonaldMacQueen 6/7/2013 17:21'!
setTimeZone:  aTimeZone
	timeZone :=  aTimeZone! !

!EsAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 7/6/2011 22:58'!
shutDown

	self close! !

!EsAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:38'!
stream

	^stream! !

!EsAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:38'!
stream: anObject

	stream := anObject! !

!EsAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2012 14:39'!
timeZone

	^timeZone! !

!EsAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2012 14:39'!
timeZone: anObject

	timeZone := anObject! !

EsAppender subclass: #EsAsyncAppender
	instanceVariableNames: 'appenders backgroundTask loggingEventQueue semaphore'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Appenders'!

!EsAsyncAppender class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 9/15/2011 16:38'!
name: aString  

	^(self basicNew)
		name: aString;
		yourself! !

!EsAsyncAppender methodsFor: 'appenders' stamp: 'LibrarySupervisor 9/15/2011 14:57'!
addAppender: anAppender

	(appenders at: anAppender name ifAbsent: []) isNil
		ifTrue: [
			appenders at: anAppender name put: anAppender.
			^anAppender]
		ifFalse: [^nil]! !

!EsAsyncAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 9/15/2011 14:32'!
appenders
	^appenders! !

!EsAsyncAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 9/15/2011 14:32'!
appenders: anObject
	appenders := anObject! !

!EsAsyncAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 9/15/2011 14:32'!
backgroundTask
	^backgroundTask! !

!EsAsyncAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 9/15/2011 14:32'!
backgroundTask: anObject
	backgroundTask := anObject! !

!EsAsyncAppender methodsFor: 'initialize' stamp: 'DonaldMacQueen 6/3/2013 19:05'!
backgroundTaskDefinition

	^[| nextLoggingEvent |

		[true] whileTrue: [
			semaphore wait.
			nextLoggingEvent := loggingEventQueue notEmpty ifTrue: [loggingEventQueue first] ifFalse: [nil].
			nextLoggingEvent notNil
				ifTrue: [
					appenders do: [:each | each closed ifFalse: [each append: nextLoggingEvent]]]]]


! !

!EsAsyncAppender methodsFor: 'initialize' stamp: 'LibrarySupervisor 4/27/2013 12:44'!
createBackgroundTask

	self backgroundTask isNil
		ifTrue: [
			semaphore := Semaphore new.
			self backgroundTask: (
				self backgroundTaskDefinition
					forkAt: Processor systemBackgroundPriority
					named: self name , '-BackgroundTask')]! !

!EsAsyncAppender methodsFor: 'actions' stamp: 'DonaldMacQueen 6/29/2013 17:37'!
doAppend: aLoggingEvent

	closed ifTrue: [^self logError: ( 'Attempted to append to a closed appender named {1}' format:  name)]. 

	aLoggingEvent fixMessage.
	timeZone notNil ifTrue: [aLoggingEvent fixTimeStamp: timeZone].
	loggingEventQueue addLast: aLoggingEvent.
	semaphore signal! !

!EsAsyncAppender methodsFor: 'appenders' stamp: 'LibrarySupervisor 9/15/2011 14:59'!
getAppender: aString

	^appenders at: aString ifAbsent: []! !

!EsAsyncAppender methodsFor: 'testing' stamp: 'LibrarySupervisor 7/18/2012 12:22'!
isAsyncAppender

	^true! !

!EsAsyncAppender methodsFor: 'initialize' stamp: 'DonaldMacQueen 6/3/2013 19:04'!
name: aString

	name := aString.
	closed := false.
	wroteFirstError := false.
	appenders := Dictionary new.
	loggingEventQueue := OrderedCollection new.

	self createBackgroundTask! !

!EsAsyncAppender methodsFor: 'printing' stamp: 'LibrarySupervisor 10/17/2011 12:26'!
printOn: aStream

	aStream
		nextPutAll: name;
		cr! !

!EsAsyncAppender methodsFor: 'appenders' stamp: 'LibrarySupervisor 9/15/2011 14:59'!
removeAllAppenders

	appenders do: [:each | each shutDown].
	appenders := Dictionary new! !

!EsAsyncAppender methodsFor: 'appenders' stamp: 'LibrarySupervisor 9/15/2011 14:59'!
removeAppender: anAppender

	appenders at: anAppender name ifPresent: [:appender | appender shutDown].

	^appenders removeKey: anAppender name ifAbsent: []! !

!EsAsyncAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 9/14/2011 11:5'!
requiresLayout

	^false! !

!EsAsyncAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 9/15/2011 17:9'!
shutDown

	self
		close;
		stopBackgroundTask! !

!EsAsyncAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 4/27/2013 12:47'!
stopBackgroundTask

	self backgroundTask isNil
		ifFalse: [
			appenders do: [:each | each shutDown].
			self backgroundTask terminate.
			self backgroundTask: nil.
			semaphore := nil]! !

EsAppender subclass: #EsInMemoryAppender
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Appenders'!

!EsInMemoryAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:39'!
append: aLoggingEvent

	| string |

	string := layout format: aLoggingEvent.
	stream
		nextPutAll: string;
		cr! !

!EsInMemoryAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:39'!
flush

	stream reset! !

!EsInMemoryAppender methodsFor: 'initialize' stamp: 'LibrarySupervisor 6/23/2011 13:39'!
name: aString level: aLevel layout: aPatternLayout

	super name: aString level: aLevel layout: aPatternLayout.

	stream := WriteStream on: ''! !

EsInMemoryAppender subclass: #EsTranscriptAppender
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Appenders'!

!EsTranscriptAppender class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 7/19/2011 9:5'!
level: aLevel layout: aPatternLayout

	^(self basicNew)
		level: aLevel layout: aPatternLayout;
		yourself! !

!EsTranscriptAppender methodsFor: 'actions' stamp: 'DonaldMacQueen 8/7/2012 15:30'!
append: aLoggingEvent

	| string |

	string := layout format: aLoggingEvent.
	self stream
		nextPutAll: string;
		cr.
		self flushTranscript! !

!EsTranscriptAppender methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/7/2012 17:39'!
contents

	 ^self stream  contents

! !

!EsTranscriptAppender methodsFor: 'actions' stamp: 'DonaldMacQueen 8/7/2012 15:29'!
flush

	"no-op dq"

! !

!EsTranscriptAppender methodsFor: 'actions' stamp: 'DonaldMacQueen 8/2/2012 20:48'!
flushTranscript

	self stream flush! !

!EsTranscriptAppender methodsFor: 'initialize' stamp: 'LibrarySupervisor 7/18/2012 14:40'!
level: aLevel layout: aPatternLayout

	name := 'Transcript'.
	level := aLevel.
	layout := aPatternLayout.
	self initialize! !

!EsTranscriptAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:42'!
name

	^'Transcript'! !

!EsTranscriptAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:42'!
name: aString

	"cannot rename the Transcript"

	name := 'Transcript'! !

!EsTranscriptAppender methodsFor: 'initialize' stamp: 'DonaldMacQueen 8/5/2012 21:18'!
stream

	stream isNil ifTrue: [stream := Transcript].
	^stream! !

EsAppender subclass: #EsSocketAppender
	instanceVariableNames: 'address remoteHost port socket retryCount retrySeconds retriedCount'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-SocketSupport'!

!EsSocketAppender class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 10/6/2011 10:42'!
name: aString
	layout: aPatternLayout
	level: aLevel
	address: anIpAddress
	port: anInteger
	retryCount: integer2
	retrySeconds: integer3

	^(self basicNew)
		name: aString
			layout: aPatternLayout
			level: aLevel
			address: anIpAddress
			port: anInteger
			retryCount: integer2
			retrySeconds: integer3;
		yourself

! !

!EsSocketAppender class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 10/6/2011 10:41'!
name: aString
	layout: aPatternLayout
	level: aLevel
	host: aHostNameString
	port: anInteger
	retryCount: integer2
	retrySeconds: integer3

	^(self basicNew)
		name: aString
			layout: aPatternLayout
			level: aLevel
			host: aHostNameString
			port: anInteger
			retryCount: integer2
			retrySeconds: integer3;
		yourself


! !

!EsSocketAppender methodsFor: 'actions' stamp: 'DonaldMacQueen 8/11/2012 19:04'!
append: aLoggingEvent

	| string |

	string := layout format: aLoggingEvent.
	
	stream nextPutAllFlush: string; crlf
	 

	



! !

!EsSocketAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 7/7/2011 14:32'!
close

	socket close! !

!EsSocketAppender methodsFor: 'initialize' stamp: 'DonaldMacQueen 6/7/2013 09:35'!
connect

	socket := Socket new.  
	(socket connectToNoSignal: address port: port waitForConnectionFor: Socket standardTimeout) isNil
		ifTrue: [ ^ self warnAndRetry: 'failed to connect in ', Socket standardTimeout printString, ' seconds' ].
	stream := SocketStream on: socket.
	closed := false.
	^ self
! !

!EsSocketAppender methodsFor: 'initialize' stamp: 'LibrarySupervisor 10/18/2011 10:38'!
initialize

	closed := true.
	wroteFirstError := false.
	filters := OrderedCollection new! !

!EsSocketAppender methodsFor: 'testing' stamp: 'LibrarySupervisor 10/18/2011 10:31'!
isClosed

	^socket isClosed! !

!EsSocketAppender methodsFor: 'initialize' stamp: 'DonaldMacQueen 8/11/2012 11:04'!
name: aString
	layout: aPatternLayout
	level: aLevel
	address: anIpAddress
	port: anInteger
	retryCount: integer2
	retrySeconds: integer3

	self initialize.
	name := aString.
	level := aLevel.
	layout := aPatternLayout.
	(address := NetNameResolver addressFromString: anIpAddress) isNil ifTrue: [^nil].
	port := anInteger.
	retriedCount := 0.
	retryCount := integer2.
	retrySeconds := integer3.

	self connect 


! !

!EsSocketAppender methodsFor: 'initialize' stamp: 'DonaldMacQueen 8/11/2012 11:06'!
name: aString
	layout: aPatternLayout
	level: aLevel
	host: aHostNameString
	port: anInteger
	retryCount: integer2
	retrySeconds: integer3

	self initialize.
	name := aString.
	level := aLevel.
	layout := aPatternLayout.
	(address := NetNameResolver addressForName: aHostNameString) isNil ifTrue: [^nil].
	port := anInteger.
	retriedCount := 0.
	retryCount := integer2.
	retrySeconds := integer3.

	self connect 



! !

!EsSocketAppender methodsFor: 'readMe' stamp: 'DonaldMacQueen 8/12/2012 11:41'!
readMe

	"you can test SocketAppender by creating a listener and a SocketAppender in a separate Smalltalk images. 
	Execute the code below in a workspace in one image to start the listener.
	Then execute 'LogManager runForever: LogManagergoodRootLoggerIniFileWithSockettAppender' in a separate image.
	
	| connectionSocket interactionSocket interactionStream dt done |
				
	connectionSocket := Socket newTCP.
	[ 
	connectionSocket listenOn: 4433 backlogSize: 10.
	interactionSocket := connectionSocket waitForAcceptFor: 30.
	interactionStream := SocketStream on: interactionSocket.
	dt := DateAndTime now.
	done := false.
	interactionStream isConnected
		ifTrue: [ 
			[ done ]
				whileFalse: [ 
					Transcript
						cr;
						show: interactionStream nextLine.
					done := (DateAndTime now - dt) seconds > 120 ] ] ]
		ensure: [ 
			connectionSocket closeAndDestroy.
			interactionStream ifNotNil: [ interactionStream close ] ]
"

! !

!EsSocketAppender methodsFor: 'initialize' stamp: 'DonaldMacQueen 8/27/2012 18:44'!
warnAndRetry: connection

	self logError: connection printString.

	Transcript
		nextPutAll: connection printString;
		cr.

	(retryCount > 0 and: [retriedCount < retryCount]) ifFalse: [^nil].

	[
		(Delay forSeconds: retrySeconds) wait.
		self connect]
			forkAt: Processor userBackgroundPriority.

	retriedCount := retriedCount + 1.

	Transcript
		nextPutAll:
			(' retried ' , retriedCount printString , ' of ' , retryCount printString , ' times');
		cr.

	^nil

! !

EsAppender subclass: #EsWriterAppender
	instanceVariableNames: 'immediateFlush'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Appenders'!

EsWriterAppender subclass: #EsConsoleAppender
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Appenders'!

!EsConsoleAppender class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 7/19/2011 9:4'!
level: aLevel layout: aPatternLayout

	^(self basicNew)
		level: aLevel layout: aPatternLayout;
		yourself! !

!EsConsoleAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 7/5/2011 15:42'!
append: aLoggingEvent

	| string |

	string := layout format: aLoggingEvent.
	stream
		nextPutAll: string;
		cr! !

!EsConsoleAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 7/5/2011 15:45'!
close

	self stream flush.
	closed := true! !

!EsConsoleAppender methodsFor: 'initialization' stamp: 'DonaldMacQueen 8/27/2012 18:45'!
level: aLevel layout: aPatternLayout

	name := 'Console'.
	level := aLevel.
	layout := aPatternLayout.
	stream := Transcript.

	self initialize! !

EsWriterAppender subclass: #EsFileAppender
	instanceVariableNames: 'fileAppend fileName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-FileSupport'!

EsFileAppender subclass: #EsDailyRollingFileAppender
	instanceVariableNames: 'datePattern scheduledRollover'
	classVariableNames: 'DatePatterns'
	poolDictionaries: ''
	category: 'Log4s-FileSupport'!

!EsDailyRollingFileAppender class methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/1/2011 9:0'!
datePatterns

	DatePatterns isNil ifTrue: [self initializeDatePatterns].

	^DatePatterns! !

!EsDailyRollingFileAppender class methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/1/2012 11:41'!
initializeDatePatterns

	"self initializeDatePatterns"

	DatePatterns := Dictionary new.

	DatePatterns at: 'topofmonth' put: 'yyyy-MM'.
	DatePatterns at: 'topofweek' put: 'yyyy-E'.
	DatePatterns at: 'topofday' put: 'yyyy-MM-dd'.
	DatePatterns at: 'halfday' put: 'yyyy-MM-dd-a'.
	DatePatterns at: 'topofhour' put: 'yyyy-MM-dd-HH'.
	DatePatterns at: 'topofminute' put: 'yyyy-MM-dd-HH-mm'! !

!EsDailyRollingFileAppender class methodsFor: 'instance creation' stamp: 'DonaldMacQueen 8/13/2012 22:03'!
name: appenderName
	layout: aPatternLayout
	threshold: aLevel
	fileName: aFileNameString
	fileAppend: aBoolean
	immediateFlush: anotherBoolean
	datePattern: aString

	^(self basicNew)
		name: appenderName
			layout: aPatternLayout
			threshold: aLevel
			fileName: aFileNameString
			fileAppend: aBoolean
			immediateFlush: anotherBoolean
			datePattern: aString! !

!EsDailyRollingFileAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 7/1/2011 9:0'!
append: aLoggingEvent

	aLoggingEvent timeStamp > scheduledRollover ifTrue: [self rollover].

	super append: aLoggingEvent! !

!EsDailyRollingFileAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 7/19/2011 8:47'!
createNewFileName

	"create a fakeLoggingEvent with the DateAndTime of the rollover and make the DatePatternConverter turn it into a fileName"

	| fakeLoggingEvent options datePatternConverter dateTimePattern |

	dateTimePattern := self class datePatterns at: datePattern asLowercase.
	fakeLoggingEvent :=
		(EsLoggingEvent new)
			timeStamp: scheduledRollover;
			yourself.

	options := dateTimePattern.

	datePatternConverter :=
		(EsDatePatternConverter new)
			options: options;
			yourself.

	^fileName , '.' , (datePatternConverter format: fakeLoggingEvent buffer: '')! !

!EsDailyRollingFileAppender methodsFor: 'initialize' stamp: 'LibrarySupervisor 7/1/2011 9:0'!
createStream: aString

	super createStream: aString.

	self
		writeHeader;
		determineScheduledRollover.

	closed := false! !

!EsDailyRollingFileAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 8/9/2011 8:52'!
determineScheduledRollover

	| now lcDatePattern |

	now := DateAndTime now.
	lcDatePattern := datePattern asLowercase.

	scheduledRollover := (lcDatePattern = 'topofminute'
		ifTrue: [self scheduleNextTopOfMinute: now]
		ifFalse: [
			lcDatePattern = 'topofhour'
				ifTrue: [self scheduleNextTopOfHour: now]
				ifFalse: [
					lcDatePattern = 'halfday'
						ifTrue: [self scheduleNextHalfDay: now]
						ifFalse: [
							lcDatePattern = 'topofday'
								ifTrue: [self scheduleNextTopOfDay: now]
								ifFalse: [
									lcDatePattern = 'topofweek'
										ifTrue: [self scheduleNextTopOfWeek: now]
										ifFalse: [
											lcDatePattern = 'topofmonth'
												ifTrue: [self scheduleNextTopOfMonth: now]
												ifFalse: [
													^self logError:
														datePattern , ' is an invalid date pattern']]]]]])




! !

!EsDailyRollingFileAppender methodsFor: 'initialize' stamp: 'LibrarySupervisor 7/19/2011 8:45'!
name: appenderName
	layout: aPatternLayout
	threshold: aLevel
	fileName: aFileNameString
	fileAppend: aBoolean
	immediateFlush: anotherBoolean
	datePattern: aString

	self initialize.

	name := appenderName.
	level := aLevel.
	layout := aPatternLayout.
	fileAppend := aBoolean.
	fileName := aFileNameString.
	immediateFlush := anotherBoolean.
	datePattern := aString.

	self createStream: fileName! !

!EsDailyRollingFileAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 12/29/2011 17:16'!
rollover

	self close.

	self createStream: self createNewFileName.


! !

!EsDailyRollingFileAppender methodsFor: 'scheduling' stamp: 'DonaldMacQueen 8/5/2012 13:44'!
scheduleNextHalfDay: now

	| secondsToAdd hoursToAdd |

	hoursToAdd := 11 - now hour12.
	hoursToAdd = -1 ifTrue: [hoursToAdd := 11].

	secondsToAdd := hoursToAdd * 3600.  
	secondsToAdd := secondsToAdd + (59 - now minute * 60).  
	secondsToAdd := secondsToAdd + (60 - now second ).

	^now + (Duration seconds: secondsToAdd).! !

!EsDailyRollingFileAppender methodsFor: 'scheduling' stamp: 'DonaldMacQueen 8/5/2012 13:45'!
scheduleNextTopOfDay: now

	| secondsToAdd |

	secondsToAdd := (23 - now hour) * 3600.  
	secondsToAdd := secondsToAdd + (59 - now minute * 60).  
	secondsToAdd := secondsToAdd + (60 - now second  ).

	^now + (Duration seconds: secondsToAdd).

! !

!EsDailyRollingFileAppender methodsFor: 'scheduling' stamp: 'DonaldMacQueen 8/5/2012 13:45'!
scheduleNextTopOfHour: now

	| secondsToAdd |

	secondsToAdd := (59 - now minute) * 60. 

	^now + (Duration seconds: secondsToAdd ).

! !

!EsDailyRollingFileAppender methodsFor: 'scheduling' stamp: 'DonaldMacQueen 8/5/2012 13:45'!
scheduleNextTopOfMinute: now

	^now + (Duration seconds: 60 - now second).




! !

!EsDailyRollingFileAppender methodsFor: 'scheduling' stamp: 'LibrarySupervisor 7/1/2011 9:0'!
scheduleNextTopOfMonth: now

	| nextMonth year |

	year := now year.
	nextMonth := now month + 1.
	nextMonth > 12
		ifTrue: [
			nextMonth := 1.
			year := now year + 1].

	^DateAndTime year: year month: nextMonth day: 1 hour: 0 minute: 0 second: 1



! !

!EsDailyRollingFileAppender methodsFor: 'scheduling' stamp: 'DonaldMacQueen 8/5/2012 13:37'!
scheduleNextTopOfWeek: now

	| daysUntilNextWeek secondsToAdd secondsPerDay duration |

	secondsPerDay := 86400. "24 * 3600"

	daysUntilNextWeek := 7 - now dayOfWeek.

	duration := (self scheduleNextTopOfDay: now) - now .

	secondsToAdd :=  (daysUntilNextWeek * secondsPerDay).
	
	^now + (Duration seconds: secondsToAdd + duration asSeconds).

! !

!EsDailyRollingFileAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/1/2011 9:0'!
scheduledRollover

	^scheduledRollover! !

!EsFileAppender class methodsFor: 'instance creation' stamp: 'DonaldMacQueen 8/13/2012 22:03'!
name: appenderName
	layout: aPatternLayout
	threshold: aLevel
	fileName: aFileNameString
	fileAppend: aBoolean
	immediateFlush: anotherBoolean

	^(self basicNew)
		name: appenderName
			layout: aPatternLayout
			threshold: aLevel
			fileName: aFileNameString
			fileAppend: aBoolean
			immediateFlush: anotherBoolean! !

!EsFileAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 7/1/2011 9:0'!
close

	self writeFooter.
	super close! !

!EsFileAppender methodsFor: 'actions' stamp: 'DonaldMacQueen 6/7/2013 09:36'!
createNewFileNamed: aString
	
	stream := [ StandardFileStream forceNewFileNamed: aString ]
		on: Exception
		do: [ :ex | ^EsLogLog logError: ex printString ].  
	^ stream! !

!EsFileAppender methodsFor: 'actions' stamp: 'DonaldMacQueen 6/7/2013 09:36'!
createStream: aString

	stream :=
		fileAppend
			ifTrue: [self readOldFileNamed: aString]
			ifFalse: [self createNewFileNamed: aString].

	stream isNil ifTrue: [^nil].  

	fileAppend ifTrue: [stream setToEnd].

	closed := false! !

!EsFileAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
fileName

	^fileName! !

!EsFileAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
fileName: anObject

	fileName := anObject! !

!EsFileAppender methodsFor: 'initialize' stamp: 'DonaldMacQueen 8/13/2012 21:59'!
name: appenderName
	layout: aPatternLayout
	threshold: aLevel
	fileName: aFileNameString
	fileAppend: aBoolean
	immediateFlush: anotherBoolean

	self initialize.

	name := appenderName.
	level := aLevel.
	layout := aPatternLayout.
	fileAppend := aBoolean.
	fileName := aFileNameString.
	immediateFlush := anotherBoolean.

	(self	createStream: fileName) isNil ifTrue: [^nil].
		self 	writeHeader

! !

!EsFileAppender methodsFor: 'printing' stamp: 'LibrarySupervisor 7/22/2011 8:12'!
printOn: aStream

	aStream
		nextPutAll: name , ' - ' , fileName , ' - ' , level printString;
		cr.
	self printFiltersOn: aStream! !

!EsFileAppender methodsFor: 'actions' stamp: 'DonaldMacQueen 6/7/2013 09:39'!
readOldFileNamed: aString

	stream := [ StandardFileStream oldFileNamed: aString ]
		on: FileDoesNotExistException
		do: [ :ex | ^EsLogLog logError: ex printString ].  
	^ stream! !

!EsFileAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 7/1/2011 9:0'!
writeFooter

	| string |

	layout isNil ifTrue: [^self].

	string := layout getFooter.

	string notNil ifTrue: [stream nextPutAll: string]! !

!EsFileAppender methodsFor: 'initialize' stamp: 'LibrarySupervisor 7/1/2011 9:0'!
writeHeader

	| string |

	layout isNil ifTrue: [^self].

	string := layout getHeader.

	string notNil ifTrue: [stream nextPutAll: string]! !

EsFileAppender subclass: #EsRollingFileAppender
	instanceVariableNames: 'maxFileSize maxBackupIndex bytesWritten backedUpSoFar'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-FileSupport'!

!EsRollingFileAppender class methodsFor: 'instance creation' stamp: 'DonaldMacQueen 8/13/2012 22:04'!
name: appenderName
	layout: aPatternLayout
	threshold: aLevel
	fileName: fileName
	fileAppend: fileAppend
	immediateFlush: immediateFlush
	maxFileSize: maxFileSize
	maxBackupIndex: maxBackupIndex

	^(self basicNew)
		name: appenderName
			layout: aPatternLayout
			threshold: aLevel
			fileName: fileName
			fileAppend: fileAppend
			immediateFlush: immediateFlush
			maxFileSize: maxFileSize
			maxBackupIndex: maxBackupIndex! !

!EsRollingFileAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 7/1/2011 9:0'!
append: aLoggingEvent

	bytesWritten := bytesWritten + (super append: aLoggingEvent) size.

	bytesWritten > maxFileSize ifTrue: [self roll]! !

!EsRollingFileAppender methodsFor: 'actions' stamp: 'DonaldMacQueen 6/7/2013 09:37'!
createStream: aString

	(stream := self createNewFileNamed: aString) isNil ifTrue: [^nil].

	bytesWritten := 0.

	closed := false




! !

!EsRollingFileAppender methodsFor: 'initialize' stamp: 'DonaldMacQueen 8/27/2012 16:57'!
name: appenderName
	layout: aPatternLayout
	threshold: aLevel
	fileName: aFileNameString
	fileAppend: aBoolean
	immediateFlush: anotherBoolean
	maxFileSize: aFileSize
	maxBackupIndex: anIndex

	self initialize.

	name := appenderName.
	level := aLevel.
	layout := aPatternLayout.
	fileAppend := aBoolean.
	fileName := aFileNameString.
	maxFileSize := aFileSize.
	maxBackupIndex := anIndex.
	immediateFlush := anotherBoolean.

	bytesWritten := backedUpSoFar := 0.

	(self	createStream: fileName) isNil ifTrue: [^nil].

! !

!EsRollingFileAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 7/1/2011 9:0'!
roll

	| newFileName |

	backedUpSoFar := backedUpSoFar + 1.
	backedUpSoFar > maxBackupIndex
		ifTrue: [
			newFileName := fileName.
			backedUpSoFar := 0]
		ifFalse: [newFileName := fileName , backedUpSoFar asString].

	stream close.
	self createStream: newFileName


! !

!EsWriterAppender class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 7/19/2011 9:5'!
name: aString level: aLevel layout: aPatternLayout

	^(self new)
		name: aString level: aLevel layout: aPatternLayout;
		yourself! !

!EsWriterAppender methodsFor: 'actions' stamp: 'LibrarySupervisor 8/3/2011 11:51'!
append: aLoggingEvent

	| string |

	string := layout format: aLoggingEvent.
	stream
		nextPutAll: string;
		cr.
	immediateFlush ifTrue: [stream flush].
	^string! !

!EsWriterAppender methodsFor: 'actions' stamp: 'DonaldMacQueen 8/27/2012 16:17'!
close
	closed
		ifFalse: [ 
			self stream notNil
				ifTrue: [ 
					self stream flush.
					self stream close ] ].
	closed := true! !

!EsWriterAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
immediateFlush

	"temporary"

	^true

! !

!EsWriterAppender methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:42'!
immediateFlush: anObject

	immediateFlush := anObject

! !

!EsWriterAppender methodsFor: 'initialize' stamp: 'LibrarySupervisor 7/19/2011 9:3'!
name: aString level: aLevel layout: aPatternLayout

	self initialize.
	name := aString.
	level := aLevel.
	layout := aPatternLayout


! !

Object subclass: #EsFormattingInfo
	instanceVariableNames: 'min max leftAlign'
	classVariableNames: 'Default'
	poolDictionaries: ''
	category: 'Log4s'!

!EsFormattingInfo class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:43'!
Default

	Default isNil ifTrue: [self initializeDefault].

	^Default! !

!EsFormattingInfo class methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/1/2012 13:35'!
initializeDefault

	"self initializeDefault"

	Default := self leftAlign: false min: 0 max: SmallInteger maxVal

! !

!EsFormattingInfo class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 7/19/2011 8:47'!
leftAlign: leftAlign min: min max: max

	^(self new)
		leftAlign: leftAlign min: min max: max;
		yourself! !

!EsFormattingInfo methodsFor: 'actions' stamp: 'LibrarySupervisor 7/19/2011 8:39'!
format: fieldStart buffer: buffer

	| rawLength string |

	string := buffer.
	rawLength := buffer size - fieldStart.

	rawLength > max
		ifTrue: [| temp | "delete from fieldStart through buffer size - max"
			temp := string copyFrom: fieldStart to: string size.
			temp := temp copyFrom: (temp size - max + 1) to: temp size.
			string := string copyFrom: 1 to: fieldStart - 1.
			string := string , temp]
		ifFalse: [
			rawLength < min
				ifTrue: [
					leftAlign
						ifTrue: [min - rawLength - 1 timesRepeat: [string := string , ' ']]
						ifFalse: [| padLength |
							string := string copyFrom: 1 to: fieldStart - 1.
							padLength := min - rawLength - 1.
							padLength timesRepeat: [string := string , ' '].
							string := string , (buffer copyFrom: fieldStart to: buffer size)]]].

	^string! !

!EsFormattingInfo methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
leftAlign

	^leftAlign! !

!EsFormattingInfo methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
leftAlign: anObject

	leftAlign := anObject! !

!EsFormattingInfo methodsFor: 'initialize' stamp: 'LibrarySupervisor 6/23/2011 13:43'!
leftAlign: aBoolean min: anInteger max: anotherInteger

	leftAlign := aBoolean.
	min := anInteger.
	max := anotherInteger! !

!EsFormattingInfo methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
max

	^max! !

!EsFormattingInfo methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
max: anObject

	max := anObject! !

!EsFormattingInfo methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
min

	^min! !

!EsFormattingInfo methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:43'!
min: anObject

	min := anObject! !

!EsFormattingInfo methodsFor: 'actions' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
reset

	min = -1.
	max = 16r7FFFFFFF.
	leftAlign = false! !

Object subclass: #EsLevel
	instanceVariableNames: 'level levelStr syslogEquivalent'
	classVariableNames: 'All Debug Error Fatal Info LevelsByName LevelsByValue Off Trace TraceInt Warn'
	poolDictionaries: ''
	category: 'Log4s'!

!EsLevel class methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/1/2012 13:09'!
All

	All isNil ifTrue: [All := self level: SmallInteger minVal levelStr: 'ALL' syslogEquivalent: 7].
	^All

! !

!EsLevel class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:44'!
Debug

	Debug isNil ifTrue: [Debug := self level: 10000 levelStr: 'DEBUG' syslogEquivalent: 7].
	^Debug

! !

!EsLevel class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:44'!
Error

	Error isNil ifTrue: [Error := self level: 40000 levelStr: 'ERROR' syslogEquivalent: 3].
	^Error

! !

!EsLevel class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:44'!
Fatal

	Fatal isNil ifTrue: [Fatal := self level: 50000 levelStr: 'FATAL' syslogEquivalent: 0].
	^Fatal

! !

!EsLevel class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:44'!
Info

	Info isNil ifTrue: [Info := self level: 20000 levelStr: 'INFO' syslogEquivalent: 6].
	^Info

! !

!EsLevel class methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/1/2012 13:09'!
Off

	Off isNil ifTrue: [Off := self level: SmallInteger maxVal levelStr: 'OFF' syslogEquivalent: 0].
	^Off

! !

!EsLevel class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:44'!
Trace

	Trace isNil ifTrue: [Trace := self level: self traceInt levelStr: 'TRACE' syslogEquivalent: 7].
	^Trace

! !

!EsLevel class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:44'!
Warn

	Warn isNil ifTrue: [Warn := self level: 30000 levelStr: 'WARN' syslogEquivalent: 4].
	^Warn

! !

!EsLevel class methodsFor: 'class initialization' stamp: 'LibrarySupervisor 6/23/2011 13:44'!
addToTables: aLevel

	LevelsByName at: aLevel levelStr put: aLevel.

	LevelsByValue at: aLevel level put: aLevel! !

!EsLevel class methodsFor: 'class initialization' stamp: 'DonaldMacQueen 8/1/2012 11:41'!
initializeClassVariables

	"self initializeClassVariables"

	LevelsByName := Dictionary new.
	LevelsByValue := Dictionary new.

	self addToTables: self Off.
	self addToTables: self All.
	self addToTables: self Debug.
	self addToTables: self Info.
	self addToTables: self Warn.
	self addToTables: self Error.
	self addToTables: self Fatal.
	self addToTables: self Trace



! !

!EsLevel class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 7/19/2011 8:45'!
level: level levelStr: levelStr syslogEquivalent: syslogEquivalent

	^(self new)
		level: level;
		levelStr: levelStr;
		syslogEquivalent: syslogEquivalent;
		yourself! !

!EsLevel class methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/7/2012 21:08'!
levelByName: aString

	LevelsByName isNil ifTrue: [self initializeClassVariables].
	^LevelsByName at: aString asUppercase ifAbsent: []




! !

!EsLevel class methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/7/2012 21:08'!
levelByValue: anInteger

	LevelsByValue isNil ifTrue: [self initializeClassVariables].
	^LevelsByValue at: anInteger ifAbsent: []




! !

!EsLevel class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:44'!
levelNamed: aString

	^self levelByName: aString




! !

!EsLevel class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:44'!
traceInt

	TraceInt isNil ifTrue: [TraceInt := 5000].
	^TraceInt! !

!EsLevel methodsFor: 'comparison' stamp: 'LibrarySupervisor 6/23/2011 13:44'!
< aLevel

	^level < aLevel level! !

!EsLevel methodsFor: 'comparison' stamp: 'LibrarySupervisor 6/23/2011 13:44'!
<= aLevel

	level < aLevel level ifTrue: [^true].
	level = aLevel level ifTrue: [^true].

	^false! !

!EsLevel methodsFor: 'comparison' stamp: 'LibrarySupervisor 6/23/2011 13:44'!
= aLevel

	aLevel class name = #EsLevel ifFalse: [^false].

	^level = aLevel level! !

!EsLevel methodsFor: 'comparison' stamp: 'LibrarySupervisor 6/23/2011 13:44'!
>= aLevel

	^(level < aLevel level) not! !

!EsLevel methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:44'!
getSyslogEquivalent

	^syslogEquivalent! !

!EsLevel methodsFor: 'comparison' stamp: 'LibrarySupervisor 6/23/2011 13:44'!
hash

	^level hash! !

!EsLevel methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
level

	^level! !

!EsLevel methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
level: anObject

	level := anObject! !

!EsLevel methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
levelStr

	^levelStr! !

!EsLevel methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
levelStr: anObject

	levelStr := anObject! !

!EsLevel methodsFor: 'printing' stamp: 'LibrarySupervisor 6/23/2011 13:44'!
printOn: aStream

	aStream
		nextPutAll: self levelStr;
		space.
	aStream
		nextPutAll: self level printString;
		space.
	aStream nextPutAll: self syslogEquivalent printString! !

!EsLevel methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
syslogEquivalent

	^syslogEquivalent! !

!EsLevel methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
syslogEquivalent: anObject

	syslogEquivalent := anObject! !

!EsLevel methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
toInt

	^level! !

!EsLevel methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
toString

	^levelStr! !

Object subclass: #EsLogLog
	instanceVariableNames: ''
	classVariableNames: 'DebugEnabled QuietMode'
	poolDictionaries: ''
	category: 'Log4s'!

!EsLogLog class methodsFor: 'actions' stamp: 'LibrarySupervisor 7/5/2011 14:8'!
debug: aString

	(self debugEnabled and: [self quietMode not]) ifTrue: [self print: 'DEBUG' msg: aString]! !

!EsLogLog class methodsFor: 'accessing' stamp: 'LibrarySupervisor 7/5/2011 14:2'!
debugEnabled

	DebugEnabled isNil ifTrue: [DebugEnabled := true].
	^DebugEnabled! !

!EsLogLog class methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
debugEnabled: aBoolean

	DebugEnabled := aBoolean! !

!EsLogLog class methodsFor: 'actions' stamp: 'DonaldMacQueen 6/3/2013 17:49'!
logError: aString

	self quietMode ifFalse: [self print: 'ERROR' msg: aString].
	^nil! !

!EsLogLog class methodsFor: 'actions' stamp: 'DonaldMacQueen 6/3/2013 17:49'!
noAppenderNamed: aString

	self logError: ( 'There is no appender named {1}' format: aString)! !

!EsLogLog class methodsFor: 'actions' stamp: 'DonaldMacQueen 6/29/2013 18:00'!
noAppenderNamed: aString forLogger: aLoggerName

	self logError: ('{1} does not have an appender named {2}' format: {aLoggerName. aString})  ! !

!EsLogLog class methodsFor: 'actions' stamp: 'DonaldMacQueen 6/3/2013 17:49'!
noLevelNamed: aString

	self logError: ( 'There is no level named {1}' format: aString)! !

!EsLogLog class methodsFor: 'actions' stamp: 'DonaldMacQueen 6/3/2013 17:50'!
noLoggerNamed: loggerName

	self logError: ( 'Logger {1} not found' format: loggerName) ! !

!EsLogLog class methodsFor: 'actions' stamp: 'DonaldMacQueen 6/3/2013 17:50'!
noPatternLayoutNamed: aString

	self logError: ('There is no PatternLayout class named {1}' format: aString). 
	^nil! !

!EsLogLog class methodsFor: 'actions' stamp: 'DonaldMacQueen 8/27/2012 18:54'!
print: debugLevel msg: aString

		| stderr |
	
		"install the line end conversion and force initialize the converter"
		stderr := FileStream  stderr
					wantsLineEndConversion: true;
					converter;
					yourself.
		stderr open.
		stderr
		nextPutAll: 'log4s: '; 
		nextPutAll: debugLevel;
		space;
		nextPutAll: aString;
		cr! !

!EsLogLog class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:44'!
quietMode

	QuietMode isNil ifTrue: [QuietMode := false].
	^QuietMode! !

!EsLogLog class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:44'!
quietMode: aBoolean

	QuietMode := aBoolean! !

!EsLogLog class methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:44'!
warn: aString

	self quietMode ifFalse: [self print: 'WARN' msg: aString]! !

Object subclass: #EsLogManager
	instanceVariableNames: 'loggers level settings'
	classVariableNames: 'Singleton StartTime'
	poolDictionaries: ''
	category: 'Log4s'!

!EsLogManager class methodsFor: 'filters' stamp: 'LibrarySupervisor 6/23/2011 20:44'!
clearFilters

	self singleton clearFilters! !

!EsLogManager class methodsFor: 'filters' stamp: 'LibrarySupervisor 6/23/2011 22:25'!
clearLevels

	self singleton clearLevels! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/11/2012 17:19'!
commonIniFileLines

	"these lines are common to all the sample ini file"

	"Uncommenting the fifth line below that says 'runForever=()' amd commenting out the next line WILL make EsLogManager run forever.
	
	As it is, EsLogManager will run for 75 seconds and generate a LoggingEvent every 7 seconds.
	Change 75 and/or 7 to whatever integers you wish"


	^self printStrings: #(
		'[log4s]'
		 'debugEnabled=''true'''
		 'quietMode=''false'''
		 'globalLevel=''All'''
		';runForever=()'
		 'runForever=''75'', ''7''')! !

!EsLogManager class methodsFor: 'loggers' stamp: 'LibrarySupervisor 7/19/2012 13:31'!
createLogger: aLoggerNameString

	^self singleton createLogger: aLoggerNameString! !

!EsLogManager class methodsFor: 'appenders' stamp: 'LibrarySupervisor 7/19/2012 13:33'!
dailyRollingFileAppender: anArray  isAsync: aBoolean

	^self singleton dailyRollingFileAppender: anArray  isAsync: aBoolean! !

!EsLogManager class methodsFor: 'loggers' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
exists: aLoggerNameString

	^self singleton exists: aLoggerNameString! !

!EsLogManager class methodsFor: 'appenders' stamp: 'LibrarySupervisor 7/19/2012 13:34'!
fileAppender: anArray isAsync: aBoolean

	^self singleton fileAppender: anArray isAsync: aBoolean! !

!EsLogManager class methodsFor: 'accessing' stamp: 'DonaldMacQueen 6/3/2013 18:02'!
getLevel: aString

	| level |

	(level := EsLevel levelNamed: aString) notNil ifTrue: [^level].

	^EsLogLog logError: ('{1} is not the name of a level' format: aString) 

! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 09:51'!
goodRootLoggerIniFileWithAsyncAppender

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithAsyncAppender'. "

	"1 - asyncAppenderName
	2 - loggerName"

	^self commonIniFileLines , (self printStrings: #('asyncAppender=''asyncAppender'', ''root'' '))
	"there is no output from this method"


! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 09:53'!
goodRootLoggerIniFileWithAsyncConsoleAndAsyncFileAppender

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithAsyncConsoleAndAsyncFileAppender'. "

	"
		1 - logger
		2 - threshold
		3-  patternConverter
		4 - layout
		5 - asyncAppenderName"

	^self commonIniFileLines , (
		self printStrings: #(
			'asyncAppender=''asyncAppender'', ''root'' '
			'asyncConsoleAppender=''root'', ''All'', '''', ''%-15d %p [asyncConsoleAppender]  %-16m'', ''asyncAppender'''
			'asyncFileAppender=''TestFileAppender'', ''root'', ''asyncFileAppender.log'',  ''false'', ''All'', '''', ''%-15d %p [asyncFileAppender]  %-16m'', ''true'', ''asyncAppender'''))



! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 09:56'!
goodRootLoggerIniFileWithAsyncConsoleAndAsyncFileAppenderOnVastLogger

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithAsyncConsoleAndAsyncFileAppenderOnVastLogger'. "

	"
		1 - logger
		2 - threshold
		3-  patternConverter
		4 - layout
		5 - asyncAppenderName"

	^self commonIniFileLines , (
		self printStrings: #(
			'createLogger=''Vast''' 'asyncAppender=''asyncAppender'', ''Vast'' '
			'asyncConsoleAppender=''Vast'', ''All'', '''', ''%-15d %p [asyncConsoleAppender]  %-16m'', ''asyncAppender'''
			'asyncFileAppender=''TestFileAppender'', ''Vast'', ''asyncFileAppenderOnVast.log'',  ''false'', ''All'', '''', ''%-15d %p [asyncFileAppender]  %-16m'', ''true'', ''asyncAppender'''))





! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 09:59'!
goodRootLoggerIniFileWithAsyncConsoleAppender

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithAsyncConsoleAppender'. "

	"
		1 - logger
		2 - threshold
		3-  patternConverter
		4 - layout
		5 - asyncAppenderName"

	^self commonIniFileLines , (
		self printStrings: #(
			'asyncAppender=''asyncAppender'', ''root'' '
			'asyncConsoleAppender=''root'', ''All'', '''', ''%-15d %p [asyncConsoleAppender]  %-16m'', ''asyncAppender'''))






! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 10:02'!
goodRootLoggerIniFileWithAsyncDailyRollingFileAppenderTopOfMinute

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithAsyncDailyRollingFileAppenderTopOfMinute'."

	"1 - name
	2 - loggerName
	3 - fileName
	4 - fileAppend
	5 - level
	6 - layout
	7 - patternConverter
	8 - immediateFlush
	9 - maxFileSize
	10 -  maxBackupIndex"

	^self commonIniFileLines , (
		self printStrings: #(
			'asyncAppender=''asyncAppender'', ''root'' '
			'asyncDailyRollingFileAppender=''TestAsyncDailyRollingFileAppender'', ''root'', ''asyncDailyRollingFile.log'',  ''false'', ''All'', '''', ''%-15d %p [asyncDailyRollingFileAppender]  %-16m'', ''true'',  ''topOfMinute'', ''asyncAppender'''))






! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 10:04'!
goodRootLoggerIniFileWithAsyncFileAppender

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithAsyncFileAppender'. "

	"1 -  appender name
	2 - loggerName
	3 - fileName
	4 - fileAppend
	5 - level
	6 - layout
	7 - patternConverter
	8 - immediateFlush
	9 - asyncAppenderName"

	^self commonIniFileLines , (
		self printStrings: #(
			'asyncAppender=''asyncAppender'', ''root'' '
			'asyncFileAppender=''TestFileAppender'', ''root'', ''asyncFileAppender.log'',  ''false'', ''All'', '''', ''%-15d %p [asyncFileAppender]  %-16m'', ''true'', ''asyncAppender'''))




! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 10:10'!
goodRootLoggerIniFileWithAsyncRollingFileAppender

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithAsyncRollingFileAppender'. "

	"1 -  appender name
	2 - loggerName
	3 - fileName
	4 - fileAppend
	5 - level
	6 - layout
	7 - patternConverter
	8 - immediateFlush
	9 - maxFileSize
	10 -  maxBackupIndex
	11 - asyncAppenderName"

	^self commonIniFileLines , (
		self printStrings: #(
			'asyncAppender=''asyncAppender'', ''root'' '
			'asyncRollingFileAppender=''TestRollingFileAppender'', ''root'', ''asyncRollingFile.log'',  ''false'', ''All'', '''', ''%-15d %p [asyncRollingFileAppender]  %-16m'', ''true'',  ''500'', ''5'', ''asyncAppender'''))





! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 6/6/2013 19:00'!
goodRootLoggerIniFileWithAsyncSocketAppenderByIpAddress

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithAsyncSocketAppenderByIpAddress'. "

	"1 -  appender name
	2 - loggerName
	3 - level
	4 - layout
	5 - patternConverter
	6 - address
	7 - hostName
	8 -  port
	9 - retryCount
	10 - retrySeconds
	11 - asyncAppenderName"

	^self commonIniFileLines , (
		self printStrings: #(
			'asyncAppender=''asyncAppender'', ''root'' '
			'asyncSocketAppender=''TestSocketAppender'', ''root'', ''All'', '''', ''%-15d [asyncSocketAppenderByIpAddress]  %-16m'', ''127.0.0.1'', ''localHost'', ''6543'', ''40'', ''2'', ''asyncAppender'''))



! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 09:46'!
goodRootLoggerIniFileWithConsoleAppender

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithConsoleAppender'. "	
	
	"
		1 - logger
		2 - threshold
		3-  patternConverter
		4 - layout"
		
	^self commonIniFileLines ,
		(self printStrings: #('consoleAppender=''root'', ''All'', '''', ''%-15d %p [consoleAppender]  %-16m'''))
! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 09:43'!
goodRootLoggerIniFileWithDailyRollingFileAppenderHalfDay

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.

	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithDailyRollingFileAppenderHalfDay'.	"

	"1 -  appender name
	2 - loggerName
	3 - fileName
	4 - fileAppend
	5 - level
	6 - layout
	7 - patternConverter
	8 - immediateFlush
	9 - datePattern "


	^self commonIniFileLines , (
		self printStrings: #(
			'dailyRollingFileAppender=''TestDailyRollingFileAppender'', ''root'', ''dallyRollingFileHalfDay.log'',  ''false'', ''All'', '''', ''%-15d [dailyRollingFileAppenderHalfDay]  %-16m'', ''true'', ''halfDay'''))

! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 09:41'!
goodRootLoggerIniFileWithDailyRollingFileAppenderTopOfDay

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithDailyRollingFileAppenderTopOfDay'."

	"1 -  appender name
	2 - loggerName
	3 - fileName
	4 - fileAppend
	5 - level
	6 - layout
	7 - patternConverter
	8 - immediateFlush
	9 - datePattern "

	^self commonIniFileLines , (
		self printStrings: #(
			'dailyRollingFileAppender=''TestDailyRollingFileAppender'', ''root'', ''dallyRollingFileTopOfDay.log'',  ''false'', ''All'', '''', ''%-15d [dailyRollingFileAppenderTopOfDay]  %-16m'', ''true'',  ''topOfDay'''))

! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 09:37'!
goodRootLoggerIniFileWithDailyRollingFileAppenderTopOfHour

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithDailyRollingFileAppenderTopOfHour'."

	"1 -  appender name
	2 - loggerName
	3 - fileName
	4 - fileAppend
	5 - level
	6 - layout
	7 - patternConverter
	8 - immediateFlush
	9 - datePattern "

	^self commonIniFileLines , (
		self printStrings: #(
			'dailyRollingFileAppender=''TestDailyRollingFileAppender'', ''root'', ''dallyRollingFileTopOfHour.log'',  ''false'', ''All'', '''', ''%-15d %p [dailyRollingFileAppenderTopOfHour]  %-16m'', ''true'',  ''topOfHour'''))

! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 09:35'!
goodRootLoggerIniFileWithDailyRollingFileAppenderTopOfMinute

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithDailyRollingFileAppenderTopOfMinute'."

	"1 -  appender name
	2 - loggerName
	3 - fileName
	4 - fileAppend
	5 - level
	6 - layout
	7 - patternConverter
	8 - immediateFlush
	9 - datePattern "

	^self commonIniFileLines , (
		self printStrings: #(
			'dailyRollingFileAppender=''TestDailyRollingFileAppender'', ''root'', ''dallyRollingFileTopOfMinute.log'',  ''false'', ''All'', '''', ''%-15d %p [dailyRollingFileAppenderTopOfMinute]  %-16m'', ''true'',  ''topOfMinute'''))

! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 09:28'!
goodRootLoggerIniFileWithDailyRollingFileAppenderTopOfMonth

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithDailyRollingFileAppenderTopOfMonth'. "

	"1 -  appender name
	2 - loggerName
	3 - fileName
	4 - fileAppend
	5 - level
	6 - layout
	7 - patternConverter
	8 - immediateFlush
	9 - datePattern "

	^self commonIniFileLines , (
		self printStrings: #(
			'dailyRollingFileAppender=''TestDailyRollingFileAppender'', ''root'', ''dallyRollingFileTopOfMonth.log'',  ''false'', ''All'', '''', ''%-15d [dailyRollingFileAppenderTopOfMonth]  %-16m'',  ''true'', ''topOfMonth'''))

! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 09:25'!
goodRootLoggerIniFileWithDailyRollingFileAppenderTopOfWeek

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithDailyRollingFileAppenderTopOfWeek'. "

	"1 -  appender name
	2 - loggerName
	3 - fileName
	4 - fileAppend
	5 - level
	6 - layout
	7 - patternConverter
	8 - immediateFlush
	9 - datePattern "

	^self commonIniFileLines , (
		self printStrings: #(
			'dailyRollingFileAppender=''TestDailyRollingFileAppender'', ''root'', ''dallyRollingFileTopOfWeek.log'',  ''false'', ''All'', '''', ''%-15d [dailyRollingFileAppenderTopOfWeek]  %-16m'', ''true'', ''topOfWeek'''))

! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 09:23'!
goodRootLoggerIniFileWithFileAppender

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithFileAppender'. "

	"1 -  appender name
	2 - loggerName
	3 - fileName
	4 - fileAppend
	5 - level
	6 - layout
	7 - patternConverter
	8 - immediateFlush"

	^self commonIniFileLines , (
		self printStrings: #(
			'fileAppender=''TestFileAppender'', ''root'', ''fileAppender.log'',  ''false'', ''All'', '''', ''%-15d %p [fileAppender - log4s.log]  %-16m'', ''true'''))

! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 09:11'!
goodRootLoggerIniFileWithRollingFileAppender

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithRollingFileAppender'. "

	"1 -  appender name
	2 - loggerName
	3 - fileName
	4 - fileAppend
	5 - level
	6 - layout
	7 - patternConverter
	8 - immediateFlush
	9 - maxFileSize
	10 -  maxBackupIndex"

	^self commonIniFileLines , (
		self printStrings: #(
			'rollingFileAppender=''TestRollingFileAppender'', ''root'', ''rollingFileAppender.log'',  ''false'', ''All'', '''', ''%-15d %p [rollingFileAppender - rollLog4s.log]  %-16m'', ''true'',  ''500'', ''5'''))

! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 6/6/2013 18:38'!
goodRootLoggerIniFileWithSocketAppenderByIpAddress

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithSocketAppenderByIpAddress'. "

	"1 -  appender name
	2 - loggerName
	3 - level
	4 - layout
	5 - patternConverter
	6 - address
	7 - hostName
	8 -  port
	9 - retryCount
	10 - retrySeconds"

	^self commonIniFileLines , (
		self printStrings: #(
			'socketAppender=''TestSocketAppender'', ''root'', ''All'', '''', ''%-15d [socketAppenderByIpAddress]  %p %-16m'', ''127.0.0.1'', ''localHost'', ''6543'',  ''40'', ''2'''))! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 6/6/2013 19:01'!
goodRootLoggerIniFileWithSocketAppenderByName

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithSocketAppenderByName'. "

	"1 -  appender name
	2 - loggerName
	3 - level
	4 - layout
	5 - patternConverter
	6 - address
	7 - hostName
	8 -  port
	9 - retryCount
	10 - retrySeconds"

	^self commonIniFileLines , (
		self printStrings: #(
			'socketAppender=''TestSocketAppender'', ''root'', ''All'', '''', ''%-15d [socketAppenderByName]  %p %-16m'', '''', ''localHost'', ''6543'', ''40'', ''2''')) "ipAddress isEmpty so hostName of localHost will be used"! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 11:49'!
goodRootLoggerIniFileWithTranscriptAppender

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithTranscriptAppender'. "

	"
		1 - logger
		2 - threshold
		3-  layout
		4 - patternConverter"

	^self commonIniFileLines , (
		self printStrings: #(
			'transcriptAppender=''root'', ''All'', '''', ''%-15d %C %object %p [transcriptAppender]  %-16m'''))! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 08:30'!
goodRootLoggerIniFileWithTranscriptAppenderAndClassNameFilterDeny

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithTranscriptAppenderAndClassNameFilterDeny'. "	

	"
		1 - logger
		2 - threshold
		3-  layout
		4 - patternConverter"

	^self commonIniFileLines , (
		self printStrings: #(
			'transcriptAppender=''root'', ''All'', '''', ''%-15d %C [transcriptAppender - ClassNameFilterDeny = EsLogManager class]  %-16m'''
			'classNameFilter=''root'', ''Transcript'', ''ClassNameFilter'', ''EsLogManager class'', ''false''')) " only log EsLoggingEvents whose className ~= 'EsLogManager class'"			
			
	"There should be no log output"! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 08:11'!
goodRootLoggerIniFileWithTranscriptAppenderAndClassNameFilterOk

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithTranscriptAppenderAndClassNameFilterOk'. "

	"
		1 - logger
		2 - threshold
		3-  layout
		4 - patternConverter"

	^self commonIniFileLines , (
		self printStrings: #(
			'transcriptAppender=''root'', ''All'', '''', ''%-15d %C [transcriptAppender - ClassNameFilterOk = EsLogManager class]  %-16m'''
			'classNameFilter=''root'', ''Transcript'', ''ClassNameFilter'', ''EsLogManager class''')) " only log EsLoggingEvents whose className = 'EsLogManager class'"! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 08:07'!
goodRootLoggerIniFileWithTranscriptAppenderAndLevelMatchFilterDeny

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithTranscriptAppenderAndLevelMatchFilterDeny'. "

	"
		1 - logger
		2 - threshold
		3-  layout
		4 - patternConverter"

	^self commonIniFileLines , (
		self printStrings: #(
			'transcriptAppender=''root'', ''All'', '''', ''%-15d %p [transcriptAppender - LevelMatchFilterDeny = Info]  %-16m'''
			'levelMatchFilter=''root'', ''Transcript'', ''LevelMatchFilter'', ''Info'', ''false''')) " only log EsLoggingEvents that DO NOT match Level Info"! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 08:03'!
goodRootLoggerIniFileWithTranscriptAppenderAndLevelMatchFilterOk

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithTranscriptAppenderAndLevelMatchFilterOk'. "
	
	"
		1 - logger
		2 - threshold
		3-  layout
		4 - patternConverter"

	^self commonIniFileLines , (
		self printStrings: #(
			'transcriptAppender=''root'', ''All'', '''', ''%-15d %p [transcriptAppender - LevelMatchFilterOk = Info]  %-16m'''
			'levelMatchFilter=''root'', ''Transcript'', ''LevelMatchFilter'', ''Info''')) " only log EsLoggingEvents that match Level Info"! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 08:01'!
goodRootLoggerIniFileWithTranscriptAppenderAndLevelRangeFillterInfoWarnDeny

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithTranscriptAppenderAndLevelRangeFillterInfoWarnDeny'. "
	
	"
		1 - logger
		2 - threshold
		3-  layout
		4 - patternConverter"

	^self commonIniFileLines , (
		self printStrings: #(
			'transcriptAppender=''root'', ''All'', '''', ''%-15d %p [transcriptAppender - LevelRangeFillterInfoWarnDeny  - Info to Warn]  %-16m'''
			'levelRangeFilter=''root'', ''Transcript'', ''LevelRangeFilter'', ''Warn'', ''Info'', ''false''')) " only log EsLoggingEvents that fall outside that range of Level Info through Level Warn"! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 07:58'!
goodRootLoggerIniFileWithTranscriptAppenderAndLevelRangeFillterInfoWarnOnly

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithTranscriptAppenderAndLevelRangeFillterInfoWarnOnly'. "
	
	"
		1 - logger
		2 - threshold
		3-  layout
		4 - patternConverter"

	^self commonIniFileLines , (
		self printStrings: #(
			'transcriptAppender=''root'', ''All'', '''', ''%-15d %p [transcriptAppender - LevelRangeFillterInfoWarnOnly - Info to Warn]  %-16m'''
			'levelRangeFilter=''root'', ''Transcript'', ''LevelRangeFilter'', ''Warn'', ''Info''')) " only log EsLoggingEvents that match Level Info through Level Warn"! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 07:55'!
goodRootLoggerIniFileWithTranscriptAppenderAndStringMatchFilterDeny

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithTranscriptAppenderAndStringMatchFilterDeny'."
	
	"
		1 - logger
		2 - threshold
		3-  layout
		4 - patternConverter"

	^self commonIniFileLines , (
		self printStrings: #(
			'transcriptAppender=''root'', ''All'', '''', ''%-15d %p [transcriptAppender - StringMatchFilterDeny = MOM case insensitive]  %-16m'''
			'stringMatchFilter=''root'', ''Transcript'', ''StringMatchFilter'', ''MOM'', ''false'', ''true''')) " only log EsLoggingEvents whose message DOES NOT include the case insensitive string 'MOM'"! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 07:45'!
goodRootLoggerIniFileWithTranscriptAppenderAndStringMatchFilterDenyCaseSensitive

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithTranscriptAppenderAndStringMatchFilterDenyCaseSensitive'. "

	"
		1 - logger
		2 - threshold
		3-  layout
		4 - patternConverter"

	^self commonIniFileLines , (
		self printStrings: #(
			'transcriptAppender=''root'', ''All'', '''', ''%-15d %p [transcriptAppender - StringMatchFilterDeny = case sensitive H]  %-16m'''
			'stringMatchFilter=''root'', ''Transcript'', ''StringMatchFilter'', ''H'', ''true'', ''false''')) " only log EsLoggingEvents whose message contains the case sensitive 'H'"! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 07:42'!
goodRootLoggerIniFileWithTranscriptAppenderAndStringMatchFilterOk

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithTranscriptAppenderAndStringMatchFilterOk'. "
	
	"
		1 - logger
		2 - threshold
		3-  layout
		4 - patternConverter"

	^self commonIniFileLines , (
		self printStrings: #(
			'transcriptAppender=''root'', ''All'', '''', ''%-15d %p [transcriptAppender - StringMatchFilterOK = MOM case insensitive]  %-16m'''
			'stringMatchFilter=''root'', ''Transcript'', ''StringMatchFilter'', ''MOM'', ''true'', ''true''')) " only log EsLoggingEvents whose message includes the case insensitive string 'MOM'"! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 07:38'!
goodRootLoggerIniFileWithTranscriptAppenderAndTopOfMinuteFileAppender

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithTranscriptAppenderAndTopOfMinuteFileAppender'. "
	
	"
		1 - logger
		2 - threshold
		3-  layout
		4 - patternConverter"

	^self commonIniFileLines , (
		self printStrings: #(
			'dailyRollingFileAppender=''TestDailyRollingFileAppender'', ''root'', ''vastTopOfMinute.log'',  ''false'', ''All'', '''', ''%-15d [dailyRollingFileAppender - vastTopOfMinute.log]  %-16m'', ''true'', ''topOfMinute'''
			'transcriptAppender=''root'', ''All'', '''', ''%-15d %p [transcriptAppender]  %-16m'''))! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 07:34'!
goodRootLoggerIniFileWithTranscriptAppenderAndTopOfMinuteFileAppenderOnTwoLoggers

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithTranscriptAppenderAndTopOfMinuteFileAppenderOnTwoLoggers'. "

	"
		1 - logger
		2 - threshold
		3-  layout
		4 - patternConverter"

	^self commonIniFileLines , (
		self printStrings: #(
			'createLogger=''Vast'''
			'fileAppender=''TestFileAppender'', ''Vast'', ''VastFileAppendee.log'',  ''false'', ''Warn'', '''', ''%-15d %p [fileAppender - Vast.log]  %-16m'', ''true'''
			'transcriptAppender=''root'', ''Info'', '''', ''%-15d %p [transcriptAppender]  %-16m'''))! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 07:28'!
goodRootLoggerIniFileWithTranscriptAppenderAndTopOfMonthFileAppender

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodRootLoggerIniFileWithTranscriptAppenderAndTopOfMonthFileAppender'. "

	"
		1 - logger
		2 - threshold
		3-  layout
		4 - patternConverter"

	^self commonIniFileLines , (
		self printStrings: #(
			'dailyRollingFileAppender=''TestDailyRollingFileAppender'', ''root'', ''vastTopOfMonth.log'',  ''false'', ''All'', '''', ''%-15d [dailyRollingFileAppender - vastTopOfMonth.log]  %-16m'', ''true'', ''topOfMonth'''
			'transcriptAppender=''root'', ''All'', '''', ''%-15d [transcriptAppender]  %-16m'''))! !

!EsLogManager class methodsFor: 'sample ini files' stamp: 'DonaldMacQueen 8/12/2012 07:26'!
goodVastLoggerIniFileWithTranscriptAppender

	"To test this in an open image, execute the line below. 
	See also the method commonIniFileLines.
	
	Execute 'EsLogManager runForever: EsLogManager goodVastLoggerIniFileWithTranscriptAppender'. "

	"
		1 - logger
		2 - threshold
		3-  layout
		4 - patternConverter"

	^self commonIniFileLines , (
		self printStrings: #(
			'createLogger=''Vast'''
			'transcriptAppender=''Vast'', ''Warn'', '''', ''%-15d %p [transcriptAppender]  %-16m'''))! !

!EsLogManager class methodsFor: 'appenders' stamp: 'LibrarySupervisor 7/19/2012 13:21'!
inMemoryAppender: anArray

	^self singleton inMemoryAppender: anArray! !

!EsLogManager class methodsFor: 'initialize' stamp: 'DonaldMacQueen 8/12/2012 10:53'!
initialize
	"self initialize"
	Smalltalk
		addToStartUpList: self ; 
		addToShutDownList: self  ! !

!EsLogManager class methodsFor: 'initialize' stamp: 'DonaldMacQueen 6/6/2013 15:47'!
initializeSingleton
	"self initializeSingleton"

	Singleton := super new
		loggers: Dictionary new;
		settings: Dictionary new;
		level: EsLevel All;
		yourself.
	Singleton
		createRootLogger;
		readIniFile
		! !

!EsLogManager class methodsFor: 'initialize' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
initializeStartTime

	"self initializeStartTime"

	StartTime := DateAndTime now


! !

!EsLogManager class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
level

	^self singleton level

! !

!EsLogManager class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
level: anObject

	^self singleton level: anObject

! !

!EsLogManager class methodsFor: 'filters' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
levelRangeFilter: anArray

	^self singleton levelRangeFilter: anArray! !

!EsLogManager class methodsFor: 'logging' stamp: 'LibrarySupervisor 6/23/2011 20:51'!
log: msg level: aLevel

	^self singleton log: msg level: aLevel! !

!EsLogManager class methodsFor: 'accessing' stamp: 'DonaldMacQueen 6/3/2013 18:05'!
logDebug: msg

	"talk to the rootLogger"

	^self singleton log: msg level: EsLevel Debug

! !

!EsLogManager class methodsFor: 'accessing' stamp: 'DonaldMacQueen 6/3/2013 18:05'!
logDebug: msg locationInfo: locationInfo

	"talk to the rootLogger"

	^self singleton log: msg level: EsLevel Debug locationInfo: locationInfo

! !

!EsLogManager class methodsFor: 'accessing' stamp: 'DonaldMacQueen 6/3/2013 18:05'!
logDebug: msg locationInfo: locationInfo object: anObject

	"talk to the rootLogger"

	^self singleton log: msg level: EsLevel Debug locationInfo: locationInfo object: anObject
! !

!EsLogManager class methodsFor: 'accessing' stamp: 'DonaldMacQueen 6/3/2013 18:05'!
logDebug: msg object: anObject

	"talk to the rootLogger"

	^self singleton log: msg level: EsLevel Debug object: anObject
! !

!EsLogManager class methodsFor: 'accessing' stamp: 'DonaldMacQueen 6/3/2013 18:06'!
logError: msg

	"talk to the rootLogger"

	^self singleton log: msg level: EsLevel Error
! !

!EsLogManager class methodsFor: 'accessing' stamp: 'DonaldMacQueen 6/3/2013 18:07'!
logError: msg locationInfo: locationInfo

	"talk to the rootLogger"

	^self singleton log: msg level: EsLevel Error locationInfo: locationInfo
! !

!EsLogManager class methodsFor: 'accessing' stamp: 'DonaldMacQueen 6/3/2013 18:07'!
logError: msg locationInfo: locationInfo object: anObject

	"talk to the rootLogger"

	^self singleton log: msg level: EsLevel Error locationInfo: locationInfo object: anObject
! !

!EsLogManager class methodsFor: 'accessing' stamp: 'DonaldMacQueen 6/3/2013 18:07'!
logError: msg object: anObject

	"talk to the rootLogger"

	^self singleton log: msg level: EsLevel Error object: anObject! !

!EsLogManager class methodsFor: 'testing' stamp: 'DonaldMacQueen 6/3/2013 18:19'!
logEvents

	| index messages vastLogger message locationInfo |

	messages := #('Hi Mom' 'Kent Beck' 'I love Smalltalk' 'Go Patriots' 'Viva Las Vegas'
	'Hello, World').

	vastLogger := self loggerNamed: 'Vast'.

	index := (Time now asMilliseconds rem: 6) + 1. "pseudo random number"

	message := messages at: index. "pick a random message"
	locationInfo := self currentClassAndMethod.

	self logWarn: message locationInfo: locationInfo object: self. "send it to the rootLogger"
	self logDebug: message locationInfo: locationInfo object: self.
	self logInfo: message locationInfo: locationInfo object: self.
	self logError: message locationInfo: locationInfo object: self.

	self loggerNamed: vastLogger warn: message locationInfo: locationInfo object: self. " send it to the logger named vast"
	self loggerNamed: vastLogger debug: message locationInfo: locationInfo object: self.
	self loggerNamed: vastLogger info: message locationInfo: locationInfo object: self.
	self loggerNamed: vastLogger error: message locationInfo: locationInfo object: self.

	(Delay forMilliseconds: 1567) wait

! !

!EsLogManager class methodsFor: 'testing' stamp: 'DonaldMacQueen 6/3/2013 18:24'!
logEventsFor: durationSeconds delay: delaySeconds anIniFile: anIniFile

	| index messages vastLoggerName message locationInfo msg done start stop   |

	messages := #('Hi Mom' 'Kent Beck' 'I love Smalltalk' 'Go Patriots' 'Viva Las Vegas'
	'Hello, World').

	done := false.
	start := DateAndTime now.

	stop :=
		DateAndTime now + (Duration seconds: durationSeconds).

	vastLoggerName := 'Vast'. "messages sent to non-existent loggers are ignored"

	[done] whileFalse: [
		index := (Time now seconds rem: 6) + 1. "pseudo random number"

		message := messages at: index. "pick a random message"
		locationInfo :=  thisContext.

		self logWarn: message locationInfo: locationInfo object: self. "send it to the rootLogger"
		self logDebug: message locationInfo: locationInfo object: self.
		self logInfo: message locationInfo: locationInfo object: self.
		self logError: message locationInfo: locationInfo object: self.

		self loggerNamed: vastLoggerName warn: message locationInfo: locationInfo object: self. " send it to the logger named vast"
		self loggerNamed: vastLoggerName debug: message locationInfo: locationInfo object: self.
		self loggerNamed: vastLoggerName info: message locationInfo: locationInfo object: self.
		self loggerNamed: vastLoggerName error: message locationInfo: locationInfo object: self.

		(Delay forSeconds: delaySeconds) wait.
		done := DateAndTime now > stop].

	self
		clearLevels;
		clearFilters.

	msg := ' ^^^^^^^ Done!!'.
	msg := anIniFile , msg.
	self log: msg level: EsLevel All.

	self shutDown


! !

!EsLogManager class methodsFor: 'accessing' stamp: 'DonaldMacQueen 6/3/2013 18:08'!
logInfo: msg

	"talk to the rootLogger"

	^self singleton log: msg level: EsLevel Info! !

!EsLogManager class methodsFor: 'accessing' stamp: 'DonaldMacQueen 6/3/2013 18:08'!
logInfo: msg locationInfo: locationInfo

	"talk to the rootLogger"

	^self singleton log: msg level: EsLevel Info locationInfo: locationInfo! !

!EsLogManager class methodsFor: 'accessing' stamp: 'DonaldMacQueen 6/3/2013 18:10'!
logInfo: msg locationInfo: locationInfo object: anObject

	"talk to the rootLogger"

	^self singleton log: msg level: EsLevel Info locationInfo: locationInfo object: anObject

! !

!EsLogManager class methodsFor: 'accessing' stamp: 'DonaldMacQueen 6/3/2013 18:10'!
logInfo: msg object: anObject

	"talk to the rootLogger"

	^self singleton log: msg level: EsLevel Info object: anObject

! !

!EsLogManager class methodsFor: 'accessing' stamp: 'DonaldMacQueen 6/3/2013 18:10'!
logWarn: msg

	"talk to the rootLogger"

	^self singleton log: msg level: EsLevel Warn! !

!EsLogManager class methodsFor: 'accessing' stamp: 'DonaldMacQueen 6/3/2013 18:10'!
logWarn: msg locationInfo: locationInfo

	"talk to the rootLogger"

	^self singleton log: msg level: EsLevel Warn locationInfo: locationInfo! !

!EsLogManager class methodsFor: 'accessing' stamp: 'DonaldMacQueen 6/3/2013 18:11'!
logWarn: msg locationInfo: locationInfo object: anObject

	"talk to the rootLogger"

	^self singleton log: msg level: EsLevel Warn locationInfo: locationInfo object: anObject! !

!EsLogManager class methodsFor: 'accessing' stamp: 'DonaldMacQueen 6/3/2013 18:11'!
logWarn: msg object: anObject

	"talk to the rootLogger"

	^self singleton log: msg level: EsLevel Warn object: anObject! !

!EsLogManager class methodsFor: 'loggers' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
loggerNamed: aLoggerNameString

	"same as getLogger:"

	^self singleton loggers at: aLoggerNameString ifAbsent: []! !

!EsLogManager class methodsFor: 'logging' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
loggerNamed: aLoggerNameString debug: msg

	"talk to the logger named aLoggerNameString"

	| logger |

	^(logger := self loggerNamed: aLoggerNameString) isNil
		ifTrue: [nil]
		ifFalse: [logger log: msg level: EsLevel Debug]! !

!EsLogManager class methodsFor: 'logging' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
loggerNamed: aLoggerNameString debug: msg locationInfo: locationInfo

	"talk to the logger named aLoggerNameString"

	| logger |

	^(logger := self loggerNamed: aLoggerNameString) isNil
		ifTrue: [nil]
		ifFalse: [logger log: msg level: EsLevel Debug locationInfo: locationInfo]! !

!EsLogManager class methodsFor: 'logging' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
loggerNamed: aLoggerNameString debug: msg locationInfo: locationInfo object: anObject

	"talk to the logger named aLoggerNameString"

	| logger |

	^(logger := self loggerNamed: aLoggerNameString) isNil
		ifTrue: [nil]
		ifFalse: [logger log: msg level: EsLevel Debug locationInfo: locationInfo object: anObject]! !

!EsLogManager class methodsFor: 'logging' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
loggerNamed: aLoggerNameString debug: msg object: anObject

	"talk to the logger named aLoggerNameString"

	| logger |

	^(logger := self loggerNamed: aLoggerNameString) isNil
		ifTrue: [nil]
		ifFalse: [logger log: msg level: EsLevel Debug object: anObject]! !

!EsLogManager class methodsFor: 'logging' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
loggerNamed: aLoggerNameString error: msg

	"talk to the logger named aLoggerNameString"

	| logger |

	^(logger := self loggerNamed: aLoggerNameString) isNil
		ifTrue: [nil]
		ifFalse: [logger log: msg level: EsLevel Error]! !

!EsLogManager class methodsFor: 'logging' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
loggerNamed: aLoggerNameString error: msg locationInfo: locationInfo

	"talk to the logger named aLoggerNameString"

	| logger |

	^(logger := self loggerNamed: aLoggerNameString) isNil
		ifTrue: [nil]
		ifFalse: [logger log: msg level: EsLevel Error locationInfo: locationInfo]! !

!EsLogManager class methodsFor: 'logging' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
loggerNamed: aLoggerNameString error: msg locationInfo: locationInfo object: anObject

	"talk to the logger named aLoggerNameString"

	| logger |

	^(logger := self loggerNamed: aLoggerNameString) isNil
		ifTrue: [nil]
		ifFalse: [logger log: msg level: EsLevel Error locationInfo: locationInfo object: anObject]! !

!EsLogManager class methodsFor: 'logging' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
loggerNamed: aLoggerNameString error: msg object: anObject

	"talk to the logger named aLoggerNameString"

	| logger |

	^(logger := self loggerNamed: aLoggerNameString) isNil
		ifTrue: [nil]
		ifFalse: [logger log: msg level: EsLevel Error object: anObject]! !

!EsLogManager class methodsFor: 'logging' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
loggerNamed: aLoggerNameString info: msg

	"talk to the logger named aLoggerNameString"

	| logger |

	^(logger := self loggerNamed: aLoggerNameString) isNil
		ifTrue: [nil]
		ifFalse: [logger log: msg level: EsLevel Info]! !

!EsLogManager class methodsFor: 'logging' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
loggerNamed: aLoggerNameString info: msg locationInfo: locationInfo

	"talk to the logger named aLoggerNameString"

	| logger |

	^(logger := self loggerNamed: aLoggerNameString) isNil
		ifTrue: [nil]
		ifFalse: [logger log: msg level: EsLevel Info locationInfo: locationInfo]! !

!EsLogManager class methodsFor: 'logging' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
loggerNamed: aLoggerNameString info: msg locationInfo: locationInfo object: anObject

	"talk to the logger named aLoggerNameString"

	| logger |

	^(logger := self loggerNamed: aLoggerNameString) isNil
		ifTrue: [nil]
		ifFalse: [logger log: msg level: EsLevel Info locationInfo: locationInfo object: anObject]

! !

!EsLogManager class methodsFor: 'logging' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
loggerNamed: aLoggerNameString info: msg object: anObject

	"talk to the logger named aLoggerNameString"

	| logger |

	^(logger := self loggerNamed: aLoggerNameString) isNil
		ifTrue: [nil]
		ifFalse: [logger log: msg level: EsLevel Info object: anObject]

! !

!EsLogManager class methodsFor: 'logging' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
loggerNamed: aLoggerNameString warn: msg

	"talk to the logger named aLoggerNameString"

	| logger |

	^(logger := self loggerNamed: aLoggerNameString) isNil
		ifTrue: [nil]
		ifFalse: [logger log: msg level: EsLevel Warn]! !

!EsLogManager class methodsFor: 'logging' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
loggerNamed: aLoggerNameString warn: msg locationInfo: locationInfo

	"talk to the logger named aLoggerNameString"

	| logger |

	^(logger := self loggerNamed: aLoggerNameString) isNil
		ifTrue: [nil]
		ifFalse: [logger log: msg level: EsLevel Warn locationInfo: locationInfo]! !

!EsLogManager class methodsFor: 'logging' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
loggerNamed: aLoggerNameString warn: msg locationInfo: locationInfo object: anObject

	"talk to the logger named aLoggerNameString"

	| logger |

	^(logger := self loggerNamed: aLoggerNameString) isNil
		ifTrue: [nil]
		ifFalse: [logger log: msg level: EsLevel Warn locationInfo: locationInfo object: anObject]! !

!EsLogManager class methodsFor: 'logging' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
loggerNamed: aLoggerNameString warn: msg object: anObject

	"talk to the logger named aLoggerNameString"

	| logger |

	^(logger := self loggerNamed: aLoggerNameString) isNil
		ifTrue: [nil]
		ifFalse: [logger log: msg level: EsLevel Warn object: anObject]! !

!EsLogManager class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
new

	^self singleton! !

!EsLogManager class methodsFor: 'ini file' stamp: 'DonaldMacQueen 8/5/2012 14:57'!
printStrings: anArray

	"we need to 'print' the ini file so that the correct line separator characters get used. literals won't work"

	| stream |

	stream := WriteStream on: ''.
	anArray do: [:each |
		stream
			nextPutAll: each;
			cr].
	^stream contents! !

!EsLogManager class methodsFor: 'ini file' stamp: 'DonaldMacQueen 8/5/2012 14:57'!
readIniFileFrom: aString

	^self singleton readIniFileFrom: aString! !

!EsLogManager class methodsFor: 'readMe' stamp: 'DonaldMacQueen 8/5/2012 14:58'!
readMe

	"to run log4s with any of these ini files, execute ''LogManager runForever: LogManager goodIniFileMethodName''.
	They will each run for 75 seconds and log every 7 seconds. Modify commonIniFileLines to change these times"



! !

!EsLogManager class methodsFor: 'loggers' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
removeAllLoggers

	^self singleton removeAllLoggers! !

!EsLogManager class methodsFor: 'loggers' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
reset

	"Private - used mainly for unit tests. You have been warned"

	^self
		removeAllLoggers;
		initializeSingleton! !

!EsLogManager class methodsFor: 'appenders' stamp: 'LibrarySupervisor 7/19/2012 13:34'!
rollingFileAppender: anArray  isAsync: aBoolean

	^self singleton rollingFileAppender: anArray  isAsync: aBoolean
! !

!EsLogManager class methodsFor: 'loggers' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
rootLogger

	^self singleton rootLogger

! !

!EsLogManager class methodsFor: 'testing' stamp: 'DonaldMacQueen 8/12/2012 11:46'!
runForever

	"self runForever"

	(self readIniFileFrom: 'log4s.ini') isNil ifTrue: [^self].  

	[true] whileTrue: [self logEvents]
! !

!EsLogManager class methodsFor: 'testing' stamp: 'DonaldMacQueen 6/6/2013 15:15'!
runForever: aString

	| runParams |

	Cursor write showWhile: [  
	self reset.

	self readIniFileFrom: (ReadStream on: aString).	
	
	(runParams :=  self singleton checkForRunForeverParams ) isNil ifTrue: [^self].

	runParams class = Association
		ifTrue: [self logEventsFor: runParams key delay: runParams value anIniFile: aString]
		ifFalse: [ "run forever" [true] whileTrue: [self logEvents]] ]! !

!EsLogManager class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/22/2012 16:9'!
settings

	^self singleton settings

! !

!EsLogManager class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/22/2012 16:9'!
settings: anObject

	^self singleton settings: anObject

! !

!EsLogManager class methodsFor: 'actions' stamp: 'DonaldMacQueen 8/9/2012 11:15'!
shutDown: quitting

	^self singleton shutDown! !

!EsLogManager class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
singleton

	Singleton isNil ifTrue: [self initializeSingleton].
	^Singleton

! !

!EsLogManager class methodsFor: 'readMe' stamp: 'DonaldMacQueen 6/6/2013 19:04'!
startSocketAppenderServer
	"Before executing any of the socketAppender goodRootLogger* socket methods tests, you must start a socket listener. This code snippet will do that. This snippet and the socketAppender goodRootLogger* socket methods use port 6543. You should pick a port that is open on your system"
	
	"
	| server done dt serverStream serverSocket port |
	port := 6543. <-------------------------------------------------------------------------------------------------- change this if necessary
	server := Socket newTCP.
	[server listenOn: port backlogSize: 4.

	serverSocket := server waitForAcceptFor: 60.
	self assert: serverSocket isConnected.
	] ensure:[server destroy].
	done := false. Transcript show: 'Connected at ', DateAndTime now printString;cr.
	dt := DateAndTime now.
	serverStream := SocketStream on: serverSocket.
	[done] whileFalse: [
		Transcript show: serverStream nextLine;cr. 
		done := ( DateAndTime now - dt) seconds > 120.]. 
	server destroy
	Transcript show: 'done';cr.
	"

	! !

!EsLogManager class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
startTime

	StartTime isNil ifTrue: [self initializeStartTime].
	^StartTime

! !

!EsLogManager class methodsFor: 'initialize' stamp: 'DonaldMacQueen 8/9/2012 21:08'!
startUp
	self
		initializeStartTime;
		initializeSingleton.! !

!EsLogManager class methodsFor: 'appenders' stamp: 'LibrarySupervisor 7/19/2012 13:21'!
transcriptAppender: anArray 

	^self singleton transcriptAppender: anArray ! !

!EsLogManager methodsFor: 'loggers' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
addLogger: aLogger

	loggers at: aLogger name ifAbsentPut: [aLogger]! !

!EsLogManager methodsFor: 'appenders' stamp: 'LibrarySupervisor 9/15/2011 15:46'!
asyncAppender: anArray

	"this method will be the one receiving the parameters from the ini file, checking them and then creating an AsyncAppender if all is well"

	"	1 - appenderName
		2 - loggerName
		3-  priority?"

	| asyncAppender error loggerName logger appenderName |

	error := false.

	(appenderName := self getAppenderName: (anArray at: 1)) isNil ifTrue: [error := true].

	(loggerName := self getLoggerName: (anArray at: 2)) isNil ifTrue: [error := true].

	(logger := self getLogger: loggerName) isNil
		ifTrue: [
			EsLogLog noLoggerNamed: loggerName.
			error := true].

	error ifTrue: [^nil].

	asyncAppender := EsAsyncAppender name: appenderName.

	logger addAppender: asyncAppender.

	^asyncAppender

! !

!EsLogManager methodsFor: 'internal' stamp: 'DonaldMacQueen 6/29/2013 17:58'!
badBoolean: aString for: anotherString

	^EsLogLog logError: ('{1} is not a valid boolean setting for ini file setting {2}'
			format: {aString. anotherString})







! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 6/3/2013 17:56'!
checkForAsyncAppender
	| values asyncAppender |
	(settings keys includes: 'asyncAppender')
		ifFalse: [ ^ self ].
	(values := settings at: 'asyncAppender') size ~= 2
		ifTrue: [ ^ EsLogLog logError: 'asyncAppender requires 2 settings' ].
	asyncAppender := self asyncAppender: values.
	asyncAppender isNil
		ifTrue: [ ^ nil ].
	self
		checkForAsyncConsoleAppender! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 6/3/2013 18:01'!
checkForAsyncConsoleAppender

	| values |

	(settings keys includes: 'asyncConsoleAppender') ifFalse: [^self].

	(values := (settings at: 'asyncConsoleAppender')) size ~= 5 ifTrue: [^EsLogLog logError: 'asyncConsoleAppender requires 5 settings'].  

	self consoleAppender: values isAsync: true! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 6/3/2013 18:00'!
checkForAsyncDailyRollingFileAppender

	| values levelName |

	(settings keys includes: 'asyncDailyRollingFileAppender') ifFalse: [^self].

	(values := (settings at: 'asyncDailyRollingFileAppender')) size ~= 10
		ifTrue: [^EsLogLog logError: 'asyncDailyRollingFileAppender requires 10 settings']. 

	levelName := values at: 5.
	(self validateLevel: levelName) isNil ifTrue: [^nil].

	self dailyRollingFileAppender: values isAsync: true! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 6/3/2013 17:58'!
checkForAsyncFileAppender

	| values levelName |

	(settings keys includes: 'asyncFileAppender') ifFalse: [^self].

	(values := (settings at: 'asyncFileAppender')) size ~= 9 ifTrue: [^EsLogLog logError: 'asyncFileAppender requires 9 settings'].  

	levelName := values at: 5.
	(self validateLevel: levelName) isNil ifTrue: [^nil].

	self fileAppender: values isAsync: true

! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 6/3/2013 17:58'!
checkForAsyncRollingFileAppender

	| values levelName |

	(settings keys includes: 'asyncRollingFileAppender') ifFalse: [^self].

	(values := (settings at: 'asyncRollingFileAppender')) size ~= 11
		ifTrue: [^EsLogLog logError: 'asyncRollingFileAppender requires 11 settings'].  

	levelName := values at: 5.
	(self validateLevel: levelName) isNil ifTrue: [^nil].

	self rollingFileAppender: values isAsync: true! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 6/3/2013 18:01'!
checkForAsyncSocketAppender

	| values levelName |

	(settings keys includes: 'asyncSocketAppender') ifFalse: [^self].

	(values := (settings at: 'asyncSocketAppender')) size ~= 11 ifTrue: [^EsLogLog logError: 'asyncSocketAppender requires 11 settings'].  

	levelName := values at: 3.
	(self validateLevel: levelName) isNil ifTrue: [^nil].

	self socketAppender: values isAsync: true

! !

!EsLogManager methodsFor: 'ini file' stamp: 'LibrarySupervisor 7/12/2012 10:40'!
checkForClassNameFilter

	| values |

	(settings keys includes: 'classNameFilter') ifFalse: [^self].

	(values := (settings at: 'classNameFilter')) isEmpty ifTrue: [^self].

	^self classNameFilter: values! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 6/3/2013 18:01'!
checkForConsoleAppender

	| values levelName |

	(settings keys includes: 'consoleAppender') ifFalse: [^self].

	(values := (settings at: 'consoleAppender')) size ~= 4 ifTrue: [^EsLogLog logError: 'Console requires 4 settings']. 
	levelName := values at: 2.

	(self validateLevel: levelName) isNil ifTrue: [^nil].

	self consoleAppender: values isAsync: false

! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 6/3/2013 18:02'!
checkForDailyRollingFileAppender

	| values levelName |

	(settings keys includes: 'dailyRollingFileAppender') ifFalse: [^self].

	(values := (settings at: 'dailyRollingFileAppender')) size ~= 9 ifTrue: [^EsLogLog logError: 'dailyRollingFileAppender requires 9 settings']. 

	levelName := values at: 5.
	(self validateLevel: levelName) isNil ifTrue: [^nil].

	self dailyRollingFileAppender: values isAsync: false

! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 6/3/2013 17:59'!
checkForFileAppender

	| values levelName |

	(settings keys includes: 'fileAppender') ifFalse: [^self].

	(values := (settings at: 'fileAppender')) size ~= 8 ifTrue: [^EsLogLog logError: 'FileAppender requires 8 settings']. 

	levelName := values at: 5.
	(self validateLevel: levelName) isNil ifTrue: [^nil].

	self fileAppender: values isAsync: false

! !

!EsLogManager methodsFor: 'ini file' stamp: 'LibrarySupervisor 6/23/2012 11:44'!
checkForFilters

	self
		checkForClassNameFilter;
		checkForLevelMatchFilter;
		checkForLevelRangeFilter;
		checkForStringMatchFilter! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 6/3/2013 18:00'!
checkForGlobalLevel

	| values levelName aLevel |

	(settings keys includes: 'globalLevel') ifFalse: [^EsLogLog logError: 'No setting found for globalLevel in ini file'].

	(values := (settings at: 'globalLevel')) isEmpty ifTrue: [^EsLogLog logError: 'No level found for globalLevel in ini file'].

	levelName := values.

	(aLevel := self validateLevel: levelName) isNil ifTrue: [^nil].

	self class level: aLevel.

	^self





! !

!EsLogManager methodsFor: 'ini file' stamp: 'LibrarySupervisor 7/12/2012 10:41'!
checkForLevelMatchFilter

	| values |

	(settings keys includes: 'levelMatchFilter') ifFalse: [^self].

	(values := (settings at: 'levelMatchFilter')) isEmpty ifTrue: [^self].

	^self levelMatchFilter: values! !

!EsLogManager methodsFor: 'ini file' stamp: 'LibrarySupervisor 7/12/2012 10:41'!
checkForLevelRangeFilter

	| values |

	(settings keys includes: 'levelRangeFilter') ifFalse: [^self].

	(values := (settings at: 'levelRangeFilter')) isEmpty ifTrue: [^self].

	^self levelRangeFilter: values! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 8/9/2012 13:56'!
checkForLogLogDebugEnabled

	| values debugEnabled errorMessage |

	EsLogLog debugEnabled: true.

	errorMessage := 'No true or false setting found for debugEnabled in ini file. Default is true'.  
	
	(settings keys includes: 'debugEnabled') ifFalse: [^EsLogLog debug: errorMessage].

	EsLogLog debugEnabled: (settings at: 'debugEnabled').

	^self! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 8/9/2012 13:56'!
checkForLogLogQuietMode

	| values quietMode errorMessage |

	EsLogLog quietMode: false.

	errorMessage := 'No true or false setting found for quietMode in ini file. Default is false'.

	(settings keys includes: 'quietMode') ifFalse: [^EsLogLog debug: errorMessage].

	EsLogLog quietMode: (settings at: 'quietMode').

	^self! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 6/3/2013 18:01'!
checkForNewLogger

	| value |

	(settings keys includes: 'createLogger') ifFalse: [^self].

	(value := (settings at: 'createLogger')) isEmpty ifTrue: [^EsLogLog logError: 'Loggers must have a name'].  
	
	self createLogger: value ! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 6/3/2013 17:59'!
checkForRollingFileAppender

	| values levelName |

	(settings keys includes: 'rollingFileAppender') ifFalse: [^self].

	(values := (settings at: 'rollingFileAppender')) size ~= 10 ifTrue: [^EsLogLog logError: 'RollingFileAppender requires 10 settings'].  

	levelName := values at: 5.
	(self validateLevel: levelName) isNil ifTrue: [^nil].

	self rollingFileAppender: values isAsync: false

! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 8/5/2012 18:55'!
checkForRunForeverParams

	"a complete hack, but suprisingly effective. I do love Smalltalk.
	
	runForever=(''60'', ''10'') will return an Association of 60 -> 10 and cause LogManager to call 'self logEventsFor: durationSeconds delay: delaySeconds' with the values of 60 and 10.
	logEventsFor:delay: will then run for 60 seconds and generate a LoggingEvent every 10 seconds.
	
	any setting of runForever that does not include two integers, or its absence in the ini file, will cause LogManager to call 'logEvents' which -will- run forever."

	| values duration delay |

	(settings keys includes: 'runForever') ifFalse: [^self].

	(values := (settings at: 'runForever')) isEmpty ifTrue: [^self].

	values size = 2 ifFalse: [^self].

	duration := (values at: 1) asNumber.
	delay := (values at: 2) asNumber.

	(delay > 0 and: [duration > 0]) ifTrue: [^Association key: duration value: delay].

	^self! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 8/5/2012 18:15'!
checkForRunForeverParams: localSettings

	"a complete hack, but suprisingly effective. I do love Smalltalk.
	
	runForever=(''60'', ''10'') will return an Association of 60 -> 10 and cause LogManager to call 'self logEventsFor: durationSeconds delay: delaySeconds' with the values of 60 and 10.
	logEventsFor:delay: will then run for 60 seconds and generate a LoggingEvent every 10 seconds.
	
	any setting of runForever that does not include two integers, or its absence in the ini file, will cause LogManager to call 'logEvents' which -will- run forever."

	| values duration delay |

	(localSettings keys includes: 'runForever') ifFalse: [^self].

	(values := self parseValue: (localSettings at: 'runForever')) isEmpty ifTrue: [^self].

	values size = 2 ifFalse: [^self].

	duration := (values at: 1) asNumber.
	delay := (values at: 2) asNumber.

	(delay > 0 and: [duration > 0]) ifTrue: [^Association key: duration value: delay].

	^self





! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 6/3/2013 18:02'!
checkForSocketAppender

	| values levelName |

	(settings keys includes: 'socketAppender') ifFalse: [^self].

	(values := (settings at: 'socketAppender')) size ~= 10 ifTrue: [^EsLogLog logError: 'socketAppender requires 10 settings'].  

	levelName := values at: 3.
	(self validateLevel: levelName) isNil ifTrue: [^nil].

	self socketAppender: values isAsync: false

! !

!EsLogManager methodsFor: 'ini file' stamp: 'LibrarySupervisor 7/12/2012 10:41'!
checkForStringMatchFilter

	| values |

	(settings keys includes: 'stringMatchFilter') ifFalse: [^self].

	(values := (settings at: 'stringMatchFilter')) isEmpty ifTrue: [^self].

	^self stringMatchFilter: values! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 6/7/2013 14:49'!
checkForTimeZoneOverride

	| values |

	(settings keys includes: 'timeZoneOverride') ifFalse: [^self].

	(values := (settings at: 'timeZoneOverride')) isEmpty ifTrue: [^self].

	^self timeZoneOverride: values! !

!EsLogManager methodsFor: 'ini file' stamp: 'LibrarySupervisor 6/27/2012 17:10'!
checkForTimeZoneOverrideAndFilters

	self
		checkForTimeZoneOverride;
		checkForFilters "check for filters after all the appenders have been created"





! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 6/3/2013 18:02'!
checkForTranscriptAppender

	| values levelName |

	(settings keys includes: 'transcriptAppender') ifFalse: [^self].

	(values := (settings at: 'transcriptAppender')) size ~= 4 ifTrue: [^EsLogLog logError: 'Transcript requires 4 settings'].  

	levelName := values at: 2.

	(self validateLevel: levelName) isNil ifTrue: [^nil].

	self transcriptAppender: values

! !

!EsLogManager methodsFor: 'filters' stamp: 'LibrarySupervisor 7/19/2012 17:0'!
classNameFilter: array

	"	1 - logger
		2 - appender
		3-  filter name
		4 - classNameToFilter
		5 - acceptOnMatch (optional)"

	| classNameFilter error filterName logger appender loggerName appenderName classNameToFilter
	  acceptOnMatch |

	error := false.
	acceptOnMatch := true.

	(loggerName := self getLoggerName: (array at: 1)) isNil ifTrue: [error := true].

	(logger := self getLogger: loggerName) isNil
		ifTrue: [
			EsLogLog noLoggerNamed: loggerName.
			^nil].

	(appenderName := self getAppenderName: (array at: 2)) isNil ifTrue: [error := true].

	(appender := logger getAppender: appenderName) isNil
		ifTrue: [
			EsLogLog noAppenderNamed: appenderName forLogger: loggerName.
			error := true].

	(filterName := self getFilterName: (array at: 3)) isNil ifTrue: [error := true].

	(classNameToFilter := self getClassName: (array at: 4)) isNil ifTrue: [error := true].

	error ifTrue: [^nil].

	array size = 5 ifTrue: [acceptOnMatch := (array at: 5)].

	classNameFilter :=
		EsClassNameFilter
			name: filterName
			classNameToFilter: classNameToFilter
			acceptOnMatch: acceptOnMatch.

	appender addFilter: classNameFilter

! !

!EsLogManager methodsFor: 'filters' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
clearFilters

	loggers do: [:each | each clearFilters]! !

!EsLogManager methodsFor: 'filters' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
clearLevels

	loggers do: [:each | each clearLevels]! !

!EsLogManager methodsFor: 'appenders' stamp: 'LibrarySupervisor 7/18/2012 13:14'!
consoleAppender: anArray isAsync: aBoolean

	"this method will be the one receiving the parameters from the ini file, checking them and then creating an ConsoleAppender if all is well"

	"
		1 - logger
		2 - threshold
		3-  patternConverter
		4 - layout
		5 - asyncAppenderName"

	| consoleAppender class error loggerName logger aPatternLayout aLevel asyncAppender
	  asyncAppenderIndex |

	error := false.
	asyncAppenderIndex := 5.

	(loggerName := self getLoggerName: (anArray at: 1)) isNil ifTrue: [error := true].

	(logger := self getLogger: loggerName) isNil
		ifTrue: [
			EsLogLog noLoggerNamed: loggerName.
			error := true].

	(aLevel := (self getLevel: (anArray at: 2))) isNil ifTrue: [error := true].

	(class := self getPatternLayout: (anArray at: 3)) isNil ifTrue: [error := true].

	aPatternLayout := (class new: (anArray at: 4)).

	error ifTrue: [^nil].

	consoleAppender := EsConsoleAppender level: aLevel layout: aPatternLayout.

	aBoolean
		ifTrue: [
			asyncAppender := self getAsyncAppender: anArray index: asyncAppenderIndex logger: logger.
			asyncAppender notNil
				ifTrue: [asyncAppender addAppender: consoleAppender]
				ifFalse: [consoleAppender close]]
		ifFalse: [logger addAppender: consoleAppender]


! !

!EsLogManager methodsFor: 'loggers' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
createLogger: aLoggerNameString

	| logger |

	logger := EsLogger new: aLoggerNameString.
	self addLogger: logger.
	^logger! !

!EsLogManager methodsFor: 'loggers' stamp: 'LibrarySupervisor 7/19/2012 13:30'!
createRootLogger

	^self createLogger: 'root'

! !

!EsLogManager methodsFor: 'appenders' stamp: 'DonaldMacQueen 8/1/2012 09:09'!
dailyRollingFileAppender: array isAsync: aBoolean

	"this method will be the one receiving the parameters from the ini file, checking them and then creating a DailyRollingFileAppender if all is well"

	"1 -  appender name
	2 - loggerName
	3 - fileName
	4 - fileAppend
	5 - level
	6 - layout
	7 - patternConverter
	8 - immediateFlush
	9 - datePattern 
	10 - asyncAppenderName"

	| dailyRollingFileAppender appenderName class error fileName fileAppend immediateFlush
	  asyncAppender loggerName logger aPatternLayout aLevel datePattern asyncAppenderIndex |

	error := false.
	asyncAppenderIndex := 10.

	(appenderName := self getAppenderName: (array at: 1)) isNil ifTrue: [error := true].

	(loggerName := self getLoggerName: (array at: 2)) isNil ifTrue: [error := true].

	(logger := self getLogger: loggerName) isNil
		ifTrue: [
			EsLogLog noLoggerNamed: loggerName.
			error := true].

	(fileName := self getFileName: (array at: 3)) isNil ifTrue: [error := true].

	fileAppend := array at: 4.

	(aLevel := (self getLevel: (array at: 5))) isNil ifTrue: [error := true].

	(class := self getPatternLayout: (array at: 6)) isNil ifTrue: [error := true].

	aPatternLayout := (class new: (array at: 7)).

	immediateFlush := array at: 8.
	datePattern := array at: 9.
	(EsDailyRollingFileAppender datePatterns keys includes: datePattern asLowercase)
		ifFalse: [
			EsLogLog error: ( 'Date pattern {1} not valid' format: datePattern). 
			error := true].

	error ifTrue: [^nil].

	dailyRollingFileAppender :=
		EsDailyRollingFileAppender
			name: appenderName
			layout: aPatternLayout
			threshold: aLevel
			fileName: fileName
			fileAppend: fileAppend
			immediateFlush: immediateFlush
			datePattern: datePattern.

	dailyRollingFileAppender isNil ifTrue: [^EsLogLog error: ( 'Creation of dailyRollingFileAppender named {1} failed' format: appenderName)].  

	aBoolean
		ifTrue: [
			asyncAppender := self getAsyncAppender: array index: asyncAppenderIndex logger: logger.
			asyncAppender notNil
				ifTrue: [asyncAppender addAppender: dailyRollingFileAppender]
				ifFalse: [dailyRollingFileAppender close]]
		ifFalse: [logger addAppender: dailyRollingFileAppender].

	^dailyRollingFileAppender

! !

!EsLogManager methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
exists: aLoggerNameString

	^(loggers at: aLoggerNameString ifAbsent: []) notNil! !

!EsLogManager methodsFor: 'appenders' stamp: 'DonaldMacQueen 6/5/2013 16:59'!
fileAppender: array isAsync: aBoolean

	"this method will be the one receiving the parameters from the ini file, checking them and then creating a FileAppender if all is well"

	"1 -  appender name
	2 - loggerName
	3 - fileName
	4 - fileAppend
	5 - level
	6 - layout
	7 - patternConverter
	8 - immediateFlush
	9 - asyncAppenderName"

	| fileAppender appenderName class error fileName fileAppend immediateFlush loggerName
	  asyncAppender logger aPatternLayout aLevel asyncAppenderIndex |

	error := false.
	asyncAppenderIndex := 9.

	(appenderName := self getAppenderName: (array at: 1)) isNil ifTrue: [error := true].

	(loggerName := self getLoggerName: (array at: 2)) isNil ifTrue: [error := true].

	(logger := self getLogger: loggerName) isNil
		ifTrue: [
			EsLogLog noLoggerNamed: loggerName.
			error := true].

	(fileName := self getFileName: (array at: 3)) isNil ifTrue: [error := true].

	fileAppend := array at: 4.

	(aLevel := (self getLevel: (array at: 5))) isNil ifTrue: [error := true].

	(class := self getPatternLayout: (array at: 6)) isNil ifTrue: [error := true].

	aPatternLayout := (class new: (array at: 7)).

	immediateFlush := array at: 8.

	error ifTrue: [^nil].

	fileAppender :=
		EsFileAppender
			name: appenderName
			layout: aPatternLayout
			threshold: aLevel
			fileName: fileName
			fileAppend: fileAppend
			immediateFlush: immediateFlush.

	fileAppender isNil ifTrue: [^EsLogLog logError: ( 'Creation of fileAppender named {1} failed' format: appenderName)]. 

	aBoolean
		ifTrue: [
			asyncAppender := self getAsyncAppender: array index: asyncAppenderIndex logger: logger.
			asyncAppender notNil
				ifTrue: [asyncAppender addAppender: fileAppender]
				ifFalse: [fileAppender close]]
		ifFalse: [logger addAppender: fileAppender].

	^fileAppender

! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 8/9/2012 21:44'!
fixBooleansAndIntegers2: anArray
	
| oc |

	oc := OrderedCollection new.

	anArray do: [:each |
		each isString 
			ifFalse: [oc add: each asNumber]
			ifTrue: [
				each = 'true'
					ifTrue: [oc add: true]
					ifFalse: [each = 'false' ifTrue: [oc add: false] ifFalse: [oc add: each]]]].

	^oc! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 8/9/2012 18:36'!
fixBooleansAndIntegers: anArray
	anArray isArray
		ifTrue: [ ^ self fixBooleansAndIntegers2: anArray ].
	anArray = 'true'
		ifTrue: [ ^ true ].
	anArray = 'false'
		ifTrue: [ ^ false ].
	^ anArray isString
		ifTrue: [ anArray ]
		ifFalse: [ anArray asNumber ]! !

!EsLogManager methodsFor: 'internal' stamp: 'DonaldMacQueen 6/3/2013 18:01'!
getAppenderName: aString

	(aString isString and: [aString notEmpty]) ifTrue: [^aString].

	^EsLogLog
		logError: ( 'Appender name {1} is not a string or is empty' format: aString)  ! !

!EsLogManager methodsFor: 'appenders' stamp: 'DonaldMacQueen 6/3/2013 18:00'!
getAsyncAppender: anArray index: index logger: logger

	| asyncAppender asyncAppenderName |

	asyncAppenderName := self getLoggerName: (anArray at: index).

	(asyncAppender := logger getAppender: asyncAppenderName) isNil
		ifTrue: [^EsLogLog logError: ('cannot find an asyncAppender named {1}' format: asyncAppenderName)]. 

	asyncAppender isAsyncAppender ifFalse: [^nil].

	^asyncAppender

! !

!EsLogManager methodsFor: 'internal' stamp: 'DonaldMacQueen 6/3/2013 17:57'!
getClassName: aString

	(aString isString and: [aString notEmpty]) ifTrue: [^aString].

	^EsLogLog logError: ( 'Class name {1} is not a string or is empty' format: aString) ! !

!EsLogManager methodsFor: 'internal' stamp: 'DonaldMacQueen 6/3/2013 17:59'!
getFileName: aString

	(aString isString and: [aString notEmpty]) ifTrue: [^aString].

	^EsLogLog logError: ( 'File name {1} is not a string or is empty' format: aString) ! !

!EsLogManager methodsFor: 'internal' stamp: 'DonaldMacQueen 6/3/2013 17:57'!
getFilterName: aString

	(aString isString and: [aString notEmpty]) ifTrue: [^aString].
	
	^EsLogLog logError: ( 'Filter name {1} is not a string or is empty' format: aString)  ! !

!EsLogManager methodsFor: 'accessing' stamp: 'DonaldMacQueen 6/3/2013 18:01'!
getLevel: aString

	| aLevel |

	(aLevel := EsLevel levelNamed: aString) notNil ifTrue: [^aLevel].

	^EsLogLog logError: ('{1} is not the name of a level' format: aString) ! !

!EsLogManager methodsFor: 'loggers' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
getLogger: aLoggerNameString

	^loggers at: aLoggerNameString ifAbsent: []! !

!EsLogManager methodsFor: 'internal' stamp: 'DonaldMacQueen 6/3/2013 18:02'!
getLoggerName: aString

	(aString isString and: [aString notEmpty]) ifTrue: [^aString].

	^EsLogLog logError: ('Logger name {1} is not a string or is empty'  format: aString)  ! !

!EsLogManager methodsFor: 'internal' stamp: 'DonaldMacQueen 6/3/2013 17:59'!
getName: aString text: errString

	(aString isString and: [aString notEmpty]) ifTrue: [^aString].

	^EsLogLog logError: ('{1} name %2 is not a string or is empty' format: errString with: aString)  ! !

!EsLogManager methodsFor: 'internal' stamp: 'DonaldMacQueen 6/5/2013 16:58'!
getPatternLayout: aString

	| class |

	aString isNil ifTrue: [^EsLogLog logError: ('Pattern name cannot be nil' )]. 
	aString isString ifFalse: [^EsLogLog logError: ('Pattern name {1} is not a string or is empty' format: aString)]. 

	aString isEmpty ifTrue: [^EsPatternLayout].

	(class := Smalltalk at: aString asSymbol ifAbsent: []) isNil
		ifTrue: [^EsLogLog noPatternLayoutNamed: aString].

	^class! !

!EsLogManager methodsFor: 'internal' stamp: 'DonaldMacQueen 6/3/2013 17:59'!
getStringToMatch: aString

	(aString isString and: [aString notEmpty]) ifTrue: [^aString].

	^EsLogLog
		logError: ('String to match {1} is not a string or is empty' format: aString) ! !

!EsLogManager methodsFor: 'internal' stamp: 'DonaldMacQueen 6/7/2013 14:48'!
getTimeZoneName: aString

	^TimeZone abbreviated: aString! !

!EsLogManager methodsFor: 'appenders' stamp: 'LibrarySupervisor 6/24/2012 9:56'!
inMemoryAppender: array

	"this method will be the one receiving the parameters from the ini file, checking them and then creating an InMemoryAppender if all is well"

	"1 - appenderName
		2 - logger
		3 - threshold
		4-  layout
		5 - patternConverter"

	| inMemoryAppender appenderName class error loggerName logger aPatternLayout aLevel |

	error := false.

	(appenderName := self getAppenderName: (array at: 1)) isNil ifTrue: [error := true].

	(loggerName := self getLoggerName: (array at: 2)) isNil ifTrue: [error := true].

	(logger := self getLogger: loggerName) isNil
		ifTrue: [
			EsLogLog noLoggerNamed: loggerName.
			error := true].

	(aLevel := (self getLevel: (array at: 3))) isNil ifTrue: [error := true].

	(class := self getPatternLayout: (array at: 4)) isNil ifTrue: [error := true].

	aPatternLayout := (class new: (array at: 5)).

	error ifTrue: [^nil].

	inMemoryAppender := EsInMemoryAppender name: appenderName level: aLevel layout: aPatternLayout.

	logger addAppender: inMemoryAppender.

	^inMemoryAppender

! !

!EsLogManager methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
level

	^level! !

!EsLogManager methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
level: anObject

	^level := anObject! !

!EsLogManager methodsFor: 'filters' stamp: 'LibrarySupervisor 7/19/2012 17:0'!
levelMatchFilter: array

	"	1 - logger
		2 - appender
		3-  filter name
		4 - level
		5 - acceptOnMatch (optional)"

	| levelMatchFilter error filterName logger appender loggerName acceptOnMatch appenderName
	  levelToMatch |

	error := false.
	acceptOnMatch := true.

	(loggerName := self getLoggerName: (array at: 1)) isNil ifTrue: [error := true].

	(logger := self getLogger: loggerName) isNil
		ifTrue: [
			EsLogLog noLoggerNamed: loggerName.
			^nil].

	(appenderName := self getAppenderName: (array at: 2)) isNil ifTrue: [error := true].

	(appender := logger getAppender: appenderName) isNil
		ifTrue: [
			EsLogLog noAppenderNamed: appenderName forLogger: loggerName.
			error := true].

	(filterName := self getFilterName: (array at: 3)) isNil ifTrue: [error := true].

	(levelToMatch := self getLevel: (array at: 4)) isNil ifTrue: [error := true].

	error ifTrue: [^nil].

	array size = 5 ifTrue: [acceptOnMatch := (array at: 5)].

	levelMatchFilter :=
		EsLevelMatchFilter name: filterName levelToMatch: levelToMatch acceptOnMatch: acceptOnMatch.

	appender addFilter: levelMatchFilter

! !

!EsLogManager methodsFor: 'filters' stamp: 'LibrarySupervisor 7/19/2012 17:0'!
levelRangeFilter: array

	"	1 - logger
		2 - appender
		3-  filter name
		4 - firstLevel
		5 - secondLevel
		6 - acceptOnMatch (optional)"

	| levelRangeFilter error filterName logger appender loggerName acceptOnMatch appenderName
	  firstLevel secondLevel |

	error := false.
	acceptOnMatch := true.

	(loggerName := self getLoggerName: (array at: 1)) isNil ifTrue: [error := true].

	(logger := self getLogger: loggerName) isNil
		ifTrue: [
			EsLogLog noLoggerNamed: loggerName.
			^nil].

	(appenderName := self getAppenderName: (array at: 2)) isNil ifTrue: [error := true].

	(appender := logger getAppender: appenderName) isNil
		ifTrue: [
			EsLogLog noAppenderNamed: appenderName forLogger: loggerName.
			error := true].

	(filterName := self getFilterName: (array at: 3)) isNil ifTrue: [error := true].

	(firstLevel := self getLevel: (array at: 4)) isNil ifTrue: [error := true].

	(secondLevel := self getLevel: (array at: 5)) isNil ifTrue: [error := true].

	error ifTrue: [^nil].

	array size = 6 ifTrue: [acceptOnMatch := (array at: 6)].

	levelRangeFilter :=
		EsLevelRangeFilter
			name: filterName
			lowLevel: firstLevel
			highLevel: secondLevel
			acceptOnMatch: acceptOnMatch.

	appender addFilter: levelRangeFilter

! !

!EsLogManager methodsFor: 'logging' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
log: msg level: aLevel

	self rootLogger log: msg level: aLevel! !

!EsLogManager methodsFor: 'logging' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
log: msg level: aLevel locationInfo: locationInfo

	self rootLogger log: msg level: aLevel locationInfo: locationInfo! !

!EsLogManager methodsFor: 'logging' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
log: msg level: aLevel locationInfo: locationInfo object: anObject

	self rootLogger log: msg level: aLevel locationInfo: locationInfo object: anObject! !

!EsLogManager methodsFor: 'logging' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
log: msg level: aLevel object: anObject

	self rootLogger log: msg level: aLevel object: anObject! !

!EsLogManager methodsFor: 'loggers' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
loggerNamed: aLoggerNameString

	"same as getLogger:"

	^loggers at: aLoggerNameString ifAbsent: []! !

!EsLogManager methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/1/2012 11:41'!
loggers

	loggers isNil ifTrue: [loggers := Dictionary new].
	^loggers! !

!EsLogManager methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
loggers: anObject

	loggers := anObject! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 6/3/2013 18:01'!
parseValue: aString
	| subStrings singleValueEntries |
	singleValueEntries := #('debugEnabled' 'quietMode' 'globalLevel').	"parse a string  like '(string1, integer, boolean)' and and return string1, integer, and boolean in an array"
	(singleValueEntries includes: aString)
		ifFalse: [ 
			(aString first = $( and: [ aString last = $) ])
				ifFalse: [ ^ EsLogLog logError: 'Ini file values must be enclosed in parentheses' ] ].
	subStrings := (aString copyFrom: 2 to: aString size - 1) subStrings: ','.
	subStrings := subStrings collect: [ :each | each trimBoth ].
	^ self
		fixBooleansAndIntegers:
			(subStrings
				collect: [ :each | 
					(each first = $' and: [ each last = $' ])
						ifTrue: [ each copyFrom: 2 to: each size - 1 ]
						ifFalse: [ each ] ])! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 8/11/2012 17:16'!
parseValue: aString for: aKey
	| subStrings  |
	
"parse a string  like '(string1, integer, boolean)' and and return string1, integer, and boolean in an array"

	(aString findString: ',') > 0 ifFalse: [ ^ self fixBooleansAndIntegers: ((aString trimBoth) trimBoth: [:each | each = $']) ].
		
 subStrings := aString  subStrings: ',' .
		
		"dq	(aString first = $( and: [ aString last = $) ])
		ifTrue: [ subStrings := (aString copyFrom: 2 to: aString size - 1) subStrings: ',' ]
		ifFalse: [ ^ EsLogLog error: 'Ini file values must be enclosed in parentheses' ]."
		
	subStrings := subStrings collect: [ :each | each trimBoth ].	"remove the quotes"
	^ self
		fixBooleansAndIntegers:
			(subStrings
				collect: [ :each | 
					(each first = $' and: [ each last = $' ])
						ifTrue: [ each copyFrom: 2 to: each size - 1 ]
						ifFalse: [ each ] ])! !

!EsLogManager methodsFor: 'printing' stamp: 'DonaldMacQueen 8/1/2012 10:31'!
printFiltersOn: aStream

	loggers isEmpty
		ifTrue: [aStream nextPutAll: 'no loggers']  
		ifFalse: [
			loggers do: [:each |
				aStream
					nextPutAll: each printString;
					cr]]! !

!EsLogManager methodsFor: 'printing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
printOn: aStream

	aStream
		nextPutAll: self class name , ' ' , level printString;
		cr.

	self printFiltersOn: aStream! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 8/9/2012 22:22'!
processIniFile
	self
		checkForLogLogDebugEnabled;
		checkForLogLogQuietMode;
		checkForGlobalLevel;
		checkForNewLogger;
		checkForAsyncAppender;
		checkForTranscriptAppender;
		checkForConsoleAppender;
		readFileAppenderIniFile;
		readSocketAppenderIniFile;
		checkForTimeZoneOverrideAndFilters.
	^ self checkForRunForeverParams! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 8/10/2012 09:35'!
readFileAppenderIniFile

	self
		checkForFileAppender;
		checkForRollingFileAppender;
		checkForDailyRollingFileAppender;
		checkForAsyncFileAppender;
		checkForAsyncRollingFileAppender;
		checkForAsyncDailyRollingFileAppender

! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 6/7/2013 17:19'!
readIniFile
	| stream |
	('log4s.ini' asFileReference exists)
		ifFalse: [ ^ self ].
	stream := FileStream readOnlyFileNamed: 'log4s.ini'.
	self readIniFileFrom: stream.
	stream close.
	! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 6/3/2013 18:02'!
readIniFileFrom: aStream
	"this method will return self | nil | anAssociation
	nil is an error.
	self means that there are no runForever params.
	anAssociation means that runForever params have been found."

	| contents string line |
	line := aStream nextLine.
	line ~= '[log4s]'
		ifTrue: [ ^ EsLogLog logError: 'the first line of the ini file must be [log4s]' ].
	[ aStream atEnd ]
		whileFalse: [ 
			| subStrings pos |			
			line := aStream nextLine.
			line isEmpty ifFalse: [	line first = $;
				ifFalse: [ 
					pos := line findString: '='.
					pos > 0
						ifTrue: [ | key  | key := line copyFrom: 1 to: pos - 1. settings at: key put: (self parseValue: (line copyFrom: pos + 1 to: line size) for: key) ] ] ].
		].
	self
		processIniFile
	! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 8/10/2012 09:35'!
readSocketAppenderIniFile

	self
		checkForAsyncSocketAppender;
		checkForSocketAppender! !

!EsLogManager methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/1/2012 11:40'!
removeAllLoggers

	loggers := Dictionary new! !

!EsLogManager methodsFor: 'appenders' stamp: 'DonaldMacQueen 8/1/2012 09:38'!
rollingFileAppender: array isAsync: aBoolean

	"this method will be the one receiving the parameters from the ini file, checking them and then creating a RollingFileAppender if all is well"

	"1 -  appender name
	2 - loggerName
	3 - fileName
	4 - fileAppend
	5 - level
	6 - layout
	7 - patternConverter
	8 - immediateFlush
	9 - maxFileSize
	10 -  maxBackupIndex
	11 - asyncAppenderName"

	| rollingFileAppender appenderName class error fileName fileAppend immediateFlush asyncAppender
	  loggerName logger maxFileSize maxBackupIndex aLevel aPatternLayout asyncAppenderIndex |

	error := false.
	asyncAppenderIndex := 11.

	(appenderName := self getAppenderName: (array at: 1)) isNil ifTrue: [error := true].

	(loggerName := self getLoggerName: (array at: 2)) isNil ifTrue: [error := true].

	(logger := self getLogger: loggerName) isNil
		ifTrue: [
			EsLogLog noLoggerNamed: loggerName.
			error := true].

	(fileName := self getFileName: (array at: 3)) isNil ifTrue: [error := true].

	fileAppend := array at: 4.

	(aLevel := (self getLevel: (array at: 5))) isNil ifTrue: [error := true].

	(class := self getPatternLayout: (array at: 6)) isNil ifTrue: [error := true].

	aPatternLayout := (class new: (array at: 7)).

	immediateFlush := array at: 8.
	maxFileSize := array at: 9.
	maxBackupIndex := array at: 10.

	error ifTrue: [^nil].

	rollingFileAppender :=
		EsRollingFileAppender
			name: appenderName
			layout: aPatternLayout
			threshold: aLevel
			fileName: fileName
			fileAppend: fileAppend
			immediateFlush: immediateFlush
			maxFileSize: maxFileSize
			maxBackupIndex: maxBackupIndex.

	rollingFileAppender isNil ifTrue: [^EsLogLog error: ('Creation of rollingFileAppender named {1} failed' format: appenderName)]. 

	aBoolean
		ifTrue: [
			asyncAppender := self getAsyncAppender: array index: asyncAppenderIndex logger: logger.
			asyncAppender notNil
				ifTrue: [asyncAppender addAppender: rollingFileAppender]
				ifFalse: [rollingFileAppender close]]
		ifFalse: [logger addAppender: rollingFileAppender].

	^rollingFileAppender

! !

!EsLogManager methodsFor: 'loggers' stamp: 'LibrarySupervisor 7/19/2012 13:39'!
rootLogger

	| rootLogger |

	rootLogger := self getLogger: 'root'.

	rootLogger isNil ifTrue: [rootLogger := self createLogger: 'root'].

	^rootLogger! !

!EsLogManager methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/22/2012 16:9'!
settings

	^settings! !

!EsLogManager methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2012 9:8'!
settings: anObject

	settings := anObject! !

!EsLogManager methodsFor: 'actions' stamp: 'LibrarySupervisor 4/5/2012 19:34'!
shutDown

	loggers do: [:each | each shutDown].
	self removeAllLoggers

! !

!EsLogManager methodsFor: 'appenders' stamp: 'DonaldMacQueen 8/1/2012 09:39'!
socketAppender: anArray isAsync: aBoolean

	"this method will be the one receiving the parameters from the ini file, checking them and then creating a SocketAppender if all is well"

	"1 -  appender name
	2 - loggerName
	3 - level
	4 - layout
	5 - patternConverter
	6 - address
	7 - hostName
	8 -  port
	9 - retryCount
	10 - retrySeconds
	11 - asyncAppenderName"

	| socketAppender class error address remoteHost loggerName appenderName port logger asyncAppender
	  retryCount retrySeconds asyncAppenderIndex aPatternLayout aLevel |

	error := false.
	asyncAppenderIndex := 11.

	(appenderName := self getAppenderName: (anArray at: 1)) isNil ifTrue: [error := true].

	(loggerName := self getLoggerName: (anArray at: 2)) isNil ifTrue: [error := true].

	(logger := self getLogger: loggerName) isNil
		ifTrue: [
			EsLogLog noLoggerNamed: loggerName.
			error := true].

	(aLevel := (self getLevel: (anArray at: 3))) isNil ifTrue: [error := true].

	(class := self getPatternLayout: (anArray at: 4)) isNil ifTrue: [error := true].

	aPatternLayout := (class new: (anArray at: 5)).

	address := anArray at: 6.
	remoteHost := anArray at: 7.
	port := (anArray at: 8) asNumber.

	(retryCount := (anArray at: 9) asInteger) < 0 ifTrue: [error := true].

	(retrySeconds := (anArray at: 10) asInteger) < 0 ifTrue: [error := true].

	(address isEmpty and: [remoteHost isEmpty])
		ifTrue: [
			EsLogLog error: 'Must have either an address or a hostname string'.
			error := true].

	error ifTrue: [^nil].

	socketAppender :=
		address notEmpty
			ifTrue: [
				EsSocketAppender
					name: loggerName
					layout: aPatternLayout
					level: aLevel
					address: address
					port: port
					retryCount: retryCount
					retrySeconds: retrySeconds]
			ifFalse: [
				EsSocketAppender
					name: loggerName
					layout: aPatternLayout
					level: aLevel
					host: remoteHost
					port: port
					retryCount: retryCount
					retrySeconds: retrySeconds].

	socketAppender isNil ifTrue: [^EsLogLog error: ('Creation of socketAppender named {1} failed' format: appenderName)]. 

	aBoolean
		ifTrue: [
			asyncAppender := self getAsyncAppender: anArray index: asyncAppenderIndex logger: logger.
			asyncAppender notNil
				ifTrue: [asyncAppender addAppender: socketAppender]
				ifFalse: [socketAppender close]]
		ifFalse: [logger addAppender: socketAppender]


! !

!EsLogManager methodsFor: 'filters' stamp: 'LibrarySupervisor 7/19/2012 17:0'!
stringMatchFilter: array

	"		1 - logger
		2 - appender
		3-  filter name
		4 - stringToMatch
		5 - acceptOnMatch
		6 - ignoreCase"

	| stringMatchFilter error filterName logger appender acceptOnMatch loggerName ignoreCase
	  appenderName stringToMatch |

	error := false.

	(loggerName := self getLoggerName: (array at: 1)) isNil ifTrue: [error := true].

	(logger := self getLogger: loggerName) isNil
		ifTrue: [
			EsLogLog noLoggerNamed: loggerName.
			^nil].

	(appenderName := self getAppenderName: (array at: 2)) isNil ifTrue: [error := true].

	(appender := logger getAppender: appenderName) isNil
		ifTrue: [
			EsLogLog noAppenderNamed: appenderName forLogger: loggerName.
			error := true].

	(filterName := self getFilterName: (array at: 3)) isNil ifTrue: [error := true].

	(stringToMatch := self getStringToMatch: (array at: 4)) isNil ifTrue: [error := true].

	acceptOnMatch := array at: 5.
	ignoreCase := array at: 6.

	error ifTrue: [^nil].

	stringMatchFilter :=
		EsStringMatchFilter
			name: filterName
			stringToMatch: stringToMatch
			acceptOnMatch: acceptOnMatch
			ignoreCase: ignoreCase.

	appender addFilter: stringMatchFilter



! !

!EsLogManager methodsFor: 'time zone' stamp: 'DonaldMacQueen 6/7/2013 14:48'!
timeZoneOverride: array
	
	"	1 - logger
		2 - appender
		3-  time zone name"

	| logger appender loggerName appenderName timeZoneName |

	loggerName := self getLoggerName: (array at: 1).

	(logger := self getLogger: loggerName) isNil
		ifTrue: [
			EsLogLog noLoggerNamed: loggerName.
			^nil].

	(appenderName := self getAppenderName: (array at: 2)) isNil ifTrue: [^nil].

	(appender := logger getAppender: appenderName) isNil
		ifTrue: [
			EsLogLog noAppenderNamed: appenderName forLogger: loggerName.
			^nil].

	(timeZoneName := self getTimeZoneName: (array at: 3)) isNil ifTrue: [^nil].

	appender
		setTimeZone: timeZoneName;
		yourself
! !

!EsLogManager methodsFor: 'appenders' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
transcriptAppender: anArray

	"this method will be the one receiving the parameters from the ini file, checking them and then creating an TranscriptAppender if all is well"

	"	1 - logger
		2 - threshold
		3-  layout
		4 - patternConverter"

	| transcriptAppender class error loggerName logger aPatternLayout aLevel |

	error := false.

	(loggerName := self getLoggerName: (anArray at: 1)) isNil ifTrue: [error := true].

	(logger := self getLogger: loggerName) isNil
		ifTrue: [
			EsLogLog noLoggerNamed: loggerName.
			error := true].

	(aLevel := (self getLevel: (anArray at: 2))) isNil ifTrue: [error := true].

	(class := self getPatternLayout: (anArray at: 3)) isNil ifTrue: [error := true].

	aPatternLayout := (class new: (anArray at: 4)).

	error ifTrue: [^nil].

	transcriptAppender := EsTranscriptAppender level: aLevel layout: aPatternLayout.

	logger addAppender: transcriptAppender.

	^transcriptAppender

! !

!EsLogManager methodsFor: 'ini file' stamp: 'DonaldMacQueen 6/3/2013 17:59'!
validateLevel: levelName

	| aLevel |

	aLevel := EsLevel levelByName: levelName.
	^aLevel isNil
		ifTrue: [EsLogLog logError: ('{1} is not the name of a valid Level' format: levelName)] 
		ifFalse: [aLevel]

! !

Object subclass: #EsLogger
	instanceVariableNames: 'name appenders'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s'!

!EsLogger class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 7/19/2011 8:47'!
new: aString

	^(self new)
		new: aString;
		yourself! !

!EsLogger methodsFor: 'appenders' stamp: 'LibrarySupervisor 6/23/2011 13:45'!
addAppender: anAppender

	(appenders at: anAppender name ifAbsent: []) isNil
		ifTrue: [
			appenders at: anAppender name put: anAppender.
			^anAppender]
		ifFalse: [^nil]! !

!EsLogger methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
allAppenders

	^appenders values! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 20:47'!
clearFilters

	appenders do: [:each | each clearFilters]! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 22:26'!
clearLevels

	appenders do: [:each | each clearLevels]! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:45'!
debug: msg

	EsLevel Debug >= self globalLevel
		ifTrue: [self forcedLog: nil level: EsLevel Debug msg: msg object: nil]

! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
debug: msg locationInfo: locationInfo

	EsLevel Debug >= self globalLevel
		ifTrue: [self forcedLog: locationInfo level: EsLevel Debug msg: msg object: nil]

! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
debug: msg locationInfo: locationInfo object: anObject

	(EsLevel Debug >= self globalLevel)
		ifTrue: [self forcedLog: locationInfo level: EsLevel Debug msg: msg object: anObject]

! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:45'!
debug: msg object: anObject

	(EsLevel Debug >= self globalLevel)
		ifTrue: [self forcedLog: nil level: EsLevel Debug msg: msg object: anObject]

! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
error: msg

	EsLevel Error >= self globalLevel
		ifTrue: [self forcedLog: nil level: EsLevel Error msg: msg object: nil]

! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
error: msg locationInfo: locationInfo

	EsLevel Error >= self globalLevel
		ifTrue: [self forcedLog: locationInfo level: EsLevel Error msg: msg object: nil]

! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:45'!
error: msg locationInfo: locationInfo object: anObject

	(EsLevel Error >= self globalLevel)
		ifTrue: [self forcedLog: locationInfo level: EsLevel Error msg: msg object: anObject]

! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:45'!
error: msg object: anObject

	(EsLevel Error >= self globalLevel)
		ifTrue: [self forcedLog: nil level: EsLevel Error msg: msg object: anObject]

! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 6/24/2012 20:24'!
forcedLog: locationInfo level: aLevel msg: msg object: anObject

	| aLoggingEvent |

	aLoggingEvent :=
		EsLoggingEvent
			logger: self
			locationInfo: locationInfo
			level: aLevel
			message: msg
			object: anObject.

	appenders do: [:each | each doAppend: aLoggingEvent]

! !

!EsLogger methodsFor: 'appenders' stamp: 'LibrarySupervisor 6/23/2011 13:45'!
getAppender: aString

	^appenders at: aString ifAbsent: []! !

!EsLogger methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
getLevel: aString

	^EsLogManager getLevel: aString! !

!EsLogger methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
globalLevel

	^EsLogManager level! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:45'!
info: msg

	EsLevel Info >= self globalLevel
		ifTrue: [self forcedLog: nil level: EsLevel Info msg: msg object: nil]

! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
info: msg locationInfo: locationInfo

	EsLevel Info >= self globalLevel
		ifTrue: [self forcedLog: locationInfo level: EsLevel Info msg: msg object: nil]

! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:45'!
info: msg locationInfo: locationInfo object: anObject

	EsLevel Info >= self globalLevel
		ifTrue: [self forcedLog: locationInfo level: EsLevel Info msg: msg object: anObject]

! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:45'!
info: msg object: anObject

	EsLevel Info >= self globalLevel
		ifTrue: [self forcedLog: nil level: EsLevel Info msg: msg object: anObject]

! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 6/24/2012 20:26'!
log: aLoggingEvent

	(aLoggingEvent level >= self globalLevel)
		ifTrue: [appenders do: [:each | each doAppend: aLoggingEvent]]

! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
log: msg level: aLevel

	aLevel >= self globalLevel ifTrue: [self forcedLog: nil level: aLevel msg: msg object: nil]

! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
log: msg level: aLevel locationInfo: locationInfo

	aLevel >= self globalLevel
		ifTrue: [self forcedLog: locationInfo level: aLevel msg: msg object: nil]

! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:45'!
log: msg level: aLevel locationInfo: locationInfo object: anObject

	aLevel >= self globalLevel
		ifTrue: [self forcedLog: locationInfo level: aLevel msg: msg object: anObject]

! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:45'!
log: msg level: aLevel object: anObject

	aLevel >= self globalLevel ifTrue: [self forcedLog: nil level: aLevel msg: msg object: anObject]

! !

!EsLogger methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:45'!
name

	^name! !

!EsLogger methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
name: anObject

	name := anObject! !

!EsLogger methodsFor: 'initialize' stamp: 'LibrarySupervisor 6/23/2011 13:45'!
new: aString

	name := aString.
	appenders := Dictionary new! !

!EsLogger methodsFor: 'printing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
printOn: aStream

	aStream
		nextPutAll: name;
		cr

! !

!EsLogger methodsFor: 'appenders' stamp: 'LibrarySupervisor 8/14/2011 14:22'!
removeAllAppenders

	appenders do: [:each | each shutDown].
	appenders := Dictionary new! !

!EsLogger methodsFor: 'appenders' stamp: 'LibrarySupervisor 8/14/2011 14:46'!
removeAppender: anAppender

	appenders at: anAppender name ifPresent: [:appender | appender shutDown].

	^appenders removeKey: anAppender name ifAbsent: []! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
rootLogger

	^EsLogManager rootLogger! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
rootLoggerLevel

	^EsLogManager rootLogger level! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 7/6/2011 22:58'!
shutDown

	appenders do: [:each | each shutDown]! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
warn: msg

	EsLevel Warn >= self globalLevel
		ifTrue: [self forcedLog: nil level: EsLevel Warn msg: msg object: nil]

! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:45'!
warn: msg locationInfo: locationInfo

	EsLevel Warn >= self globalLevel
		ifTrue: [self forcedLog: locationInfo level: EsLevel Warn msg: msg object: nil]

! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:45'!
warn: msg locationInfo: locationInfo object: anObject

	EsLevel Warn >= self globalLevel
		ifTrue: [self forcedLog: locationInfo level: EsLevel Warn msg: msg object: anObject]

! !

!EsLogger methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:45'!
warn: msg object: anObject

	EsLevel Warn >= self globalLevel
		ifTrue: [self forcedLog: nil level: EsLevel Warn msg: msg object: anObject]

! !

Object subclass: #EsLoggingEvent
	instanceVariableNames: 'logger object className methodName timeStamp level message threadName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s'!

!EsLoggingEvent class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 7/19/2011 8:47'!
logger: aLogger locationInfo: anAssociation level: aLevel message: aString object: object

	^(self new)
		logger: aLogger locationInfo: anAssociation level: aLevel message: aString object: object;
		yourself! !

!EsLoggingEvent class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 19:4'!
startTime

	^EsLogManager startTime! !

!EsLoggingEvent methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
className

	^className! !

!EsLoggingEvent methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
className: anObject

	className := anObject! !

!EsLoggingEvent methodsFor: 'actions' stamp: 'LibrarySupervisor 1/19/2012 11:0'!
fixMessage

	message isString ifFalse: [message := message value asString]! !

!EsLoggingEvent methodsFor: 'actions' stamp: 'DonaldMacQueen 6/7/2013 16:45'!
fixTimeStamp: aTimeZone
 
	timeStamp transformTo:  aTimeZone ! !

!EsLoggingEvent methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
level

	^level! !

!EsLoggingEvent methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
level: anObject

	level := anObject! !

!EsLoggingEvent methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
logger

	^logger! !

!EsLoggingEvent methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
logger: anObject

	logger := anObject! !

!EsLoggingEvent methodsFor: 'initialize' stamp: 'DonaldMacQueen 8/8/2012 11:04'!
logger: aLogger locationInfo: context level: aLevel message: aString

	logger := aLogger. 
	className := context method methodClass name.
	methodName := context  method selector.
	timeStamp := DateAndTime now.
	level := aLevel.
	message := aString
! !

!EsLoggingEvent methodsFor: 'initialize' stamp: 'DonaldMacQueen 8/8/2012 11:04'!
logger: aLogger locationInfo: context level: aLevel message: aString object: anObject
	level := aLevel.
	object := anObject.
	logger := aLogger.
	message := aString.
	timeStamp := DateAndTime now. 
	context notNil
		ifTrue: [ 
			className := context method methodClass name.
			methodName := context method selector ].
		threadName := Processor activeProcess name! !

!EsLoggingEvent methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
message

	^message! !

!EsLoggingEvent methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
message: anObject

	message := anObject! !

!EsLoggingEvent methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
methodName

	^methodName! !

!EsLoggingEvent methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
methodName: anObject

	methodName := anObject! !

!EsLoggingEvent methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
object

	^object! !

!EsLoggingEvent methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/7/2011 9:3'!
object: anObject

	object := anObject! !

!EsLoggingEvent methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:44'!
startTime

	^self class startTime! !

!EsLoggingEvent methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
threadName

	^threadName! !

!EsLoggingEvent methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
threadName: anObject

	threadName := anObject! !

!EsLoggingEvent methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
timeStamp

	^timeStamp! !

!EsLoggingEvent methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
timeStamp: anObject

	timeStamp := anObject! !

Object subclass: #EsPatternConverter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Converters'!

EsPatternConverter class
	instanceVariableNames: 'singleton'!

EsPatternConverter class
	instanceVariableNames: 'singleton'!

EsPatternConverter subclass: #EsClassNamePatternConverter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Converters'!

!EsClassNamePatternConverter methodsFor: 'actions' stamp: 'DonaldMacQueen 8/8/2012 11:09'!
format: aLoggingEvent buffer: string

	aLoggingEvent className isNil ifTrue: [^string].
	^string , aLoggingEvent className! !

EsPatternConverter subclass: #EsDatePatternConverter
	instanceVariableNames: 'options printDateFirst dateFormat timeFormat printCombos'
	classVariableNames: 'DateFormatConversions FormatSelectors LowerToUppercaseMap TimeFormatConversions UpperToLowercaseMap'
	poolDictionaries: ''
	category: 'Log4s-Converters'!

!EsDatePatternConverter class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:34'!
DateFormatConversions

	DateFormatConversions isNil ifTrue: [self initializeDateFormatConversions].
	^DateFormatConversions! !

!EsDatePatternConverter class methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/7/2012 20:53'!
FormatSelectors
	FormatSelectors isNil
		ifTrue: [ 
			(FormatSelectors := Array new: 52)
				at: $A digitValue - 9 + 26 put: #formata:date:time:;
				at: $A digitValue - 9 put: #formatA:date:time:;
				at: $B digitValue - 9 + 26 put: #formatb:date:time:;
				at: $B digitValue - 9 put: #formatB:date:time:;
				at: $C digitValue - 9 put: #formatC:date:time:;
				at: $D digitValue - 9 put: #formatD:date:time:;
				at: $D digitValue - 9 + 26 put: #formatd:date:time:;
				at: $E digitValue - 9 + 26 put: #formate:date:time:;
				at: $F digitValue - 9 + 26 put: #formatf:date:time:;
				at: $H digitValue - 9 put: #formatH:date:time:;
				at: $I digitValue - 9 put: #formatI:date:time:;
				at: $J digitValue - 9 + 26 put: #formatj:date:time:;
				at: $K digitValue - 9 + 26 put: #formatk:date:time:;
				at: $L digitValue - 9 + 26 put: #formatl:date:time:;
				at: $M digitValue - 9 + 26 put: #formatm:date:time:;
				at: $M digitValue - 9 put: #formatM:date:time:;
				at: $N digitValue - 9 + 26 put: #formatn:date:time:;
				at: $P digitValue - 9 put: #formatP:date:time:;
				at: $P digitValue - 9 + 26 put: #formatp:date:time:;
				at: $R digitValue - 9 put: #formatR:date:time:;
				at: $S digitValue - 9 put: #formatS:date:time:;
				at: $T digitValue - 9 put: #formatT:date:time:;
				at: $T digitValue - 9 + 26 put: #formatt:date:time:;
				at: $U digitValue - 9 + 26 put: #formatu:date:time:;
				at: $W digitValue - 9 + 26 put: #formatw:date:time:;
				at: $X digitValue - 9 + 26 put: #formatx:date:time:;
				at: $X digitValue - 9 put: #formatX:date:time:;
				at: $Y digitValue - 9 + 26 put: #formaty:date:time:;
				at: $Y digitValue - 9 put: #formatY:date:time:;
				at: $Z digitValue - 9 + 26 put: #formatz:date:time:;
				at: $Z digitValue - 9 put: #formatZ:date:time: ].
	^ FormatSelectors! !

!EsDatePatternConverter class methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/2/2012 13:00'!
LowerToUppercaseMap
	"Answer the default upperToLowercaseMap used for upper to lowercase
	 conversion."

	LowerToUppercaseMap isNil
		ifTrue: [ 
			| uppercase lowercase map |
			uppercase := 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'.
			lowercase := 'abcdefghijklmnopqrstuvwxyz'.
			map := String new: 256.
			1 to: map size do: [ :i | map at: i put: (Character value: i - 1) ].
			lowercase with: uppercase do: [ :l :u | map at: l asciiValue + 1 put: u ].
			LowerToUppercaseMap := map ].
	^ LowerToUppercaseMap! !

!EsDatePatternConverter class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:34'!
TimeFormatConversions

	TimeFormatConversions isNil ifTrue: [self initializeTimeFormatConversions].
	^TimeFormatConversions! !

!EsDatePatternConverter class methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/2/2012 13:04'!
UpperToLowercaseMap
	UpperToLowercaseMap isNil
		ifTrue: [ 
			| uppercase lowercase map |
			uppercase := 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'.	 
			lowercase := 'abcdefghijklmnopqrstuvwxyz'.	 
			map := String new: 256.
			1 to: map size do: [ :i | map at: i put: (Character value: i - 1) ].
			uppercase with: lowercase do: [ :u :l | map at: u asciiValue + 1 put: l ]. UpperToLowercaseMap := map ].
	^ UpperToLowercaseMap! !

!EsDatePatternConverter class methodsFor: 'initialize' stamp: 'DonaldMacQueen 8/1/2012 11:41'!
initializeDateFormatConversions

	"self initializeDateFormatConversions"

	DateFormatConversions := Dictionary new. "date formats"

	"month. use long form if pattern is 4+ in length"
	DateFormatConversions at: 'MMM' put: '%b'. "Month, using locale's abbreviated month names"
	DateFormatConversions at: 'MMMM' put: '%B'. "Month, using locale's full month names"
	DateFormatConversions at: 'MMMMM' put: '%B'. "Month, using locale's full month names. just in case"

	DateFormatConversions at: 'MM' put: '%m'. "Month number (01-12)"
	DateFormatConversions at: 'M' put: '%z'. "Month number (1-12) no leading zeros"

	DateFormatConversions at: 'dd' put: '%d'. "Day of month (01-31)"
	DateFormatConversions at: 'd' put: '%e'. "Day of month (1-31, single digits preceded by a space)"
	DateFormatConversions at: 'f' put: '%f'. "Day of month (1-31) no leading zeros "

	DateFormatConversions at: 'u' put: '%u'. "day in month. (0-6). Sunday is day 0"
	DateFormatConversions at: 'w' put: '%w'. "day in month. (1-7) Monday is day 1"

	DateFormatConversions at: 'D' put: '%j'. "Day of year"

	"day of week. use long form if pattern is 4+ in length"
	DateFormatConversions at: 'E' put: '%a'. "Day of week, using locale's abbreviated weekday names"
	DateFormatConversions at: 'EE' put: '%a'. "Day of week, using locale's abbreviated weekday names"
	DateFormatConversions at: 'EEE' put: '%a'. "Day of week, using locale's abbreviated weekday names"

	DateFormatConversions at: 'EEEE' put: '%A'. "Day of week, using locale's weekday names"
	DateFormatConversions at: 'EEEEE' put: '%A'. "Day of week, using locale's weekday names"

	DateFormatConversions at: 'yyyy' put: '%Y'. "Year including century (eg: 1993)"
	DateFormatConversions at: 'y' put: '%y'. "Year within century (00-99)"
	DateFormatConversions at: 'yy' put: '%y' "Year within century (00-99)"


! !

!EsDatePatternConverter class methodsFor: 'initialize' stamp: 'DonaldMacQueen 8/1/2012 11:41'!
initializeTimeFormatConversions

	"self initializeTimeFormatConversions"

	TimeFormatConversions := Dictionary new. "time formats"

	TimeFormatConversions at: 'HH' put: '%H'. "Hour, (00-23)"
	TimeFormatConversions at: 'H' put: '%k'. "Hour, (0-23) -> no leading zeros"

	TimeFormatConversions at: 'mm' put: '%M'. "2 digit minute"

	TimeFormatConversions at: 'ss' put: '%S'. "2 digit second"

	TimeFormatConversions at: 'SSS' put: '%_'. "3 digit millisecond"

	TimeFormatConversions at: 'hh' put: '%I'. "Capital I - Hour, (01-12)"
	TimeFormatConversions at: 'h' put: '%l'. "Small l - Hour, (1-12) -> no leading zeros		"

	TimeFormatConversions at: 'a' put: '%P'. "Locale's Equivalent of AM/PM"



! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 13:04'!
asLowercase: aCharacter

	"Answer a Character that is the lower case letter
	 corresponding to the aCharacter. If aCharacter is not an
	 upper case letter, answer the character itself."

	^aCharacter asciiValue < 256
		ifTrue: [self upperToLowercaseMap at: aCharacter asciiValue + 1]
		ifFalse: [  aCharacter asLowercase]! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 12:54'!
asUppercase: aCharacter

	"Answer a Character that is the upper case letter
	 corresponding to the aCharacter. If aCharacter is not a
	 lower case letter, answer the character itself."

	^(aCharacter asciiValue) < 256
		ifTrue: [self lowerToUppercaseMap at: aCharacter asciiValue + 1]
		ifFalse: [ aCharacter asUppercase]! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'LibrarySupervisor 6/23/2011 13:34'!
checkFormatString: vastFormatString forValidPairs: formatConversions

	| temp |

	"finally we need to check all the '%someCharacter pairs to see that they have vaild values.
	this will detect the intermixing of time and date values. 
	For instance, '%b %H%ms%ss %y%m%d' is invalid because the day of the week is grouped with the time not the date."

	1 to: vastFormatString size do: [:index | | char |
		char := vastFormatString at: index.
		$% = char
			ifTrue: [temp := char asString]
			ifFalse: [
				(Character value: char asInteger) isLetter
					ifTrue: [
						temp := temp , char asString.
						(formatConversions values includes: temp) ifFalse: [^nil].
						temp := '']]].

	^vastFormatString! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'LibrarySupervisor 7/19/2011 8:39'!
convertFormatString: stringToFormat formatConversions: formatConversions keys: keys

	| stream vastFormatString | "convert something like 'HH:mm:ss' into its vast equivalent of '%H:%M:%S'."

	stream := WriteStream on: ''.
	vastFormatString := stringToFormat deepCopy.

	keys reverseDo: [:key | | index alreadyDone value | "we need to access the keys in reverse order so that MMMM gets done before MMM, etc."
		value := formatConversions at: key.
		index := vastFormatString indexOfSubCollection: key startingAt: 1 ifAbsent: [0].
		index > 0
			ifTrue: [
				alreadyDone := false.
				index > 1
					ifTrue: [ "we might find a character. $d for instance, that has already been converted, so we need to check to see if a $% preceeds it. If so, skip"
						((vastFormatString at: index - 1) = $%)
							ifTrue: [alreadyDone := true]
							ifFalse: [ "we found the pattern at index 1"
								stream nextPutAll: (vastFormatString copyFrom: 1 to: index - 1)]].
				alreadyDone
					ifFalse: [
						stream
							nextPutAll: value;
							nextPutAll: (
								vastFormatString copyFrom: index + key size to: vastFormatString size).
						vastFormatString := stream contents.
						stream reset "reuse the stream"]]].

	^self checkFormatString: vastFormatString forValidPairs: formatConversions! !

!EsDatePatternConverter methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/2/2012 12:02'!
dateFormat

	^dateFormat! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/27/2012 13:00'!
encodedFormat: format

	"Answer the encoded format for format using the format selectors in aClass."
	
	"handle the special case of underscore for milliseconds"

	| ctype answer scanned token formatStream selector index |
 
	answer := OrderedCollection new.
	formatStream := ReadStream on: format.
	[formatStream atEnd] whileFalse: [
		scanned := formatStream upTo: $%.
		scanned isEmpty ifFalse: [answer add: scanned].
		formatStream atEnd
			ifFalse: [
				token := formatStream next.

				token = $.
					ifTrue: [
						token :=
							formatStream
								next;
								next].

				token = $_
					ifTrue: [selector := #formatMilliseconds:date:time:] 
					ifFalse: [
						selector :=
							(index := (self asUppercase: token) digitValue) < 0
								ifTrue: [nil]
								ifFalse: [
									(token isLowercase) ifTrue: [index := index + 26].
									self formatSelectors at: index - 9]].
				answer
					add: (selector notNil ifTrue: [selector] ifFalse: [String with: $% with: token])]].

	^answer asArray
		
		 




 ! !

!EsDatePatternConverter methodsFor: 'actions' stamp: 'DonaldMacQueen 6/29/2013 17:38'!
format: aLoggingEvent buffer: string

	| stream dateFormatter |

	dateFormat := timeFormat := ''.

	(dateFormatter := self getDateAndTimeFormatter) isNil ifTrue: [^( 'Error - date and time formats are intermixed in specifier {1}' format:  options)]. 

	self
		formatTimeStamp: aLoggingEvent timeStamp
		on: (stream := WriteStream on: '')
		using: dateFormatter.

	^string , stream contents

! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 14:44'!
formatA: aStream date: date time: time

	"Append the name of the day of the week of the date on aStream."

	aStream nextPutAll: ( date weekday).! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 14:43'!
formatB: aStream date: date time: time

	"Append the name of the month of the date on aStream."

	aStream nextPutAll: (date monthName).! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 10:59'!
formatC: aStream date: date time: time

	"Append the century of the year on aStream.  This is a POSIX.2 extension."

	(date year / 100) truncated printOn: aStream.! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 11:00'!
formatD: aStream date: date time: time

	"Append the date using the format %m/%d/%y on aStream.  This is a POSIX.2 extension."

	self formatm: aStream date: date time: time.
	aStream nextPut: $/.
	self formatd: aStream date: date time: time.
	aStream nextPut: $/.
	self formaty: aStream date: date time: time.! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 11:03'!
formatH: aStream date: date time: time

	"Append the hour of the time to aStream. The hour
	 is printed in 24 hour time format (00 - 23) with a leading
	 zero when the hour is less than ten." 

	| hours |
	(hours := time hours) < 10 ifTrue: [aStream nextPut: $0].
	hours printOn: aStream.! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 6/3/2013 18:53'!
formatI: aStream date: date time: time

	"Append the hour of the time to aStream. The hour
	 is printed in 12 hour time format (01 - 12) with a leading
	 zero when the hour is less than ten." 

	| hours |
	(hours := time hours) == 0 ifTrue: [^aStream nextPutAll: '12'].   
	hours <= 12 ifTrue: [
		hours < 10 ifTrue: [aStream nextPut: $0].
		hours printOn: aStream.
	] ifFalse: [
		hours - 12 < 10 ifTrue: [aStream nextPut: $0].
		hours - 12 printOn: aStream.
	].! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 11:04'!
formatM: aStream date: date time: time

	"Append the minute (00 - 59) of the time to aStream. A
	 leading zero is printed when the minute is less than 10." 

	| minutes |
	(minutes := time minutes) < 10 ifTrue: [aStream nextPut: $0].
	minutes printOn: aStream.! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/27/2012 13:07'!
formatMilliseconds: aStream date: date time: time

	"Append the milliseconds (000 - 999) of the time to aStream. A
	 leading zero is printed when milliseconds is less than 100."

	| milliseconds |

	time notNil
		ifTrue: [

			milliseconds := time nanoSecond / 1000000.0.

			milliseconds < 100 ifTrue: [aStream nextPut: $0].
			milliseconds < 10 ifTrue: [aStream nextPut: $0].
			aStream nextPutAll: milliseconds asInteger asString]! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 11:04'!
formatP: aStream date: date time: time

	"Append the appropriate am/pm string from aLocale on
	 aStream in lowercase depending on the hour of the time.  This is a GNU extension."

	| tempStream |

	tempStream := WriteStream on: String new.

	self formatp: tempStream date: date time: time.
	
	aStream nextPutAll: tempStream contents asLowercase.! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 11:05'!
formatS: aStream date: date time: time

	"Append the seconds (00 - 59) of the time to aStream. A
	 leading zero is printed when seconds is less than 10." 

	| seconds |
	(seconds := time seconds) < 10 ifTrue: [aStream nextPut: $0].
	seconds printOn: aStream.! !

!EsDatePatternConverter methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/2/2012 12:46'!
formatSelectors

	^self class FormatSelectors! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 11:06'!
formatT: aStream date: date time: time
	"Append the equivalent of (%H:%M:%S).  This is a POSIX.2 extension."

	self formatH: aStream date: date time: time.
	aStream nextPut: $:.
	self formatM: aStream date: date time: time.
	aStream nextPut: $:.
	self formatS: aStream date: date time: time.! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/7/2012 20:35'!
formatTimeStamp: now on: stream using: formatter

	dateFormat := self encodedFormat: formatter dateFormat.
	timeFormat := self encodedFormat: formatter timeFormat.	

	self printDateThenTime
		ifTrue: [	self printDate: now asDate time: nil on: stream usingFormat:   dateFormat.
				^self printDate: nil time: now asTime on: stream usingFormat:   timeFormat.].

	self printTimeOnly ifTrue: [^self printDate: nil time: now asTime on: stream usingFormat:   timeFormat.].
 
	self printTimeThenDate
		ifTrue: [	self printDate: nil time: now asTime on: stream usingFormat:   timeFormat.
				^self printDate: now asDate time: nil on: stream usingFormat:   dateFormat.].

	self printDateOnly ifTrue: [^self printDate: now asDate time: nil on: stream usingFormat:   dateFormat.].

 
	 






! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 11:07'!
formatX: aStream date: date time: time

	"Append the time using the current time format to aStream." 

	self printTime: time on: aStream.! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 11:07'!
formatY: aStream date: date time: time

	"Append the year of the date to aStream." 

	date year printOn: aStream.! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 11:10'!
formatZ: aStream date: date time: time

	"Append the time zone abbreviation to aStream."
	"It is okay to append nothing if the time zone can't be determined."

	(DateAndTime date: date time: time) timeZoneAbbreviation printOn: aStream! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 13:46'!
formata: aStream date: date time: time

	"Append the name of the abbreviated day of the week of the date
	 on aStream."

	aStream nextPutAll: (date weekday truncateTo: 3).! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 13:28'!
formatb: aStream date: date time: time

	"Append the abbreviated name of the month of the date on aStream."

	aStream nextPutAll: (date monthName asString truncateTo: 3 ).
	
! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 10:59'!
formatd: aStream date: date time: time

	"Append the day of the month (01-31) of the date to aStream.
	 The day is preceded with a leading zero when it is less than ten." 

	| dayOfMonth |
	(dayOfMonth := date dayOfMonth) < 10 ifTrue: [aStream nextPut: $0].
	dayOfMonth printOn: aStream.! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 11:03'!
formate: aStream date: date time: time

	"Append the day of the month ( 1-31) of the date to aStream.
	 The day is preceded with a space when it is less than ten." 

	| dayOfMonth |
	(dayOfMonth := date dayOfMonth) < 10 ifTrue: [ aStream nextPut: $  ].
	dayOfMonth printOn: aStream.! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 11:03'!
formatf: aStream date: date time: time

	"Append the day of the month (1-31) of the date to aStream." 

	date dayOfMonth printOn: aStream.! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 11:03'!
formath: aStream date: date time: time

	"Append the abbreviated name of the month of the date on aStream.  This is a POSIX.2 extension"

	self formath: aStream date: date time: time.! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 11:03'!
formatj: aStream date: date time: time

	"Append the day of the year (001-366) of the date to aStream.
	 The day is preceded with a leading zeros when it is less than three
	characters long." 

	| dayOfYear |
	(dayOfYear := date dayOfYear) < 10 ifTrue: [aStream nextPut: $0].
	dayOfYear < 100 ifTrue: [aStream nextPut: $0].
	dayOfYear printOn: aStream.! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 11:04'!
formatk: aStream date: date time: time

	"Append the hour of the time to aStream. The hour
	 is printed in 24 hour time format (0 - 23) without any
	 leading zeros." 
	
	time hours printOn: aStream.! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 6/3/2013 18:54'!
formatl: aStream date: date time: time

	"Append the hour of the time to aStream. The hour
	 is printed in 12 hour time format (1 - 12) without any
	 leading zeros." 

	| hours |
	(hours := time hours) == 0 ifTrue: [^aStream nextPutAll: '12'].   
	hours <= 12 
		ifTrue: [hours printOn: aStream]
		ifFalse: [hours - 12 printOn: aStream].! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 11:04'!
formatm: aStream date: date time: time

	"Append the month index (01-12) of the date to aStream.
	 The month is preceded with a leading zero when it is less than ten." 

	| month |
	(month := date monthIndex) < 10 ifTrue: [aStream nextPut: $0].	
	month printOn: aStream.! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 11:04'!
formatn: aStream date: date time: time

	"Append a newline character to aStream.  This is a POSIX.2 extension."

	aStream cr.! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 13:32'!
formatp: aStream date: date time: time

	"Append the appropriate am/pm string from aLocale on
	 aStream depending on the hour of the time." 
	
	aStream nextPutAll:
		(time hours > 11
			ifTrue: ['PM'] 
			ifFalse: ['AM']).! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 11:06'!
formatt: aStream date: date time: time

	"Append a tab character to aStream.  This is a POSIX.2 extension."

	aStream tab.! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 14:51'!
formatu: aStream date: date time: time

	"Append the index of the day of the week (1-7) of the date on
	 aStream. Monday is 1.  This is a POSIX.2 extension."

	| weekDay |
	weekDay := (date weekdayIndex - 1).
	(weekDay == 0) ifTrue: [ weekDay := 7 ].
	weekDay printOn: aStream.! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 14:54'!
formatw: aStream date: date time: time

	"Append the index of the day of the week (0-6) of the date on
	 aStream. Sunday is 0."

	| weekDay |
	weekDay := date weekdayIndex - 1 .
	weekDay printOn: aStream.! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 11:06'!
formatx: aStream date: date time: time

	"Append the date using the current date format to aStream." 

	self printDate: date on: aStream.! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 11:07'!
formaty: aStream date: date time: time

	"Append the year within the century (00-99) of the date to aStream.
	 The year is preceded with a leading zero when it is less than ten." 

	| year |
	(year := date year abs \\ 100) < 10 ifTrue: [aStream nextPut: $0].
	year printOn: aStream.! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 11:08'!
formatz: aStream date: date time: time

	"Append the month index (1-12) of the date to aStream." 

	date monthIndex printOn: aStream.! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'LibrarySupervisor 6/23/2011 13:34'!
getDateAndTimeFormats

	self splitDateAndTimeFormats.
	(dateFormat :=
		self
			convertFormatString: dateFormat
			formatConversions: self class DateFormatConversions
			keys: self class DateFormatConversions keys asSortedCollection)
				isNil
					ifTrue: [^nil].

	(timeFormat :=
		self
			convertFormatString: timeFormat
			formatConversions: self class TimeFormatConversions
			keys: self class TimeFormatConversions keys asSortedCollection)
				isNil
					ifTrue: [^nil]

! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'LibrarySupervisor 6/23/2011 13:34'!
getDateAndTimeFormatter

	self isHardCodedOption ifFalse: [^self getDateAndTimeFormats]! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'LibrarySupervisor 6/23/2011 13:34'!
isHardCodedOption

	options isNil ifTrue: [options := 'ISO8601']. "default"

	options = 'DATE'
		ifTrue: [
			printCombos := 3.
			dateFormat := '%d %b %Y '.
			timeFormat := '%H:%M:%S,%_'.
			^true]. "dd MMM yyyy HH:mm:ss,SSS"

	options = 'ABSOLUTE'
		ifTrue: [
			printCombos := 2.
			timeFormat := '%H:%M:%S,%_'.
			^true]. "HH:mm:ss,SSS"

	options = 'ISO8601'
		ifTrue: [
			printCombos := 3.
			dateFormat := '%Y-%m-%d '.
			timeFormat := '%H:%M:%S,%_'.
			^true]. "yyyy-MM-dd HH:mm:ss,SSS"

	^false



! !

!EsDatePatternConverter methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/2/2012 12:40'!
lowerToUppercaseMap

	^self class LowerToUppercaseMap! !

!EsDatePatternConverter methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
options: aString

	options := aString! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'LibrarySupervisor 6/23/2011 13:34'!
parse: aString parsePosition: anInteger

	^nil! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/2/2012 09:43'!
printDate: aDate time: aTime on: aStream usingFormat: aFormat

	"Append a printed representation of aDate and aTime on aStream 
	 according to the format aFormat."	

	aFormat do: [:s |
		s isSymbol
			ifTrue: [self perform: s with: aStream with: aDate with: aTime]
			ifFalse: [aStream nextPutAll: s]].
		
		"dq"






! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'LibrarySupervisor 6/23/2011 13:34'!
printDateOnly

	^printCombos = 1! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'LibrarySupervisor 6/23/2011 13:34'!
printDateThenTime

	^printCombos = 3! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'LibrarySupervisor 6/23/2011 13:34'!
printTimeOnly

	^printCombos = 2! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'LibrarySupervisor 6/23/2011 13:34'!
printTimeThenDate

	^printCombos = 4! !

!EsDatePatternConverter methodsFor: 'internal' stamp: 'DonaldMacQueen 8/1/2012 16:01'!
splitDateAndTimeFormats

	| firstDatePos firstTimePos dateFormatConversionKeys timeFormatConversionKeys |

	firstDatePos := firstTimePos := SmallInteger maxVal.

	dateFormatConversionKeys := self class DateFormatConversions keys asOrderedCollection.
	1 to: dateFormatConversionKeys size do: [:index | | pos def |
		def := (dateFormatConversionKeys at: index).
		pos := options indexOfSubCollection: def startingAt: 1 ifAbsent: [].
		pos notNil ifTrue: [pos < firstDatePos ifTrue: [firstDatePos := pos]]].

	timeFormatConversionKeys := self class TimeFormatConversions keys asOrderedCollection.
	1 to: timeFormatConversionKeys size do: [:index | | pos def |
		def := (timeFormatConversionKeys at: index).
		pos := options indexOfSubCollection: def startingAt: 1 ifAbsent: [].
		pos notNil ifTrue: [pos < firstTimePos ifTrue: [firstTimePos := pos]]].

	printDateFirst := firstDatePos < firstTimePos.

	(firstDatePos = SmallInteger maxVal and: [firstTimePos = SmallInteger maxVal])
		ifTrue: [ "no date or time format found. should not happen" ^self].

	printDateFirst
		ifTrue: [
			firstTimePos < SmallInteger maxVal "we have a time too"
				ifTrue: [
					printCombos := 3.
					dateFormat := options copyFrom: 1 to: firstTimePos - 1.
					timeFormat := options copyFrom: firstTimePos to: options size]
				ifFalse: [
					dateFormat := options.
					printCombos := 1]]
		ifFalse: [
			firstDatePos < SmallInteger maxVal "we have a date too"
				ifTrue: [
					printCombos := 4.
					timeFormat := options copyFrom: 1 to: firstDatePos - 1.
					dateFormat := options copyFrom: firstDatePos to: options size]
				ifFalse: [
					timeFormat := options.
					printCombos := 2]]

! !

!EsDatePatternConverter methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/2/2012 12:02'!
timeFormat

	^timeFormat! !

!EsDatePatternConverter methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/2/2012 12:56'!
upperToLowercaseMap

	^self class UpperToLowercaseMap! !

EsPatternConverter subclass: #EsFullLocationPatternConverter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Converters'!

!EsFullLocationPatternConverter methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:35'!
format: aLoggingEvent buffer: string

	aLoggingEvent className isNil ifTrue: [^string].

	^string , aLoggingEvent className , '>>' , aLoggingEvent methodName! !

EsPatternConverter subclass: #EsLevelPatternConverter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Converters'!

!EsLevelPatternConverter methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:35'!
format: aLoggingEvent buffer: string

	^string , aLoggingEvent level levelStr! !

EsPatternConverter subclass: #EsLineSeparatorPatternConverter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Converters'!

!EsLineSeparatorPatternConverter methodsFor: 'actions' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
format: aLoggingEvent buffer: string

	^string , EsAbstractLayout lineSeparator! !

EsPatternConverter subclass: #EsLiteralPatternConverter
	instanceVariableNames: 'literal'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Converters'!

!EsLiteralPatternConverter class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 7/19/2011 9:5'!
literal: aString

	^(self new)
		literal: aString;
		yourself! !

!EsLiteralPatternConverter methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:36'!
format: aLoggingEvent buffer: string

	^string , literal! !

!EsLiteralPatternConverter methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:36'!
literal: aString

	literal := aString! !

EsPatternConverter subclass: #EsLoggerPatternConverter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Converters'!

!EsLoggerPatternConverter methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:36'!
format: aLoggingEvent buffer: string

	^string , aLoggingEvent logger name! !

EsPatternConverter subclass: #EsMessagePatternConverter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Converters'!

!EsMessagePatternConverter methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:36'!
format: aLoggingEvent buffer: string

	^string , aLoggingEvent message! !

EsPatternConverter subclass: #EsMethodLocationPatternConverter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Converters'!

!EsMethodLocationPatternConverter methodsFor: 'actions' stamp: 'DonaldMacQueen 8/8/2012 11:09'!
format: aLoggingEvent buffer: string

	aLoggingEvent methodName isNil ifTrue: [^string].
	^string , aLoggingEvent methodName! !

EsPatternConverter subclass: #EsObjectPatternConverter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Converters'!

!EsObjectPatternConverter methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:37'!
format: aLoggingEvent buffer: string

	| stringToAppend |

	aLoggingEvent object isNil ifTrue: [^string].

	stringToAppend :=
		(aLoggingEvent object respondsTo: #printLog4s)
			ifTrue: [aLoggingEvent object printLog4s]
			ifFalse: [aLoggingEvent object printString].

	^string , stringToAppend! !

!EsPatternConverter class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 7/19/2011 9:5'!
name: aString style: anObject

	^super new
		name: aString style: anObject;
		yourself! !

!EsPatternConverter class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 7/19/2011 9:5'!
new

	^super new
		initialize;
		yourself! !

!EsPatternConverter class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 7/19/2011 9:5'!
singleton

	singleton isNil
		ifTrue: [
			singleton :=
				super new
					initialize;
					yourself].
	^singleton! !

!EsPatternConverter class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 7/15/2011 14:37'!
singleton: anObject

	singleton := anObject! !

!EsPatternConverter methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
options: aString

	"intentional no-op. most converter do NOT have options."

! !

EsPatternConverter subclass: #EsRelativeTimePatternConverter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Converters'!

!EsRelativeTimePatternConverter methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 19:3'!
format: aLoggingEvent buffer: string

	^string , (aLoggingEvent timeStamp - aLoggingEvent startTime) printString! !

EsPatternConverter subclass: #EsThreadPatternConverter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Log4s-Converters'!

!EsThreadPatternConverter methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 19:3'!
format: aLoggingEvent buffer: string

	^string , aLoggingEvent threadName! !

Object subclass: #EsPatternParser
	instanceVariableNames: 'currentLiteral state char index pattern patternLength ruleRegistry patternConverters formattingInfo formattingInfoDefault formattingInfos'
	classVariableNames: 'PatternLayoutRules'
	poolDictionaries: ''
	category: 'Log4s'!

!EsPatternParser class methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/1/2012 11:06'!
ConverterState

	^1! !

!EsPatternParser class methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/1/2012 11:06'!
DotState

	^2! !

!EsPatternParser class methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/1/2012 14:55'!
EscapeChar

	^'%'! !

!EsPatternParser class methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/1/2012 11:05'!
LiteralState

	^0! !

!EsPatternParser class methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/1/2012 11:06'!
MaxState

	^5! !

!EsPatternParser class methodsFor: 'accessing' stamp: 'DonaldMacQueen 8/1/2012 11:06'!
MinState

	^4! !

!EsPatternParser class methodsFor: 'accessing' stamp: 'LibrarySupervisor 6/23/2011 13:45'!
PatternLayoutRules

	PatternLayoutRules isNil ifTrue: [self initializePatternLayoutRules].
	^PatternLayoutRules! !

!EsPatternParser class methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
initializeClassVariables

	"self  initializeClassVariables"

	self initializePatternLayoutRules! !

!EsPatternParser class methodsFor: 'accessing' stamp: 'LibrarySupervisor 8/3/2011 16:57'!
initializePatternLayoutRules

	"self initializePatternLayoutRules"

	PatternLayoutRules := Dictionary new.

	PatternLayoutRules at: 'c' put: #EsLoggerPatternConverter. "category - name of logger"
	PatternLayoutRules at: 'logger' put: #EsLoggerPatternConverter. "category - name of logger"

	PatternLayoutRules at: 'C' put: #EsClassNamePatternConverter. "class name"
	PatternLayoutRules at: 'class' put: #EsClassNamePatternConverter. "class name"

	PatternLayoutRules at: 'd' put: #EsDatePatternConverter.
	PatternLayoutRules at: 'date' put: #EsDatePatternConverter.

	PatternLayoutRules at: 'l' put: #EsFullLocationPatternConverter.

	PatternLayoutRules at: 'm' put: #EsMessagePatternConverter. "the application supplied message associated with the logging event"
	PatternLayoutRules at: 'message' put: #EsMessagePatternConverter. "same as above"

	PatternLayoutRules at: 'M' put: #EsMethodLocationPatternConverter. "the method name where the logging request was issued"
	PatternLayoutRules at: 'method' put: #EsMethodLocationPatternConverter. "same as above"

	PatternLayoutRules at: 'o' put: #EsObjectPatternConverter. "the object that created the logging event"
	PatternLayoutRules at: 'object' put: #EsObjectPatternConverter. "same as above"

	PatternLayoutRules at: 'n' put: #EsLineSeparatorPatternConverter. "the platform dependent line separator character or characters"

	PatternLayoutRules at: 'p' put: #EsLevelPatternConverter. "the priority (level) of the logging event"
	PatternLayoutRules at: 'level' put: #EsLevelPatternConverter. "same as above"

	PatternLayoutRules at: 'r' put: #EsRelativeTimePatternConverter.
	PatternLayoutRules at: 'relative' put: #EsRelativeTimePatternConverter.
	"the number of milliseconds elapsed from the construction of the layout until the creation of the logging event"

	PatternLayoutRules at: 't' put: #EsThreadPatternConverter. "the name of the process that created the event"
	PatternLayoutRules at: 'thread' put: #EsThreadPatternConverter "same as above"


! !

!EsPatternParser class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 6/23/2011 13:45'!
new

	^self shouldNotImplement! !

!EsPatternParser class methodsFor: 'instance creation' stamp: 'LibrarySupervisor 7/22/2011 11:26'!
parse: patternString loggingEvent: aLoggingEvent ruleRegistry: aLookupTable

	"This method returns aString. do NOT add yourself"

	^(super new) parse: patternString loggingEvent: aLoggingEvent ruleRegistry: aLookupTable



! !

!EsPatternParser methodsFor: 'actions' stamp: 'DonaldMacQueen 8/1/2012 15:41'!
addConverter: aPatternConverter

	patternConverters at: aPatternConverter class name ifAbsentPut: [aPatternConverter].

	currentLiteral := ''.

	state := self literalState. "Next pattern is assumed to be a literal."

	formattingInfo reset " Reset formatting info"

! !

!EsPatternParser methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:45'!
convertAndFormat: aLoggingEvent

	| string |

	string := String new.

	1 to: patternConverters size do: [:idx | | eachpatternConverter eachformattingInfo fieldStart |
		fieldStart := string size + 1.
		eachpatternConverter := (patternConverters at: idx).
		eachformattingInfo := (formattingInfos at: idx).
		string := eachpatternConverter format: aLoggingEvent buffer: string.
		string := eachformattingInfo format: fieldStart buffer: string].

	^string! !

!EsPatternParser methodsFor: 'actions' stamp: 'DonaldMacQueen 8/1/2012 15:38'!
converterState

	^self class ConverterState

! !

!EsPatternParser methodsFor: 'actions' stamp: 'DonaldMacQueen 6/5/2013 16:56'!
createConverter: aConverterIdString
	converterRegistry: converterRegistry
	rules: rules
	options: options

	| converterObj successfulName done idx |

	done := false.
	successfulName := nil.
	idx := aConverterIdString size.

	[done] whileFalse: [| chr converterName | "successively shorten the name string and try to find it"

		chr := (aConverterIdString at: idx).
		chr notNil
			ifTrue: [
				converterName := aConverterIdString copyFrom: 1 to: idx.

				converterRegistry notNil
					ifTrue: [
						converterObj := converterRegistry at: converterName ifAbsent: [].

						(done := converterObj notNil and: [successfulName isNil])
							ifTrue: [successfulName := idx]]. "end of  converterRegistry notNil"

				(converterObj isNil and: [rules notNil])
					ifTrue: [
						converterObj := rules at: converterName ifAbsent: [].

						(done := converterObj notNil and: [successfulName isNil])
							ifTrue: [successfulName := idx]]].
		idx := idx - 1.
		idx = 0 ifTrue: [done := true]].

	converterObj isNil
		ifTrue: [
			EsLogLog logError: ('Unrecognized format specifier {1}' format: aConverterIdString). 
			^nil]
		ifFalse: [| class |
			currentLiteral :=
				aConverterIdString copyFrom: successfulName + 1 to: aConverterIdString size.
			class := (Smalltalk
				at: converterObj
				ifAbsent: [
					EsLogLog logError: ('Failed to create converter {1}' format: aConverterIdString).  
					^nil]).
			^class singleton options: options "set any options"]


! !

!EsPatternParser methodsFor: 'actions' stamp: 'DonaldMacQueen 8/1/2012 15:37'!
dotState

	^self class DotState

! !

!EsPatternParser methodsFor: 'actions' stamp: 'DonaldMacQueen 8/1/2012 14:58'!
escapeChar

	^self class EscapeChar
! !

!EsPatternParser methodsFor: 'actions' stamp: 'LibrarySupervisor 7/19/2011 8:43'!
extractConverter: convBuf

	| chr |

	convBuf nextPutAll: char.
	index > patternLength ifTrue: [^self]. "we could be on the last character, example %n"

	chr := pattern at: index.

	[index <= patternLength] whileTrue: [
		chr isAlphaNumeric
			ifTrue: [
				convBuf nextPut: chr.
				currentLiteral := currentLiteral , chr asString.
				index := index + 1.
				index > pattern size ifTrue: [^self "we are done"].
				chr := pattern at: index]
			ifFalse: [^self]]









! !

!EsPatternParser methodsFor: 'actions' stamp: 'LibrarySupervisor 6/23/2011 13:45'!
extractOptions: aStream

	"return what is between the curly braces and set the index. Example {DATE} returns DATE"

	| start end |

	(start := pattern indexOfSubCollection: '{' startingAt: index ifAbsent: [0]) = 0 ifTrue: [^nil].

	(end := pattern indexOfSubCollection: '}' startingAt: index ifAbsent: [0]) = 0 ifTrue: [^nil].

	aStream nextPutAll: (pattern copyFrom: start + 1 to: end - 1).

	index := end + 1.

	^aStream contents! !

!EsPatternParser methodsFor: 'actions' stamp: 'LibrarySupervisor 7/19/2011 8:43'!
finalizeConverter

	| stream aPatternConverter converterId options |

	stream := WriteStream on: String new.
	self extractConverter: stream.
	converterId := stream contents.
	options := self extractOptions: (stream := WriteStream on: String new).

	aPatternConverter :=
		self
			createConverter: converterId
			converterRegistry: ruleRegistry
			rules: self class PatternLayoutRules
			options: options.

	aPatternConverter isNil
		ifTrue: [
			self logBadSpecifier: converterId.
			patternConverters add: (EsLiteralPatternConverter literal: currentLiteral).
			formattingInfos add: formattingInfoDefault deepCopy]
		ifFalse: [
			patternConverters add: aPatternConverter.
			formattingInfos add: formattingInfo.

			currentLiteral size > 0
				ifTrue: [
					patternConverters add: (EsLiteralPatternConverter literal: currentLiteral).
					formattingInfos add: formattingInfoDefault deepCopy]].

	currentLiteral := ''

! !

!EsPatternParser methodsFor: 'initialize' stamp: 'DonaldMacQueen 8/1/2012 15:41'!
initialize: aLookupTable patternString: patternString

	index := 1.
	pattern := patternString.
	patternLength := pattern size.
	state := self literalState.
	currentLiteral := ''.
	patternConverters := OrderedCollection new.
	formattingInfos := OrderedCollection new.
	formattingInfoDefault := EsFormattingInfo Default deepCopy.
	formattingInfo := formattingInfoDefault.
	ruleRegistry := aLookupTable.
	ruleRegistry := aLookupTable

! !

!EsPatternParser methodsFor: 'actions' stamp: 'DonaldMacQueen 8/1/2012 15:38'!
literalState

	^self class LiteralState

! !

!EsPatternParser methodsFor: 'actions' stamp: 'DonaldMacQueen 6/29/2013 18:06'!
logBadSpecifier: converterId

	| msg |

	(converterId isNil or: [converterId size = 0])
		ifTrue: [msg := ('Empty conversion specifier starting at position {1} in conversion pattern.' format: index asString)]  
		ifFalse: [msg := ('Unrecognized conversion specifier {1} starting at position {2}  in conversion pattern.' format: {converterId asString.  index asString})]. 
	EsLogLog logError: msg! !

!EsPatternParser methodsFor: 'actions' stamp: 'DonaldMacQueen 8/1/2012 15:37'!
maxState

	^self class MaxState

! !

!EsPatternParser methodsFor: 'actions' stamp: 'DonaldMacQueen 8/1/2012 15:37'!
minState

	^self class MinState

! !

!EsPatternParser methodsFor: 'initialize' stamp: 'DonaldMacQueen 8/4/2012 07:42'!
parse: patternString

	[index <= (patternLength)] whileTrue: [
		char := (pattern at: index) asString.
		index := index + 1.
		state = self literalState
			ifTrue: [self parseLiteralState]
			ifFalse: [
				state = self converterState
					ifTrue: [self parseConverterState]
					ifFalse: [
						state = self minState
							ifTrue: [self parseMinState]
							ifFalse: [
								state = self dotState
									ifTrue: [self parseDotState]
									ifFalse: [state = self maxState ifTrue: [self parseMaxState]]]]]].

	currentLiteral size ~= 0
		ifTrue: [
			patternConverters add: (EsLiteralPatternConverter literal: currentLiteral asString).
			formattingInfos add: formattingInfoDefault deepCopy]

! !

!EsPatternParser methodsFor: 'initialize' stamp: 'LibrarySupervisor 6/23/2011 13:45'!
parse: patternString loggingEvent: aLoggingEvent ruleRegistry: aLookupTable

	self initialize: aLookupTable patternString: patternString.

	self parse: patternString.

	^self convertAndFormat: aLoggingEvent! !

!EsPatternParser methodsFor: 'actions' stamp: 'DonaldMacQueen 8/1/2012 15:40'!
parseConverterState

	currentLiteral := currentLiteral , char.

	(char = '-') ifTrue: [^formattingInfo leftAlign: true].

	char = '.' ifTrue: [^state := self dotState].

	"default"
	(char >= '0' and: [char <= '9'])
		ifTrue: [
			formattingInfo min: (char asNumber - $0 digitValue).
			state := self minState]
		ifFalse: [
			self finalizeConverter.
			" Next pattern is assumed to be a literal."
			state := self literalState.
			formattingInfo := formattingInfoDefault deepCopy.
			currentLiteral := '']! !

!EsPatternParser methodsFor: 'actions' stamp: 'DonaldMacQueen 6/3/2013 17:53'!
parseDotState

	currentLiteral := currentLiteral , char.

	(char >= '0' and: [char <= '9'])
		ifTrue: [
			formattingInfo max: (char asNumber - $0 digitValue).
			state := self maxState]
		ifFalse: [
			EsLogLog logError: ('Error occured in position {1}. Was expecting digit, instead got character' format: index printString with: char).  
			state := self literalState]
		
		

! !

!EsPatternParser methodsFor: 'actions' stamp: 'DonaldMacQueen 8/1/2012 15:38'!
parseLiteralState

	| peekChar |

	" In literal state, the last char is always a literal."

	(index > patternLength) ifTrue: [^currentLiteral := currentLiteral , char].

	(char = self escapeChar )
		ifTrue: [

			peekChar := pattern at: index.
			(peekChar = self escapeChar)
				ifTrue: [
					index := index + 1.
					^currentLiteral := currentLiteral , char]
				ifFalse: [

					currentLiteral size > 0 "default"
						ifTrue: [
							patternConverters
								add: (EsLiteralPatternConverter literal: currentLiteral).
							formattingInfos add: formattingInfoDefault deepCopy].

					currentLiteral := ''. "default"
					currentLiteral := currentLiteral , char.
					state := self converterState.
					formattingInfo := formattingInfoDefault deepCopy]]

		ifFalse: [^currentLiteral := currentLiteral , char]



! !

!EsPatternParser methodsFor: 'actions' stamp: 'DonaldMacQueen 8/1/2012 15:40'!
parseMaxState

	currentLiteral := currentLiteral , char.

	(char >= '0' and: [char <= '0'])
		ifTrue: [formattingInfo max: ((formattingInfo max * 10) + (char asNumber - $0 digitValue))]
		ifFalse: [
			state := self literalState.
			self finalizeConverter]


! !

!EsPatternParser methodsFor: 'actions' stamp: 'DonaldMacQueen 8/1/2012 15:40'!
parseMinState

	currentLiteral := currentLiteral , char.

	(char >= '0' and: [char <= '9'])
		ifTrue: [formattingInfo min: ((formattingInfo min * 10) + (char asNumber - $0 digitValue))]
		ifFalse: [
			char = '.'
				ifTrue: [state := self dotState]
				ifFalse: [
					self finalizeConverter.
					state := self literalState.
					formattingInfo := formattingInfoDefault deepCopy.
					currentLiteral := '']]! !
EsLogManager initialize!
